(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    209362,       5018]
NotebookOptionsPosition[    204765,       4869]
NotebookOutlinePosition[    205138,       4886]
CellTagsIndexPosition[    205095,       4883]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Library of one-loop integrals", "Section",
 CellChangeTimes->{{3.57350190286487*^9, 3.573501913242659*^9}, {
  3.573666651717391*^9, 3.573666654242181*^9}, {3.574179983689109*^9, 
  3.574179984647106*^9}, {3.612716302486286*^9, 3.6127163038246193`*^9}}],

Cell[CellGroupData[{

Cell["Initialize", "Subsection",
 CellChangeTimes->{{3.6128003517078953`*^9, 3.6128003598898907`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SimpPowerExpand", "[", "x_", "]"}], ":=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"PowerExpand", "[", "x", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.574023493293314*^9, 3.574023502996666*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Combinatorica`\>\"", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.5790123628033*^9, 3.579012367575576*^9}, 
   3.584065470630303*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "compat"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Combinatorica Graph and Permutations functionality has \
been superseded by preloaded functionality. The package now being loaded may \
conflict with this. Please see the Compatibility Guide for details.\"\>"}]], \
"Message", "MSG",
 CellChangeTimes->{3.6746063570287933`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ZeroList", "[", "arglist_", "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"arglist", "/.", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"#", "\[Rule]", "0"}], ")"}], "&"}], ",", 
     RowBox[{"Subsets", "[", "arglist", "]"}], ",", 
     RowBox[{"{", "2", "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.579010832240737*^9, 3.579010839546554*^9}, {
  3.57901092222068*^9, 3.579011013531438*^9}, {3.5790110591063747`*^9, 
  3.5790110840218887`*^9}, {3.579011266832509*^9, 3.579011485515212*^9}, {
  3.579011854148758*^9, 3.579011867482092*^9}, {3.57901193206878*^9, 
  3.5790119883315287`*^9}, {3.579012658529066*^9, 3.579012682209354*^9}, {
  3.5790127837545023`*^9, 3.579012784160153*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"EqualList", "[", "arglist_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"Flatten", "[", "#", "]"}], "&"}], "/@", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", 
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", "#", "]"}]}], "}"}]}], "]"}], "&"}], ",", 
     RowBox[{"SetPartitions", "[", "arglist", "]"}], ",", 
     RowBox[{"{", "2", "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.579012661754188*^9, 3.579012688640642*^9}, 
   3.5790127862655163`*^9, {3.5790137990672817`*^9, 3.579013838511228*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "PaVe", " ", "integrals", " ", "are", " ", "singular", " ", 
    "when", " ", "any", " ", "argument", " ", "is", " ", "zero", " ", "or", 
    " ", "any", " ", "two", " ", "arguments", " ", "are", " ", 
    RowBox[{"equal", ".", " ", "This"}], " ", "function", " ", "generates", 
    " ", "a", " ", "list", " ", "of", " ", "all", " ", "possible", " ", 
    "ways", " ", "that", " ", "an", " ", "argument", " ", "list", " ", "can", 
    " ", "be", " ", 
    RowBox[{"singular", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"SingularityList", "[", "arglist_", "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"zerolist", "=", 
        RowBox[{"ZeroList", "[", "arglist", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"equallist", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"EqualList", "[", 
           RowBox[{"Select", "[", 
            RowBox[{"#", ",", 
             RowBox[{
              RowBox[{"!", 
               RowBox[{"TrueQ", "[", 
                RowBox[{"#", "\[Equal]", "0"}], "]"}]}], "&"}]}], "]"}], 
           "]"}], "&"}], "/@", "zerolist"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Flatten", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "/.", 
              RowBox[{"#", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "&"}], "/@", 
           RowBox[{"Partition", "[", 
            RowBox[{
             RowBox[{"Riffle", "[", 
              RowBox[{"zerolist", ",", "equallist"}], "]"}], ",", "2"}], 
            "]"}]}], ")"}], ",", "2"}], "]"}]}]}], "\[IndentingNewLine]", 
     "\[IndentingNewLine]", "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.579012702655048*^9, 3.5790128214478083`*^9}, {
   3.579012885296301*^9, 3.57901293891328*^9}, {3.579013000509573*^9, 
   3.579013077439859*^9}, {3.579013131996681*^9, 3.579013201587511*^9}, {
   3.579013231662423*^9, 3.57901332886128*^9}, {3.579013472849806*^9, 
   3.579013526103385*^9}, {3.579013614920434*^9, 3.579013660152219*^9}, 
   3.5790143458638153`*^9, {3.5790144353458138`*^9, 3.579014455253799*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DefineIntegralFunction2", "[", 
   RowBox[{"funcname_", ",", "funcexpr_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"singlist", "=", 
      RowBox[{"Sort", "[", 
       RowBox[{"SingularityList", "[", 
        RowBox[{"{", 
         RowBox[{"m1temp", ",", "m2temp"}], "}"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"funcsinglist", "=", 
      RowBox[{"Collect", "[", 
       RowBox[{
        RowBox[{"Simplify", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Normal", "[", 
            RowBox[{"Simplify", "[", 
             RowBox[{"Series", "[", 
              RowBox[{"funcexpr", ",", 
               RowBox[{"{", 
                RowBox[{"m1", ",", 
                 RowBox[{"singlist", "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", "0"}], "}"}], 
               ",", 
               RowBox[{"{", 
                RowBox[{"m2", ",", 
                 RowBox[{"singlist", "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", "0"}], "}"}]}],
               "]"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "singlist", "]"}]}], "}"}]}], "]"}], 
         "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"psq", ",", 
          RowBox[{"Log", "[", "x_", "]"}]}], "}"}], ",", "FullSimplify"}], 
       "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"singlist2", "=", 
      RowBox[{
       RowBox[{"singlist", "/.", 
        RowBox[{"m1temp", "\[Rule]", "m1temp_"}]}], "/.", 
       RowBox[{"m2temp", "\[Rule]", "m2temp_"}]}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"funcname", "[", 
         RowBox[{"psqsub_", ",", 
          RowBox[{"singlist2", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{"singlist2", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], ":=", 
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{"funcsinglist", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "/.", 
          RowBox[{"psq", "\[Rule]", "psqsub"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "singlist", "]"}]}], "}"}]}], "]"}], ";"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBWIQ/WydVX3uqleOTCz7poFoXfv6TSDaxvcMmC6dx3QG
RHuxzT0LouM+n7HMA9Iz/i51AtFH9Le6gehJP6/7gujk7RdCQbRMWVMEiK64
YhAHoj/KrYsH0Yycu/JA9MqzLvUg+umja+0g+m5OaheIllul3Q+id8bfnAyi
LXZ7LAXbd//SKhCdMtVwF4iOO+YGplN5ZfeBaIlJIWDa5fKO8h9Ael52RwWI
bo3b0QKiY3rft4NomcX1fSB6zqT9YPqPZO80EL3v7k0wvUlX74DZaqA/uC4c
AtHzjLceA9FP7q4+DqKnLJuqs3L9K8el0Z/1QfSyqwtquTcC3bvyDpgGABnQ
va8=
  "]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"c0", "=", 
     RowBox[{
      RowBox[{"-", "16"}], 
      SuperscriptBox["\[Pi]", "2"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dd", "=", 
     RowBox[{"16", 
      SuperscriptBox["\[Pi]", "2"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ww", "=", 
     RowBox[{"-", "1"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"subtry", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"b0", "\[Rule]", 
       RowBox[{"ww", " ", "c0"}]}], ",", 
      RowBox[{"b1", "\[Rule]", 
       RowBox[{"-", "c0"}]}], ",", 
      RowBox[{"c1", "\[Rule]", "c0"}], ",", 
      RowBox[{"c00", "\[Rule]", 
       RowBox[{"-", "c0"}]}], ",", 
      RowBox[{"c11", "\[Rule]", "c0"}], ",", 
      RowBox[{"c12", "\[Rule]", "c0"}], ",", 
      RowBox[{"c22", "\[Rule]", "c0"}], ",", 
      RowBox[{"d1", "\[Rule]", "dd"}], ",", 
      RowBox[{"d2", "\[Rule]", "dd"}], ",", 
      RowBox[{"d3", "\[Rule]", "dd"}]}], "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.575042954867443*^9, 3.5750429854586678`*^9}, {
   3.575490849009437*^9, 3.57549084997838*^9}, {3.5754910209177322`*^9, 
   3.575491021163351*^9}, {3.579005015456066*^9, 3.579005031369314*^9}, {
   3.579005887926588*^9, 3.579005891361506*^9}, {3.579006051576683*^9, 
   3.579006051778133*^9}, {3.5790064448038588`*^9, 3.579006445024472*^9}, {
   3.5790072207109756`*^9, 3.579007229439061*^9}, {3.5793038816604958`*^9, 
   3.5793039016902857`*^9}, 3.579456292710253*^9, 3.579456339374145*^9, {
   3.5798239987784986`*^9, 3.579824004964258*^9}, 3.673367543607161*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"b0", "\[Rule]", 
    RowBox[{"16", " ", 
     SuperscriptBox["\[Pi]", "2"]}]}], ",", 
   RowBox[{"b1", "\[Rule]", 
    RowBox[{"16", " ", 
     SuperscriptBox["\[Pi]", "2"]}]}], ",", 
   RowBox[{"c1", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "16"}], " ", 
     SuperscriptBox["\[Pi]", "2"]}]}], ",", 
   RowBox[{"c00", "\[Rule]", 
    RowBox[{"16", " ", 
     SuperscriptBox["\[Pi]", "2"]}]}], ",", 
   RowBox[{"c11", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "16"}], " ", 
     SuperscriptBox["\[Pi]", "2"]}]}], ",", 
   RowBox[{"c12", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "16"}], " ", 
     SuperscriptBox["\[Pi]", "2"]}]}], ",", 
   RowBox[{"c22", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "16"}], " ", 
     SuperscriptBox["\[Pi]", "2"]}]}], ",", 
   RowBox[{"d1", "\[Rule]", 
    RowBox[{"16", " ", 
     SuperscriptBox["\[Pi]", "2"]}]}], ",", 
   RowBox[{"d2", "\[Rule]", 
    RowBox[{"16", " ", 
     SuperscriptBox["\[Pi]", "2"]}]}], ",", 
   RowBox[{"d3", "\[Rule]", 
    RowBox[{"16", " ", 
     SuperscriptBox["\[Pi]", "2"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.575043013869433*^9, 3.575043073655641*^9, 3.575071447921322*^9, 
   3.575121679858591*^9, 3.575199762167226*^9, 3.575394513588811*^9, 
   3.575410763762823*^9, 3.5754139967079487`*^9, 3.5754140702052794`*^9, 
   3.575431612462995*^9, 3.5754773374465427`*^9, 3.575478030286368*^9, 
   3.575480185856987*^9, {3.575485369424922*^9, 3.575485389918748*^9}, 
   3.575490850977228*^9, 3.575491021522698*^9, 3.5754911886749687`*^9, 
   3.575503795428752*^9, 3.575503961484762*^9, 3.575741183105297*^9, 
   3.5757428916671553`*^9, 3.575818535991591*^9, 3.5759271437889023`*^9, 
   3.575928273017831*^9, 3.5759305656761923`*^9, 3.575931310528709*^9, 
   3.575932802779191*^9, 3.575933088104995*^9, 3.575933675104514*^9, 
   3.575934955362894*^9, 3.575935239906148*^9, 3.575935875555892*^9, 
   3.57593835744022*^9, 3.5759386212125483`*^9, 3.5759394133113956`*^9, 
   3.575940269890809*^9, 3.575940605718133*^9, 3.575943006933403*^9, 
   3.5759445173487453`*^9, 3.575945937190374*^9, 3.57600770536974*^9, 
   3.576008619362673*^9, 3.576015064394923*^9, 3.5760973103045177`*^9, 
   3.576099970816325*^9, 3.5761924359087553`*^9, 3.576194998911701*^9, 
   3.576198776887838*^9, 3.576245992068396*^9, {3.5762519228143187`*^9, 
   3.576251938096982*^9}, 3.576253347619233*^9, 3.576359014786941*^9, 
   3.576363199951838*^9, 3.5763640960016737`*^9, 3.576364222025247*^9, 
   3.576364303118949*^9, 3.576364441335236*^9, 3.5763725433491*^9, 
   3.576429131389999*^9, 3.576536707108782*^9, 3.576539474404297*^9, 
   3.576539810151184*^9, 3.576690429626*^9, 3.5766928964569387`*^9, 
   3.576712134950122*^9, 3.57679573961194*^9, 3.576983736157333*^9, 
   3.576983816134763*^9, 3.5772154577109947`*^9, 3.577278670205554*^9, 
   3.577283263880157*^9, 3.577296658000499*^9, 3.5773831225389433`*^9, 
   3.577401292769883*^9, 3.577662996102186*^9, 3.577675339104742*^9, 
   3.5776763105773983`*^9, 3.577676944934498*^9, 3.577816807099882*^9, 
   3.5778344712265463`*^9, 3.577915846484864*^9, 3.577928330524172*^9, {
   3.577930787717387*^9, 3.577930793311027*^9}, 3.5779310532815523`*^9, 
   3.577934502094308*^9, 3.578330288585644*^9, 3.578342608279067*^9, 
   3.578344520409423*^9, 3.5784941980194483`*^9, 3.5787568165700293`*^9, 
   3.5788499542025747`*^9, 3.578850467574522*^9, 3.578867481129546*^9, 
   3.5789536021744556`*^9, 3.5790050376628447`*^9, {3.579005891877615*^9, 
   3.579005894786524*^9}, {3.579006052743475*^9, 3.579006056337336*^9}, {
   3.579006445615044*^9, 3.579006450744247*^9}, {3.57900723156706*^9, 
   3.579007233723658*^9}, 3.579023930003867*^9, 3.5791951436440077`*^9, 
   3.579216905806884*^9, 3.57928251272476*^9, 3.579283963278603*^9, {
   3.5793038833196297`*^9, 3.579303905744555*^9}, 3.579452384551778*^9, 
   3.579456293208825*^9, {3.579456339880159*^9, 3.579456349621071*^9}, 
   3.5798208789293423`*^9, 3.579824006747295*^9, 3.580008808176806*^9, 
   3.5804391643150253`*^9, 3.5805960519499903`*^9, 3.580642964841667*^9, 
   3.580671586364586*^9, 3.5806991896142597`*^9, 3.580845931808278*^9, 
   3.58117207528395*^9, 3.5811903574594107`*^9, 3.581195613071712*^9, 
   3.5812689697065487`*^9, 3.581270924314546*^9, 3.581276300736116*^9, 
   3.5812918055404797`*^9, 3.5812955085564203`*^9, {3.5812976194617577`*^9, 
   3.581297646507716*^9}, 3.581298245362618*^9, 3.581298844929579*^9, 
   3.581346628053157*^9, 3.5813635143482027`*^9, 3.581369182114607*^9, 
   3.5813695722705927`*^9, 3.581441999866383*^9, 3.5814507973301*^9, 
   3.5817579117250032`*^9, 3.581915387945673*^9, 3.582021737089329*^9, 
   3.58248345526013*^9, 3.584065494446225*^9, 3.584109822216515*^9, 
   3.584110054418703*^9, 3.5842086784711027`*^9, 3.5842088873323517`*^9, 
   3.5842110865926867`*^9, 3.5842112633698463`*^9, 3.5842136057592163`*^9, 
   3.584214152736388*^9, 3.584221412069625*^9, 3.58422408566437*^9, 
   3.584279759833972*^9, 3.584317071592132*^9, 3.584362233178879*^9, 
   3.584383349846652*^9, 3.584448803259794*^9, 3.5844532981658*^9, 
   3.5844533806445713`*^9, 3.5844535874814796`*^9, 3.5844538269952383`*^9, 
   3.584479563361059*^9, 3.584485173930067*^9, 3.5847084878627357`*^9, 
   3.5847203737156057`*^9, 3.5847255086131144`*^9, 3.584874692958721*^9, 
   3.584874747575588*^9, 3.584875999948765*^9, 3.5848795437531023`*^9, 
   3.591549611236767*^9, 3.603755703697228*^9, 3.603757445198309*^9, 
   3.603849868847774*^9, 3.6038501955242977`*^9, 3.603853945090892*^9, 
   3.603925571749226*^9, 3.6041575927138033`*^9, 3.604236386430853*^9, 
   3.60505044157209*^9, 3.6054522256683083`*^9, 3.605453002876965*^9, {
   3.6127948048206577`*^9, 3.6127948200980177`*^9}, 3.6127949524444733`*^9, 
   3.6127985979048433`*^9, 3.612798787235694*^9, 3.612800457060669*^9, {
   3.61331412390136*^9, 3.613314144948628*^9}, 3.613320288769598*^9, 
   3.613578349453062*^9, 3.6148130433714857`*^9, 3.674606357293947*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", 
        SuperscriptBox["\[Pi]", 
         RowBox[{"d", "/", "2"}]]}], ")"}], "/", 
      RowBox[{"Gamma", "[", 
       RowBox[{
        RowBox[{"1", "/", "2"}], "d"}], "]"}]}], " ", 
     RowBox[{"1", "/", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"2", "\[Pi]"}], ")"}], "d"]}], 
     SuperscriptBox["k", 
      RowBox[{"d", "-", "1", "+", "\[Alpha]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["k", "2"], "+", "mm"}], ")"}], 
      RowBox[{"-", "\[Beta]"}]]}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "0", ",", "Infinity"}], "}"}], ",", 
    RowBox[{"GenerateConditions", "\[Rule]", "False"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5776600473816767`*^9, 3.577660080024358*^9}, {
  3.577660935572315*^9, 3.5776609704676437`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["2", 
    RowBox[{"-", "d"}]], " ", 
   SuperscriptBox["mm", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"d", "+", "\[Alpha]", "-", 
       RowBox[{"2", " ", "\[Beta]"}]}], ")"}]}]], " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{
     RowBox[{"-", "d"}], "/", "2"}]], " ", 
   RowBox[{"Gamma", "[", 
    FractionBox[
     RowBox[{"d", "+", "\[Alpha]"}], "2"], "]"}], " ", 
   RowBox[{"Gamma", "[", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["d", "2"]}], "-", 
     FractionBox["\[Alpha]", "2"], "+", "\[Beta]"}], "]"}]}], 
  RowBox[{
   RowBox[{"Gamma", "[", 
    FractionBox["d", "2"], "]"}], " ", 
   RowBox[{"Gamma", "[", "\[Beta]", "]"}]}]]], "Output",
 CellChangeTimes->{{3.577660048527835*^9, 3.577660080426022*^9}, 
   3.5776609715526648`*^9, 3.5776629969663363`*^9, 3.577675339972603*^9, 
   3.577676311441531*^9, 3.577676945426168*^9, 3.577816807894815*^9, 
   3.577834472138543*^9, 3.577915846987459*^9, 3.5779283309577837`*^9, {
   3.577930789011544*^9, 3.5779307934958353`*^9}, 3.57793105355891*^9, 
   3.577934512467959*^9, 3.578330291442461*^9, 3.578342608767334*^9, 
   3.578344520760738*^9, 3.578494198603936*^9, 3.5787568169570847`*^9, 
   3.578849954671998*^9, 3.5788504679263487`*^9, 3.57886748190263*^9, 
   3.578953603129985*^9, 3.5790050380004263`*^9, 3.5790058950743523`*^9, 
   3.579006056651231*^9, 3.579006451023212*^9, 3.579007233916791*^9, 
   3.579023930696919*^9, 3.579195144244574*^9, 3.579216906259956*^9, 
   3.5792825130894747`*^9, 3.579283963679009*^9, {3.579303887407576*^9, 
   3.579303905928524*^9}, 3.5794523848955517`*^9, 3.579456294865025*^9, 
   3.579456349779402*^9, 3.57982088053382*^9, 3.5798240072719316`*^9, 
   3.580008808898921*^9, 3.580439165259691*^9, 3.580596052719626*^9, 
   3.5806429655281773`*^9, 3.580671587357574*^9, 3.58069918998799*^9, 
   3.580845933045457*^9, 3.581172075617673*^9, 3.581190358270054*^9, 
   3.581195613497218*^9, 3.5812689706693687`*^9, 3.581270925098887*^9, 
   3.581276301562886*^9, 3.581291806168305*^9, 3.5812955103366137`*^9, {
   3.581297619884066*^9, 3.581297646781621*^9}, 3.5812982456597977`*^9, 
   3.58129884523463*^9, 3.581346629000722*^9, 3.581363514883255*^9, 
   3.581369182607357*^9, 3.5813695727603703`*^9, 3.581442000621718*^9, 
   3.581450797984355*^9, 3.581757912799136*^9, 3.5819153888488894`*^9, 
   3.5820217376034184`*^9, 3.582483456758857*^9, 3.5840654951843224`*^9, 
   3.584109823438748*^9, 3.58411005504243*^9, 3.58420867894324*^9, 
   3.5842088878072433`*^9, 3.584211087042275*^9, 3.584211263782467*^9, 
   3.584213606190509*^9, 3.584214153152915*^9, 3.584221412532528*^9, 
   3.584224086125415*^9, 3.584279760493761*^9, 3.58431707224433*^9, 
   3.5843622338428993`*^9, 3.584383350521386*^9, 3.584448803924879*^9, 
   3.584453298868166*^9, 3.584453381048203*^9, 3.584453587903215*^9, 
   3.58445382741108*^9, 3.58447956401999*^9, 3.5844851743450823`*^9, 
   3.58470848852697*^9, 3.584720374139813*^9, 3.584725509037991*^9, 
   3.584874693630862*^9, 3.5848747479882927`*^9, 3.584876000441311*^9, 
   3.58487954425815*^9, 3.591549611883752*^9, 3.603755705923913*^9, 
   3.603757446313044*^9, 3.603849869988105*^9, 3.6038501960197163`*^9, 
   3.603853945936942*^9, 3.603925573099287*^9, 3.6041575932345943`*^9, 
   3.604236387710288*^9, 3.605050442133197*^9, 3.605452226214574*^9, 
   3.605453003403495*^9, {3.612794813018045*^9, 3.612794820385364*^9}, 
   3.612794952779544*^9, 3.612798603253881*^9, 3.612798787622415*^9, 
   3.612800457615397*^9, {3.613314124773509*^9, 3.613314145343203*^9}, 
   3.613320289427966*^9, 3.6135783503922367`*^9, 3.61481304489581*^9, 
   3.674606357794578*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"This", " ", "is", " ", 
    RowBox[{"\[Integral]", " ", 
     RowBox[{
      SuperscriptBox["d", "d"], 
      RowBox[{"k", " ", "/", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", "\[Pi]"}], ")"}], 
        RowBox[{"d", " "}]]}], 
      RowBox[{
       SuperscriptBox["k", "\[Alpha]"], "/", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["k", "2"], "+", "mm"}], ")"}], "\[Beta]"]}]}]}]}], 
   " ", "*)"}], 
  RowBox[{
   RowBox[{
    RowBox[{"Intfunc1", "[", 
     RowBox[{"\[Alpha]_", ",", "\[Beta]_", ",", "mm_"}], "]"}], ":=", 
    FractionBox[
     RowBox[{
      SuperscriptBox["2", 
       RowBox[{"-", "d"}]], " ", 
      SuperscriptBox["mm", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"d", "+", "\[Alpha]", "-", 
          RowBox[{"2", " ", "\[Beta]"}]}], ")"}]}]], " ", 
      SuperscriptBox["\[Pi]", 
       RowBox[{
        RowBox[{"-", "d"}], "/", "2"}]], " ", 
      RowBox[{"Gamma", "[", 
       FractionBox[
        RowBox[{"d", "+", "\[Alpha]"}], "2"], "]"}], " ", 
      RowBox[{"Gamma", "[", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["d", "2"]}], "-", 
        FractionBox["\[Alpha]", "2"], "+", "\[Beta]"}], "]"}]}], 
     RowBox[{
      RowBox[{"Gamma", "[", 
       FractionBox["d", "2"], "]"}], " ", 
      RowBox[{"Gamma", "[", "\[Beta]", "]"}]}]]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.575483860879274*^9, 3.5754838949164057`*^9}, {
  3.575484045540969*^9, 3.5754840970366707`*^9}, {3.5754843873860703`*^9, 
  3.575484400969928*^9}, {3.5776599594727707`*^9, 3.577659959844493*^9}, {
  3.577660927022317*^9, 3.5776609300441093`*^9}, {3.577660984423538*^9, 
  3.577660997688994*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Intfuncgen", "[", "integrand_", "]"}], ":=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"PowerExpand", "[", 
       RowBox[{"Series", "[", 
        RowBox[{
         RowBox[{"Collect", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"PowerExpand", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"Expand", "[", 
                  RowBox[{"Apart", "[", 
                   RowBox[{"integrand", ",", "k"}], "]"}], "]"}], "/.", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["k", "\[Alpha]\[Alpha]_"], 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["k", "2"], "+", "x_"}], ")"}], 
                    "\[Beta]\[Beta]_"]}], "\[Rule]", 
                  RowBox[{"Inttemp", "[", 
                   RowBox[{"\[Alpha]\[Alpha]", ",", 
                    RowBox[{"-", "\[Beta]\[Beta]"}], ",", "x"}], "]"}]}]}], "/.", 
                RowBox[{
                 RowBox[{"k", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["k", "2"], "+", "x_"}], ")"}], 
                   "\[Beta]\[Beta]_"]}], "\[Rule]", 
                 RowBox[{"Inttemp", "[", 
                  RowBox[{"1", ",", 
                   RowBox[{"-", "\[Beta]\[Beta]"}], ",", "x"}], "]"}]}]}], "/.", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["k", "2"], "+", "x_"}], ")"}], 
                 "\[Beta]\[Beta]_"], "\[Rule]", 
                RowBox[{"Inttemp", "[", 
                 RowBox[{"0", ",", 
                  RowBox[{"-", "\[Beta]\[Beta]"}], ",", "x"}], "]"}]}]}], "/.", 
              RowBox[{"Inttemp", "\[Rule]", "Intfunc1"}]}], "]"}], "/.", 
            RowBox[{"d", "\[Rule]", 
             RowBox[{"4", "-", "\[Delta]"}]}]}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Log", "[", "x_", "]"}], ",", "qsq", ",", 
             "\[Eta]\[Mu]\[Nu]", ",", "p1\[Mu]", ",", "p2\[Mu]", ",", 
             "p1\[Nu]", ",", "p2\[Nu]"}], "}"}], ",", "Simplify"}], "]"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"\[Delta]", ",", "0", ",", "0"}], "}"}]}], "]"}], "]"}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Log", "[", "x_", "]"}], ",", "qsq", ",", "\[Eta]\[Mu]\[Nu]", 
       ",", "p1\[Mu]", ",", "p2\[Mu]", ",", "p1\[Nu]", ",", "p2\[Nu]"}], 
      "}"}], ",", "Simplify"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.575483929629788*^9, 3.575483973212853*^9}, {
  3.5754840289325237`*^9, 3.575484029679343*^9}, {3.5754841276675253`*^9, 
  3.575484152700367*^9}, {3.5754844722541647`*^9, 3.57548451871596*^9}, {
  3.5754846423030376`*^9, 3.5754847350562983`*^9}, {3.575484901778983*^9, 
  3.575484918355789*^9}, {3.577661217455694*^9, 3.577661228557322*^9}, {
  3.5779310270457983`*^9, 3.577931029206278*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Need: 2-pt integrals B0 and B1 for general m1,m2 and expanded to first order \
around p^2=0\
\>", "Subsection",
 CellChangeTimes->{{3.5740226090101967`*^9, 3.574022667481187*^9}, 
   3.5740235572529907`*^9, {3.57502543741217*^9, 3.575025448218295*^9}, {
   3.612794809783206*^9, 3.612794810981319*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "B0", " ", "expanded", " ", "to", " ", "first", " ", "order", " ", 
     "around", " ", 
     RowBox[{"p", "^", "2"}]}], "=", "0"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"integrandB0temp", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Normal", "[", 
          RowBox[{"Simplify", "[", 
           RowBox[{"Series", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"1", "/", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["k", "2"], "+", "m1"}], ")"}]}], "/", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["k", "2"], "+", 
                RowBox[{"2", "\[Epsilon]", " ", "kdotp"}], "+", 
                RowBox[{
                 SuperscriptBox["\[Epsilon]", "2"], "ww", " ", "psq"}], "+", 
                "m2"}], ")"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"\[Epsilon]", ",", "0", ",", "2"}], "}"}]}], "]"}], 
           "]"}], "]"}], "/.", 
         RowBox[{
          SuperscriptBox["\[Epsilon]", "2"], "\[Rule]", "1"}]}], "/.", 
        RowBox[{"\[Epsilon]", "\[Rule]", "0"}]}], "]"}], "/.", 
      RowBox[{
       SuperscriptBox["kdotp", "2"], "\[Rule]", 
       RowBox[{"ww", " ", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"4", "-", "\[Delta]"}], ")"}]}], 
        SuperscriptBox["k", "2"], "psq"}]}]}], ",", "psq", ",", 
     "FullSimplify"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.574897145698737*^9, 3.574897187536634*^9}, {
   3.5748973919474897`*^9, 3.574897394916353*^9}, {3.57489873915858*^9, 
   3.574898755726925*^9}, {3.5750253028314753`*^9, 3.57502530739159*^9}, 
   3.575025385969935*^9, {3.5750254195706177`*^9, 3.575025475271454*^9}, {
   3.5754706366444883`*^9, 3.575470636946663*^9}, {3.575472807561222*^9, 
   3.575472810594472*^9}, {3.575472881748713*^9, 3.575472882013166*^9}, {
   3.575476938210127*^9, 3.575476944629327*^9}, {3.575477964872813*^9, 
   3.575477967522271*^9}, {3.5776692478457003`*^9, 3.577669248913002*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["k", "2"], "+", "m1"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["k", "2"], "+", "m2"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"psq", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"m2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "4"}], "+", "\[Delta]"}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["k", "2"], " ", "\[Delta]"}]}], ")"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["k", "2"], "+", "m1"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["k", "2"], "+", "m2"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "4"}], "+", "\[Delta]"}], ")"}]}]]}]], "Output",
 CellChangeTimes->{
  3.5748971480726013`*^9, 3.574897188067897*^9, 3.5748973952454357`*^9, 
   3.574903924283656*^9, 3.575024417169873*^9, {3.5750254688715363`*^9, 
   3.575025475564116*^9}, 3.575037147637155*^9, 3.5750393165566797`*^9, 
   3.5750430739543324`*^9, 3.575071448380361*^9, 3.575121680344964*^9, 
   3.575199763377063*^9, 3.575394514018334*^9, 3.575410763854545*^9, 
   3.575413996858362*^9, 3.5754140702989807`*^9, 3.575431612599882*^9, 
   3.575470637560069*^9, 3.575472812441102*^9, 3.5754728825295486`*^9, 
   3.575477245208291*^9, 3.5754773376181726`*^9, 3.5754779682439423`*^9, 
   3.575478033333494*^9, 3.575480870676506*^9, 3.5754847513976507`*^9, {
   3.575485369614955*^9, 3.575485390171187*^9}, 3.5754911888371487`*^9, 
   3.575503795576527*^9, 3.575503961752125*^9, 3.575741183540249*^9, 
   3.575742891945629*^9, 3.575818536420475*^9, 3.57592714433144*^9, 
   3.575928273322296*^9, 3.575930566033886*^9, 3.575931310701819*^9, 
   3.5759328031188917`*^9, 3.575933088470902*^9, 3.575933675562271*^9, 
   3.5759349555196342`*^9, 3.575935240194129*^9, 3.5759358760218687`*^9, 
   3.575938357698848*^9, 3.575938621764667*^9, 3.5759394138212013`*^9, 
   3.575940270172717*^9, 3.575940606045836*^9, 3.575943007367503*^9, 
   3.575944517590722*^9, 3.575945937489574*^9, 3.576007705658545*^9, 
   3.576008619785453*^9, 3.5760150647185173`*^9, 3.576097310687413*^9, 
   3.57609997115548*^9, 3.5761924363405647`*^9, 3.576194999266423*^9, 
   3.576198777211071*^9, 3.5762459926495657`*^9, {3.576251922960137*^9, 
   3.5762519383220043`*^9}, 3.5762533478544064`*^9, 3.576359015341858*^9, 
   3.576363200161202*^9, 3.576364096213388*^9, 3.576364222249543*^9, 
   3.57636430332203*^9, 3.5763644417757683`*^9, 3.57637254371066*^9, 
   3.576429131781621*^9, 3.576536707671377*^9, 3.5765394748086557`*^9, 
   3.576539810474167*^9, 3.576690430240218*^9, 3.5766928968843403`*^9, 
   3.5767121353771353`*^9, 3.576795740885474*^9, 3.5769837367358313`*^9, 
   3.576983816236206*^9, 3.577215457900812*^9, 3.577278670649599*^9, 
   3.57728326421833*^9, 3.577296658250574*^9, 3.5773831229637012`*^9, 
   3.5774012933095284`*^9, 3.577661013637348*^9, 3.577661236968512*^9, 
   3.577662997170597*^9, 3.577669944578038*^9, 3.577675340139019*^9, 
   3.5776763208346033`*^9, 3.577676945651194*^9, 3.577816808350091*^9, 
   3.577834472325987*^9, 3.577915847120616*^9, 3.577928331106043*^9, 
   3.577930793715952*^9, 3.577931053719604*^9, 3.57793451319487*^9, 
   3.5783302931251*^9, 3.5783426090140944`*^9, 3.578344520924871*^9, 
   3.5784941988033123`*^9, 3.5787568172080507`*^9, 3.578849954969954*^9, 
   3.578850468046525*^9, 3.578867482263431*^9, 3.578953603870117*^9, 
   3.5790050380955763`*^9, 3.5790058951892023`*^9, 3.579006056742367*^9, 
   3.579006451127404*^9, 3.5790072339644213`*^9, 3.5790239308208027`*^9, 
   3.57919514443148*^9, 3.579216906450232*^9, 3.579282513242794*^9, 
   3.579283963792451*^9, 3.579298895408025*^9, 3.579299000914176*^9, {
   3.579303887649921*^9, 3.579303906166692*^9}, 3.57945238512932*^9, 
   3.5794563020419073`*^9, 3.57945634986423*^9, 3.579820880827182*^9, 
   3.5798240075336657`*^9, 3.58000880980907*^9, 3.580439165652833*^9, 
   3.580596052881098*^9, 3.580642965672771*^9, 3.5806715876342688`*^9, 
   3.580699190355055*^9, 3.580845933454543*^9, 3.581172075806842*^9, 
   3.58119035861716*^9, 3.5811956136607103`*^9, 3.581268971063052*^9, 
   3.581270925305366*^9, 3.5812763017488813`*^9, 3.5812918063394938`*^9, 
   3.581295510550188*^9, {3.581297620066132*^9, 3.581297646995181*^9}, 
   3.5812982457910213`*^9, 3.581298845411449*^9, 3.581346629509644*^9, 
   3.581363515122386*^9, 3.581369182793726*^9, 3.5813695729446173`*^9, 
   3.581442000865353*^9, 3.581450798393248*^9, 3.58175781064107*^9, 
   3.581757913356634*^9, 3.581915389283721*^9, 3.582021737995367*^9, 
   3.582483457293336*^9, 3.584065495484778*^9, 3.584109823850079*^9, 
   3.584110055446577*^9, 3.58420867935999*^9, 3.584208888207376*^9, 
   3.584211087449856*^9, 3.584211264318192*^9, 3.584213606591154*^9, 
   3.58421415356994*^9, 3.584221412945539*^9, 3.584224086509255*^9, 
   3.584279760731715*^9, 3.5843170726381493`*^9, 3.58436223421378*^9, 
   3.5843833509438868`*^9, 3.584448804231526*^9, 3.584453299107111*^9, 
   3.5844533815592213`*^9, 3.5844535883366003`*^9, 3.584453827780903*^9, 
   3.5844795644148293`*^9, 3.5844851747173147`*^9, 3.5847084887213583`*^9, 
   3.58472037452293*^9, 3.584725509340436*^9, 3.5848746940768013`*^9, 
   3.584874748294691*^9, 3.584876000821691*^9, 3.5848795447088842`*^9, 
   3.591549612281967*^9, 3.6037557063824244`*^9, 3.603757446708041*^9, 
   3.603849870361224*^9, 3.603850196225211*^9, 3.60385394633781*^9, 
   3.603925573442759*^9, 3.604157593541947*^9, 3.604236388280788*^9, 
   3.6050504424098377`*^9, 3.605452226598083*^9, 3.60545300370308*^9, {
   3.612794815200815*^9, 3.6127948206611633`*^9}, 3.612794953101596*^9, 
   3.612798647920527*^9, 3.612798787795219*^9, 3.612800457971463*^9, 
   3.6133202897844048`*^9, 3.613578351585102*^9, 3.613578436449181*^9, 
   3.6746065378270607`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B0temp", "=", 
  RowBox[{
   RowBox[{"b0", " ", 
    RowBox[{"Intfuncgen", "[", "integrandB0temp", "]"}]}], "/.", 
   "subtry"}]}]], "Input",
 CellChangeTimes->{{3.5754808634290257`*^9, 3.575480867725335*^9}, {
   3.575481968745048*^9, 3.575481970120699*^9}, {3.575484534913494*^9, 
   3.575484538673607*^9}, {3.575490855385932*^9, 3.575490856464773*^9}, 
   3.577296603663827*^9, 3.577675298851139*^9}],

Cell[BoxData[
 RowBox[{"16", " ", 
  SuperscriptBox["\[Pi]", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     FractionBox["1", 
      RowBox[{"32", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"m1", "-", "m2"}], ")"}], "2"], " ", 
       SuperscriptBox["\[Pi]", "2"], " ", "\[Delta]"}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["m1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"4", "-", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "EulerGamma"}], ")"}], " ", 
           "\[Delta]"}]}], ")"}]}], "+", 
       RowBox[{"m1", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"psq", " ", "\[Delta]"}], "+", 
          RowBox[{"4", " ", "m2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "EulerGamma"}], ")"}], " ", 
              "\[Delta]"}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"m2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"psq", " ", "\[Delta]"}], "+", 
          RowBox[{"m2", " ", 
           RowBox[{"(", 
            RowBox[{"4", "+", 
             RowBox[{"2", " ", "\[Delta]"}], "-", 
             RowBox[{"2", " ", "EulerGamma", " ", "\[Delta]"}]}], ")"}]}]}], 
         ")"}]}]}], ")"}]}], "+", 
    FractionBox[
     RowBox[{"Log", "[", "2", "]"}], 
     RowBox[{"8", " ", 
      SuperscriptBox["\[Pi]", "2"]}]], "-", 
    FractionBox[
     RowBox[{"m1", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["m1", "2"], "-", 
        RowBox[{"2", " ", "m1", " ", "m2"}], "+", 
        RowBox[{"m2", " ", 
         RowBox[{"(", 
          RowBox[{"m2", "+", "psq"}], ")"}]}]}], ")"}], " ", 
      RowBox[{"Log", "[", "m1", "]"}]}], 
     RowBox[{"16", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m1", "-", "m2"}], ")"}], "3"], " ", 
      SuperscriptBox["\[Pi]", "2"]}]], "+", 
    FractionBox[
     RowBox[{"m2", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["m1", "2"], "+", 
        SuperscriptBox["m2", "2"], "+", 
        RowBox[{"m1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "m2"}], "+", "psq"}], ")"}]}]}], ")"}], 
      " ", 
      RowBox[{"Log", "[", "m2", "]"}]}], 
     RowBox[{"16", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m1", "-", "m2"}], ")"}], "3"], " ", 
      SuperscriptBox["\[Pi]", "2"]}]], "+", 
    FractionBox[
     RowBox[{"Log", "[", "\[Pi]", "]"}], 
     RowBox[{"16", " ", 
      SuperscriptBox["\[Pi]", "2"]}]]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.5754808681400137`*^9, 3.5754808712391777`*^9}, 
   3.5754809224568644`*^9, 3.575481731182124*^9, {3.5754819710565767`*^9, 
   3.575481995025735*^9}, 3.575484539168133*^9, 3.575484758184689*^9, {
   3.575485369772649*^9, 3.575485390229281*^9}, 3.575490856748584*^9, 
   3.575491028254929*^9, 3.5754911888818274`*^9, 3.5755037956961813`*^9, 
   3.5755039618702106`*^9, 3.575741183686819*^9, 3.5757428920788593`*^9, 
   3.575818536567547*^9, 3.575927144477356*^9, 3.5759282734536552`*^9, 
   3.575930566163409*^9, 3.5759313108517647`*^9, 3.575932803249076*^9, 
   3.5759330886011457`*^9, 3.5759336756930027`*^9, 3.575934955667036*^9, 
   3.575935240335877*^9, 3.575935876150666*^9, 3.5759383578472347`*^9, 
   3.5759386219681664`*^9, 3.575939414021455*^9, 3.5759402703037243`*^9, 
   3.575940606175745*^9, 3.575943007497736*^9, 3.575944517720262*^9, 
   3.575945937619451*^9, 3.576007705791368*^9, 3.5760086199362507`*^9, 
   3.5760150648506603`*^9, 3.5760973108342733`*^9, 3.5760999712868834`*^9, 
   3.576192436492364*^9, 3.576194999395742*^9, 3.5761987773407373`*^9, 
   3.57624599279951*^9, {3.5762519230879507`*^9, 3.576251938441455*^9}, 
   3.5762533479929743`*^9, 3.576359015491336*^9, 3.5763632002915163`*^9, 
   3.576364096361382*^9, 3.5763642223864727`*^9, 3.576364303461186*^9, 
   3.576364441907151*^9, 3.576372543842272*^9, 3.576429131911203*^9, 
   3.576536707814953*^9, 3.5765394749387608`*^9, 3.576539810603663*^9, 
   3.576690430389133*^9, 3.576692897013714*^9, 3.576712135508935*^9, 
   3.576795741945097*^9, 3.576983737083455*^9, 3.576983816350696*^9, 
   3.5772154580610037`*^9, 3.577278671564959*^9, 3.577283264418109*^9, 
   3.577296658373117*^9, 3.57738312355575*^9, 3.577401293964767*^9, 
   3.577661017458295*^9, 3.577661240406261*^9, 3.577662998651285*^9, 
   3.5776699492839203`*^9, 3.577675342657958*^9, 3.5776763243144693`*^9, 
   3.577676948101758*^9, 3.577816811159068*^9, 3.5778344748835497`*^9, 
   3.577915849498146*^9, 3.5779283335849752`*^9, 3.5779307960820417`*^9, 
   3.57793105453371*^9, 3.57793451422453*^9, 3.578330294100424*^9, 
   3.57834260982546*^9, 3.578344521712263*^9, 3.578494199671928*^9, 
   3.5787568181077213`*^9, 3.5788499558115063`*^9, 3.578850468940434*^9, 
   3.578867483029654*^9, 3.5789536048169403`*^9, 3.5790050388960238`*^9, 
   3.579005895977563*^9, 3.579006057522883*^9, 3.5790064513761597`*^9, 
   3.579007234134161*^9, 3.579023931619417*^9, 3.579195145232931*^9, 
   3.579216907249083*^9, 3.579282513998473*^9, 3.57928396454932*^9, 
   3.5792988971034517`*^9, 3.579299001506206*^9, {3.579303888420102*^9, 
   3.579303906524852*^9}, 3.57945238586211*^9, 3.579456303516036*^9, 
   3.5794563501516733`*^9, 3.579820881563553*^9, 3.5798240082632313`*^9, 
   3.580008810620768*^9, 3.5804391663768787`*^9, 3.580596053823814*^9, 
   3.580642966466124*^9, 3.58067158838234*^9, 3.580699191108687*^9, 
   3.580845934193252*^9, 3.5811720766404867`*^9, 3.5811903594973497`*^9, 
   3.581195614398109*^9, 3.581268971855411*^9, 3.5812709262358637`*^9, 
   3.581276302739407*^9, 3.581291807081503*^9, 3.5812955112921743`*^9, {
   3.5812976207925653`*^9, 3.581297647760627*^9}, 3.581298246515087*^9, 
   3.581298846131531*^9, 3.5813466304812393`*^9, 3.5813635159941607`*^9, 
   3.581369183734392*^9, 3.581369573935794*^9, 3.5814420017146807`*^9, 
   3.581450799534264*^9, 3.5817579143809357`*^9, 3.5819153904795437`*^9, 
   3.582021738953269*^9, 3.582483458491539*^9, 3.5840654964598627`*^9, 
   3.584109824944767*^9, 3.584110056400456*^9, 3.584208680236071*^9, 
   3.58420888907758*^9, 3.5842110883236103`*^9, 3.584211265204771*^9, 
   3.584213607465844*^9, 3.5842141544514027`*^9, 3.584221413837241*^9, 
   3.5842240873976097`*^9, 3.584279761735215*^9, 3.5843170735695953`*^9, 
   3.584362235139389*^9, 3.5843833518724003`*^9, 3.584448805152999*^9, 
   3.584453300065021*^9, 3.584453382529854*^9, 3.5844535892198353`*^9, 
   3.584453828670388*^9, 3.584479565630888*^9, 3.584485175611916*^9, 
   3.58470848972082*^9, 3.584720375456375*^9, 3.584725510247533*^9, 
   3.5848746950120583`*^9, 3.584874749173751*^9, 3.584876001701374*^9, 
   3.584879545594458*^9, 3.591549613320744*^9, 3.6037557074553213`*^9, 
   3.6037574479000063`*^9, 3.603849871317791*^9, 3.6038501972078447`*^9, 
   3.603853947382169*^9, 3.603925574686903*^9, 3.604157594483265*^9, 
   3.6042363894767447`*^9, 3.605050443321663*^9, 3.6054522275105333`*^9, 
   3.605453004609997*^9, {3.612794817804097*^9, 3.6127948207072277`*^9}, 
   3.612794953169732*^9, 3.612798649933321*^9, 3.612798788984335*^9, 
   3.6128004589620047`*^9, 3.6133202909093*^9, 3.6135783539650784`*^9, 
   3.6135784365030813`*^9, 3.674606539044108*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "B1", " ", "expanded", " ", "to", " ", "first", " ", "order", " ", 
     "around", " ", 
     RowBox[{"p", "^", "2"}]}], "=", "0"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"integrandB1temp", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Expand", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Normal", "[", 
            RowBox[{"Simplify", "[", 
             RowBox[{"Series", "[", 
              RowBox[{
               RowBox[{"\[Epsilon]", " ", 
                RowBox[{
                 RowBox[{"k\[Mu]", "/", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["k", "2"], "+", "m1"}], ")"}]}], "/", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["k", "2"], "+", 
                   RowBox[{"2", "\[Epsilon]", " ", "kdotp"}], "+", 
                   RowBox[{
                    SuperscriptBox["\[Epsilon]", "2"], "ww", " ", "psq"}], 
                   "+", "m2"}], ")"}]}]}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Epsilon]", ",", "0", ",", "4"}], "}"}]}], "]"}], 
             "]"}], "]"}], "/.", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "4"], "\[Rule]", "1"}]}], "/.", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], "\[Rule]", "1"}]}], "/.", 
         RowBox[{"\[Epsilon]", "\[Rule]", "0"}]}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"kdotp", " ", "k\[Mu]"}], "\[Rule]", 
          RowBox[{
           RowBox[{"1", "/", "d"}], " ", 
           SuperscriptBox["k", "2"], "p\[Mu]"}]}], ",", 
         RowBox[{
          RowBox[{
           SuperscriptBox["kdotp", "3"], " ", "k\[Mu]"}], " ", "\[Rule]", 
          RowBox[{"ww", " ", 
           RowBox[{"3", "/", 
            RowBox[{"(", 
             RowBox[{"d", 
              RowBox[{"(", 
               RowBox[{"d", "+", "2"}], ")"}]}], ")"}]}], 
           SuperscriptBox["k", "4"], "psq", " ", "p\[Mu]"}]}]}], "}"}]}], "/.", 
      RowBox[{"d", "\[Rule]", 
       RowBox[{"4", "-", "\[Delta]"}]}]}], ",", "psq", ",", "FullSimplify"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.575025500320006*^9, 3.575025543620569*^9}, {
  3.575025576572165*^9, 3.575025638525362*^9}, {3.5750256807403316`*^9, 
  3.575025698648065*^9}, {3.575476974978651*^9, 3.575476986762218*^9}, {
  3.575477034686808*^9, 3.575477039334394*^9}, {3.575477128735261*^9, 
  3.575477131375552*^9}, {3.575477234276248*^9, 3.5754772343407793`*^9}, {
  3.5754779422269497`*^9, 3.5754779488187857`*^9}, {3.57547800318672*^9, 
  3.5754780068982143`*^9}, {3.577379162148179*^9, 3.577379162780962*^9}, {
  3.577669736076992*^9, 3.5776697367224092`*^9}, {3.5776699176308537`*^9, 
  3.57766992817467*^9}, {3.577676285357152*^9, 3.577676285827388*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["k", "2"], " ", "p\[Mu]"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["k", "2"], "+", "m1"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["k", "2"], "+", "m2"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "4"}], "+", "\[Delta]"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"4", " ", 
    SuperscriptBox["k", "2"], " ", "psq", " ", "p\[Mu]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"m2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "6"}], "+", "\[Delta]"}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["k", "2"], " ", "\[Delta]"}]}], ")"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["k", "2"], "+", "m1"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["k", "2"], "+", "m2"}], ")"}], "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "6"}], "+", "\[Delta]"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "4"}], "+", "\[Delta]"}], ")"}]}]]}]], "Output",
 CellChangeTimes->{
  3.575025543963251*^9, {3.5750255771351852`*^9, 3.575025603192131*^9}, 
   3.5750256990448103`*^9, 3.575037159045957*^9, 3.5750393251379843`*^9, 
   3.575043085539357*^9, 3.575071460067535*^9, 3.5751216916812696`*^9, 
   3.5751997742293587`*^9, 3.575410774465536*^9, 3.575414007569174*^9, 
   3.5754140809274817`*^9, 3.575431623470738*^9, 3.575476998152134*^9, 
   3.575477049452777*^9, {3.5754771290641193`*^9, 3.5754771315594378`*^9}, 
   3.5754772526975327`*^9, 3.575477348620954*^9, 3.575478007327166*^9, 
   3.575478044159663*^9, 3.5754819958585577`*^9, 3.5754847604355392`*^9, {
   3.575485369825796*^9, 3.575485390270904*^9}, 3.575490857672619*^9, 
   3.575491029478403*^9, 3.575491188909198*^9, 3.575503795742791*^9, 
   3.575503961916787*^9, 3.575741183738614*^9, 3.575742892133062*^9, 
   3.575818536618863*^9, 3.5759271445291023`*^9, 3.575928273504549*^9, 
   3.5759305662142487`*^9, 3.575931310912696*^9, 3.575932803300067*^9, 
   3.5759330887174253`*^9, 3.575933675744331*^9, 3.5759349557274*^9, 
   3.575935240393528*^9, 3.5759358762011642`*^9, 3.575938357904718*^9, 
   3.575938622019094*^9, 3.57593941407197*^9, 3.575940270353303*^9, 
   3.575940606228457*^9, 3.575943007548552*^9, 3.575944517771682*^9, 
   3.575945937670473*^9, 3.576007705845668*^9, 3.5760086200610027`*^9, 
   3.576015064901465*^9, 3.576097310886014*^9, 3.57609997133689*^9, 
   3.576192436603448*^9, 3.576194999446961*^9, 3.576198777390375*^9, 
   3.576245992851748*^9, {3.576251923137641*^9, 3.5762519384929943`*^9}, 
   3.576253348048314*^9, 3.576359015541642*^9, 3.576363200346848*^9, 
   3.5763640964203997`*^9, 3.576364222442628*^9, 3.57636430351901*^9, 
   3.5763644419588223`*^9, 3.5763725438931026`*^9, 3.576429131961306*^9, 
   3.576536707867393*^9, 3.5765394749895353`*^9, 3.576539810653819*^9, 
   3.576690430441633*^9, 3.576692897063964*^9, 3.576712135560163*^9, 
   3.576795742102047*^9, 3.57698373721441*^9, 3.576983816398879*^9, 
   3.577215458120162*^9, 3.577278671808963*^9, 3.577283264477585*^9, 
   3.577296658419301*^9, 3.577379163255774*^9, 3.577383123754422*^9, 
   3.57740129416148*^9, 3.57766125927941*^9, 3.577662998891724*^9, 
   3.577669928871092*^9, 3.5776753429076853`*^9, 3.577676326464102*^9, 
   3.5776769483210373`*^9, 3.577816811307097*^9, 3.577834475168556*^9, 
   3.5779158497982283`*^9, 3.5779283338434134`*^9, 3.577930796305224*^9, 
   3.577931054883415*^9, 3.577934514475995*^9, 3.578330294211041*^9, 
   3.578342610024601*^9, 3.57834452201344*^9, 3.578494199962214*^9, 
   3.578756818240036*^9, 3.5788499560190077`*^9, 3.578850469063386*^9, 
   3.57886748310608*^9, 3.578953605017568*^9, 3.579005039074963*^9, 
   3.579005896129548*^9, 3.5790060577014513`*^9, 3.579006451448567*^9, 
   3.579007234152692*^9, 3.5790239318008623`*^9, 3.5791951454213667`*^9, 
   3.579216907472144*^9, 3.579282514193433*^9, 3.5792839647140083`*^9, 
   3.579298901943714*^9, 3.579299002146305*^9, {3.5793038886214333`*^9, 
   3.579303906566909*^9}, 3.579452386298285*^9, 3.579456303736022*^9, 
   3.579456350190114*^9, 3.579820881767232*^9, 3.579824008496764*^9, 
   3.5800088108648577`*^9, 3.580439166508716*^9, 3.580596053906897*^9, 
   3.5806429666235027`*^9, 3.580671588555583*^9, 3.5806991913776817`*^9, 
   3.580845934493079*^9, 3.581172076826466*^9, 3.581190359816094*^9, 
   3.5811956146823606`*^9, 3.5812689720563507`*^9, 3.5812709263752127`*^9, 
   3.581276302815827*^9, 3.581291807269143*^9, 3.581295511364944*^9, {
   3.5812976209285707`*^9, 3.5812976479335203`*^9}, 3.581298246668334*^9, 
   3.581298846293037*^9, 3.581346630649757*^9, 3.581363516169319*^9, 
   3.5813691839162827`*^9, 3.581369574150185*^9, 3.58144200185637*^9, 
   3.581450799714048*^9, 3.581757914651925*^9, 3.581915390645562*^9, 
   3.582021739138659*^9, 3.582483458676896*^9, 3.584065496539905*^9, 
   3.5841098250982847`*^9, 3.584110056488325*^9, 3.5842086803501663`*^9, 
   3.584208889197073*^9, 3.584211088461524*^9, 3.584211265355968*^9, 
   3.5842136076073227`*^9, 3.5842141546007147`*^9, 3.584221414007959*^9, 
   3.584224087545247*^9, 3.584279761819942*^9, 3.5843170736920137`*^9, 
   3.584362235290751*^9, 3.5843833519892483`*^9, 3.584448805298078*^9, 
   3.584453300465282*^9, 3.584453382912532*^9, 3.584453589366346*^9, 
   3.5844538288137207`*^9, 3.58447956577803*^9, 3.5844851757513657`*^9, 
   3.584708489805616*^9, 3.58472037557771*^9, 3.58472551039981*^9, 
   3.5848746951418324`*^9, 3.584874749307119*^9, 3.58487600181743*^9, 
   3.5848795457362022`*^9, 3.591549613465872*^9, 3.6037557076252193`*^9, 
   3.603757448220387*^9, 3.603849871509256*^9, 3.603850197430315*^9, 
   3.6038539475703087`*^9, 3.603925574881588*^9, 3.604157594702343*^9, 
   3.604236389690922*^9, 3.605050443496254*^9, 3.605452227648991*^9, 
   3.6054530047336187`*^9, {3.612794818082922*^9, 3.612794820755693*^9}, 
   3.6127949532514553`*^9, 3.612798652658942*^9, 3.6127987892889137`*^9, 
   3.6128004591967983`*^9, 3.6133202911827517`*^9, 3.613578354146324*^9, 
   3.613578436540145*^9, 3.674606539385697*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B1temp", "=", 
  RowBox[{
   RowBox[{"b1", " ", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Intfuncgen", "[", "integrandB1temp", "]"}], ",", "p\[Mu]"}], 
     "]"}]}], "/.", "subtry"}]}]], "Input",
 CellChangeTimes->{{3.575481997438965*^9, 3.575482008880863*^9}, {
   3.575482088808155*^9, 3.575482092007248*^9}, {3.575484546161133*^9, 
   3.5754845536794558`*^9}, 3.577296599280238*^9, 3.577675304155553*^9}],

Cell[BoxData[
 RowBox[{"16", " ", 
  SuperscriptBox["\[Pi]", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     FractionBox["1", 
      RowBox[{"192", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"m1", "-", "m2"}], ")"}], "3"], " ", 
       SuperscriptBox["\[Pi]", "2"], " ", "\[Delta]"}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["m1", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "4"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             RowBox[{"2", " ", "EulerGamma"}]}], ")"}], " ", "\[Delta]"}]}], 
         ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["m1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", "psq", " ", "\[Delta]"}], "+", 
          RowBox[{"m2", " ", 
           RowBox[{"(", 
            RowBox[{"36", "+", 
             RowBox[{"21", " ", "\[Delta]"}], "-", 
             RowBox[{"18", " ", "EulerGamma", " ", "\[Delta]"}]}], ")"}]}]}], 
         ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["m2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "psq", " ", "\[Delta]"}], "+", 
          RowBox[{"3", " ", "m2", " ", 
           RowBox[{"(", 
            RowBox[{"4", "+", "\[Delta]", "-", 
             RowBox[{"2", " ", "EulerGamma", " ", "\[Delta]"}]}], ")"}]}]}], 
         ")"}]}], "+", 
       RowBox[{"m1", " ", "m2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "10"}], " ", "psq", " ", "\[Delta]"}], "+", 
          RowBox[{"3", " ", "m2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "12"}], "-", 
             RowBox[{"5", " ", "\[Delta]"}], "+", 
             RowBox[{"6", " ", "EulerGamma", " ", "\[Delta]"}]}], ")"}]}]}], 
         ")"}]}]}], ")"}]}], "-", 
    FractionBox[
     RowBox[{"Log", "[", "2", "]"}], 
     RowBox[{"16", " ", 
      SuperscriptBox["\[Pi]", "2"]}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["m1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["m1", "2"], "-", 
        RowBox[{"2", " ", "m1", " ", "m2"}], "+", 
        RowBox[{"m2", " ", 
         RowBox[{"(", 
          RowBox[{"m2", "+", 
           RowBox[{"2", " ", "psq"}]}], ")"}]}]}], ")"}], " ", 
      RowBox[{"Log", "[", "m1", "]"}]}], 
     RowBox[{"32", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m1", "-", "m2"}], ")"}], "4"], " ", 
      SuperscriptBox["\[Pi]", "2"]}]], "+", 
    FractionBox[
     RowBox[{"m2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["m1", "3"]}], "-", 
        RowBox[{"4", " ", "m1", " ", 
         SuperscriptBox["m2", "2"]}], "+", 
        SuperscriptBox["m2", "3"], "+", 
        RowBox[{
         SuperscriptBox["m1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"5", " ", "m2"}], "-", 
           RowBox[{"2", " ", "psq"}]}], ")"}]}]}], ")"}], " ", 
      RowBox[{"Log", "[", "m2", "]"}]}], 
     RowBox[{"32", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m1", "-", "m2"}], ")"}], "4"], " ", 
      SuperscriptBox["\[Pi]", "2"]}]], "-", 
    FractionBox[
     RowBox[{"Log", "[", "\[Pi]", "]"}], 
     RowBox[{"32", " ", 
      SuperscriptBox["\[Pi]", "2"]}]]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.575484554376258*^9, 3.575484761350093*^9, {3.575485369967785*^9, 
   3.575485390366139*^9}, 3.575491033174017*^9, 3.575491188995398*^9, 
   3.57550379588421*^9, 3.5755039620583067`*^9, 3.575741183933632*^9, 
   3.5757428923283*^9, 3.575818536809085*^9, 3.575927144723024*^9, 
   3.575928273695162*^9, 3.575930566402096*^9, 3.5759313111273603`*^9, 
   3.575932803489469*^9, 3.575933088906666*^9, 3.5759336759320107`*^9, 
   3.575934955938051*^9, 3.575935240604005*^9, 3.57593587639072*^9, 
   3.57593835811589*^9, 3.575938622209331*^9, 3.5759394142649193`*^9, 
   3.5759402705408773`*^9, 3.575940606416358*^9, 3.575943007737093*^9, 
   3.57594451795897*^9, 3.575945937858364*^9, 3.576007706042568*^9, 
   3.576008620261612*^9, 3.576015065093461*^9, 3.576097311075554*^9, 
   3.5760999715252666`*^9, 3.5761924367933292`*^9, 3.576194999633471*^9, 
   3.576198777577023*^9, 3.576245993044931*^9, {3.576251923326189*^9, 
   3.576251938679184*^9}, 3.576253348255924*^9, 3.576359015732218*^9, 
   3.576363200552608*^9, 3.576364096636528*^9, 3.576364222652931*^9, 
   3.576364303730906*^9, 3.5763644421498528`*^9, 3.576372544083868*^9, 
   3.576429132148416*^9, 3.576536708058949*^9, 3.576539475179587*^9, 
   3.576539810842581*^9, 3.576690430637081*^9, 3.5766928972525787`*^9, 
   3.576712135750451*^9, 3.5767957422399673`*^9, 3.5769837375225677`*^9, 
   3.5769838165381937`*^9, 3.5772154582570467`*^9, 3.5772786719455967`*^9, 
   3.577283264628951*^9, 3.577296658586594*^9, 3.577379166638294*^9, 
   3.577383124038525*^9, 3.577401294426441*^9, 3.5776612652664824`*^9, 
   3.577663001440487*^9, 3.577669940529717*^9, 3.577675346782977*^9, 
   3.577676333222208*^9, 3.577676951442605*^9, 3.5778168149467373`*^9, 
   3.577834478280175*^9, 3.577915852873177*^9, 3.577928336887247*^9, 
   3.577930799511572*^9, 3.577931055925191*^9, 3.577934515544627*^9, 
   3.578330295310927*^9, 3.5783426110772333`*^9, 3.5783445230866137`*^9, 
   3.578494200959385*^9, 3.578756819422586*^9, 3.578849957043049*^9, 
   3.57885047025478*^9, 3.57886748412964*^9, 3.578953606311413*^9, 
   3.579005040121973*^9, 3.579005897111558*^9, 3.579006058709331*^9, 
   3.5790064520907516`*^9, 3.5790072343650093`*^9, 3.5790239327841578`*^9, 
   3.579195146424066*^9, 3.579216908480912*^9, 3.5792825152260113`*^9, 
   3.579283965676848*^9, 3.5792989045808773`*^9, 3.579299004174643*^9, {
   3.5793038894346848`*^9, 3.579303907581292*^9}, 3.579452387291152*^9, 
   3.579456306820874*^9, 3.579456351031074*^9, 3.579820882752078*^9, 
   3.5798240094721518`*^9, 3.580008811830606*^9, 3.580439167415325*^9, 
   3.580596055036178*^9, 3.580642967571175*^9, 3.580671589487185*^9, 
   3.580699192424582*^9, 3.580845935455229*^9, 3.581172078053103*^9, 
   3.581190360927799*^9, 3.581195615626981*^9, 3.581268973053722*^9, 
   3.581270927400344*^9, 3.581276303844061*^9, 3.5812918082904863`*^9, 
   3.5812955124227657`*^9, {3.581297621911838*^9, 3.58129764886525*^9}, 
   3.58129824765764*^9, 3.581298847294814*^9, 3.581346631847926*^9, 
   3.581363517350533*^9, 3.5813691851870823`*^9, 3.581369575421073*^9, 
   3.5814420029795237`*^9, 3.581450800989945*^9, 3.581757915926536*^9, 
   3.5819153921212683`*^9, 3.582021740352882*^9, 3.582483459950286*^9, 
   3.584065497766983*^9, 3.584109826382741*^9, 3.584110057757106*^9, 
   3.584208681540574*^9, 3.584208890369155*^9, 3.584211089646234*^9, 
   3.584211266547009*^9, 3.584213608776062*^9, 3.58421415578526*^9, 
   3.584221415183177*^9, 3.584224088743505*^9, 3.58427976311554*^9, 
   3.5843170749013367`*^9, 3.584362236495202*^9, 3.584383353179006*^9, 
   3.5844488064951878`*^9, 3.584453301738124*^9, 3.5844533842143087`*^9, 
   3.584453590543954*^9, 3.5844538300099773`*^9, 3.5844795670079403`*^9, 
   3.5844851769452677`*^9, 3.584708491090905*^9, 3.584720376775831*^9, 
   3.584725511606925*^9, 3.584874696355105*^9, 3.584874750481352*^9, 
   3.584876002991663*^9, 3.5848795469110518`*^9, 3.5915496147532177`*^9, 
   3.603755709015025*^9, 3.6037574495268717`*^9, 3.603849872712492*^9, 
   3.603850198717548*^9, 3.6038539488791733`*^9, 3.603925576285527*^9, 
   3.604157595948022*^9, 3.604236391089527*^9, 3.6050504447318163`*^9, 
   3.605452228879327*^9, 3.605453005965335*^9, 3.61279482209026*^9, 
   3.6127949541605673`*^9, 3.612798655212516*^9, 3.6127987908733053`*^9, 
   3.612800460509871*^9, 3.613320292506565*^9, 3.6135783558757*^9, 
   3.6135784366084347`*^9, 3.674606540586397*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"DefineIntegralFunction2", "[", 
  RowBox[{"B0func", ",", "B0temp"}], "]"}]], "Input",
 CellChangeTimes->{{3.575025822681981*^9, 3.575025824761858*^9}}],

Cell[BoxData[
 RowBox[{"DefineIntegralFunction2", "[", 
  RowBox[{"B1func", ",", "B1temp"}], "]"}]], "Input",
 CellChangeTimes->{{3.575025810829546*^9, 3.575025818977489*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B1func", "[", 
  RowBox[{"0", ",", "x", ",", "x"}], "]"}]], "Input",
 CellChangeTimes->{{3.613578359942388*^9, 3.613578411606007*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["EulerGamma", "2"], "-", 
  FractionBox["1", "\[Delta]"], "-", 
  RowBox[{"Log", "[", "2", "]"}], "-", 
  FractionBox[
   RowBox[{"Log", "[", "\[Pi]", "]"}], "2"], "+", 
  FractionBox[
   RowBox[{"Log", "[", "x", "]"}], "2"]}]], "Output",
 CellChangeTimes->{{3.613578363428619*^9, 3.6135784366683817`*^9}, 
   3.6746065420592127`*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"B0func0", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{"1", "-", "EulerGamma", "+", 
    FractionBox["2", "\[Delta]"], "+", 
    RowBox[{"Log", "[", 
     RowBox[{"4", " ", "\[Pi]"}], "]"}], "+", 
    FractionBox[
     RowBox[{"x", " ", 
      RowBox[{"Log", "[", "x", "]"}]}], 
     RowBox[{
      RowBox[{"-", "x"}], "+", "y"}]], "+", 
    FractionBox[
     RowBox[{"y", " ", 
      RowBox[{"Log", "[", "y", "]"}]}], 
     RowBox[{"x", "-", "y"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"B0func0", "[", 
    RowBox[{"x_", ",", "x_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"-", "EulerGamma"}], "+", 
    FractionBox["2", "\[Delta]"], "+", 
    RowBox[{"Log", "[", "4", "]"}], "+", 
    RowBox[{"Log", "[", "\[Pi]", "]"}], "-", 
    RowBox[{"Log", "[", "x", "]"}]}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"B0func1", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{
    FractionBox[
     RowBox[{"x", "+", "y"}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", "-", "y"}], ")"}], "2"]}]], "-", 
    FractionBox[
     RowBox[{"x", " ", "y", " ", 
      RowBox[{"Log", "[", "x", "]"}]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "-", "y"}], ")"}], "3"]], "+", 
    FractionBox[
     RowBox[{"x", " ", "y", " ", 
      RowBox[{"Log", "[", "y", "]"}]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "-", "y"}], ")"}], "3"]]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"B0func1", "[", 
     RowBox[{"x_", ",", "x_"}], "]"}], ":=", 
    FractionBox["1", 
     RowBox[{"6", " ", "x"}]]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"B1func0", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     FractionBox["1", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", "EulerGamma"}], "+", 
       FractionBox[
        RowBox[{"2", " ", "x"}], 
        RowBox[{
         RowBox[{"-", "x"}], "+", "y"}]], "-", 
       FractionBox["4", "\[Delta]"]}], ")"}]}], "-", 
    FractionBox[
     RowBox[{"x", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["y", "2"]}]}], ")"}], " ", 
      RowBox[{"Log", "[", "2", "]"}]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "-", "y"}], ")"}], "3"]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["y", "3"], " ", 
      RowBox[{"Log", "[", "16", "]"}]}], 
     RowBox[{"4", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", "-", "y"}], ")"}], "3"]}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "2"], " ", "y", " ", 
      RowBox[{"Log", "[", "4096", "]"}]}], 
     RowBox[{"4", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", "-", "y"}], ")"}], "3"]}]], "-", 
    FractionBox[
     RowBox[{"Log", "[", "\[Pi]", "]"}], "2"], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "2"], " ", 
      RowBox[{"Log", "[", "x", "]"}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", "-", "y"}], ")"}], "2"]}]], "+", 
    FractionBox[
     RowBox[{"y", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "x"}], "+", "y"}], ")"}], " ", 
      RowBox[{"Log", "[", "y", "]"}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", "-", "y"}], ")"}], "2"]}]]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"B1func0", "[", 
     RowBox[{"x_", ",", "x_"}], "]"}], ":=", 
    RowBox[{
     FractionBox["EulerGamma", "2"], "-", 
     FractionBox["1", "\[Delta]"], "-", 
     RowBox[{"Log", "[", "2", "]"}], "-", 
     FractionBox[
      RowBox[{"Log", "[", "\[Pi]", "]"}], "2"], "+", 
     FractionBox[
      RowBox[{"Log", "[", "x", "]"}], "2"]}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"B1func1", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{"5", " ", "x", " ", "y"}], "+", 
      SuperscriptBox["y", "2"]}], 
     RowBox[{"6", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", "-", "y"}], ")"}], "3"]}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "2"], " ", "y", " ", 
      RowBox[{"Log", "[", "x", "]"}]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "-", "y"}], ")"}], "4"]], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "2"], " ", "y", " ", 
      RowBox[{"Log", "[", "y", "]"}]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "-", "y"}], ")"}], "4"]]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"B1func1", "[", 
     RowBox[{"x_", ",", "x_"}], "]"}], ":=", 
    RowBox[{"-", 
     FractionBox["1", 
      RowBox[{"12", " ", "x"}]]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.6132663605917873`*^9, 3.613266421984432*^9}, {
  3.6132664647997828`*^9, 3.613266538931871*^9}, {3.6133023043941593`*^9, 
  3.6133023074894*^9}, {3.613302388137073*^9, 3.6133024006149797`*^9}, {
  3.6133024424673862`*^9, 3.6133025098282843`*^9}, {3.613302804867923*^9, 
  3.6133028859661503`*^9}, {3.613578367666663*^9, 3.613578376610368*^9}, {
  3.6135784096902237`*^9, 3.613578417958172*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Need 3-pt integrals C0, C1, C2, C00 for p1^2 = p2^2 = 0 and general m1, m2, \
m3 and expanded to linear order around p1dotp2=0\
\>", "Subsection",
 CellChangeTimes->{{3.574023579872418*^9, 3.574023598464611*^9}, 
   3.574184334934391*^9, {3.574882525191081*^9, 3.574882540855279*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"C0", " ", "with", " ", 
     SuperscriptBox["p1", "2"]}], "=", 
    RowBox[{
     SuperscriptBox["p2", "2"], "=", 
     RowBox[{
      RowBox[{
      "0", " ", "and", " ", "expanded", " ", "to", " ", "first", " ", "order",
        " ", "around", " ", "p1dotp2"}], "=", "0"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"integrandC0temp", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Normal", "[", 
             RowBox[{"Simplify", "[", 
              RowBox[{"Series", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"1", "/", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["k", "2"], "+", "m1"}], ")"}]}], "/", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["k", "2"], "+", 
                    RowBox[{"2", "\[Epsilon]", " ", "kdotp1"}], "+", "m2"}], 
                   ")"}]}], "/", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["k", "2"], "+", 
                   RowBox[{"2", "\[Epsilon]", " ", "kdotp2"}], "+", "m3"}], 
                  ")"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"\[Epsilon]", ",", "0", ",", "2"}], "}"}]}], "]"}], 
              "]"}], "]"}], "/.", 
            RowBox[{
             SuperscriptBox["\[Epsilon]", "2"], "\[Rule]", "1"}]}], "/.", 
           RowBox[{"\[Epsilon]", "\[Rule]", "0"}]}], "/.", 
          RowBox[{
           SuperscriptBox["kdotp1", "2"], "\[Rule]", "0"}]}], "/.", 
         RowBox[{
          SuperscriptBox["kdotp2", "2"], "\[Rule]", "0"}]}], "/.", 
        RowBox[{
         RowBox[{"kdotp1", " ", "kdotp2"}], "\[Rule]", 
         RowBox[{
          RowBox[{"1", "/", "d"}], " ", 
          SuperscriptBox["k", "2"], "p1dotp2"}]}]}], "/.", 
       RowBox[{"d", "\[Rule]", 
        RowBox[{"4", "-", "\[Delta]"}]}]}], "/.", 
      RowBox[{"p1dotp2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "qsq"}], "/", "2"}]}]}], ",", "qsq", ",", 
     "FullSimplify"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.574897145698737*^9, 3.574897187536634*^9}, {
  3.5748973919474897`*^9, 3.574897394916353*^9}, {3.57489873915858*^9, 
  3.574898755726925*^9}, {3.5776699624455433`*^9, 3.5776699712051086`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["k", "2"], "+", "m1"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["k", "2"], "+", "m2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["k", "2"], "+", "m3"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["k", "2"], " ", "qsq"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["k", "2"], "+", "m1"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["k", "2"], "+", "m2"}], ")"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["k", "2"], "+", "m3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "4"}], "+", "\[Delta]"}], ")"}]}]]}]], "Output",
 CellChangeTimes->{
  3.5748971480726013`*^9, 3.574897188067897*^9, 3.5748973952454357`*^9, 
   3.574903924283656*^9, 3.575024417169873*^9, 3.575037168602854*^9, 
   3.575039334929381*^9, 3.575043095154052*^9, 3.5750714697154293`*^9, 
   3.5751217012262917`*^9, 3.575199783544715*^9, 3.575410783696611*^9, 
   3.575414016754126*^9, 3.575414090162072*^9, 3.575431632601409*^9, 
   3.575477359278277*^9, 3.575478058302403*^9, 3.5754821043845863`*^9, 
   3.575484766095099*^9, {3.575485370070292*^9, 3.575485390569195*^9}, 
   3.575491189117011*^9, 3.575503795982009*^9, 3.575503962205645*^9, 
   3.5757411840977697`*^9, 3.575742892575355*^9, 3.5758185369649343`*^9, 
   3.575927144930654*^9, 3.575928273837411*^9, 3.575930566567824*^9, 
   3.575931311395584*^9, 3.575932803636202*^9, 3.575933089060338*^9, 
   3.575933676094315*^9, 3.575934956181621*^9, 3.575935240772909*^9, 
   3.575935876564817*^9, 3.575938358295298*^9, 3.575938622362239*^9, 
   3.575939414425799*^9, 3.5759402706837587`*^9, 3.575940606588168*^9, 
   3.575943007891754*^9, 3.575944518071342*^9, 3.575945938071208*^9, 
   3.576007706241067*^9, 3.576008620469935*^9, 3.5760150652336607`*^9, 
   3.576097311299911*^9, 3.576099972140047*^9, 3.576192436945587*^9, 
   3.576194999846745*^9, 3.57619877768997*^9, 3.576245993225621*^9, {
   3.576251923452886*^9, 3.5762519388191223`*^9}, 3.576253348401009*^9, 
   3.576359015873736*^9, 3.576363200732362*^9, 3.576364096810697*^9, 
   3.576364222808535*^9, 3.57636430392715*^9, 3.576364442289371*^9, 
   3.576372544226355*^9, 3.5764291322963467`*^9, 3.576536708251452*^9, 
   3.576539475327636*^9, 3.576539810992508*^9, 3.576690430941389*^9, 
   3.576692897414905*^9, 3.576712135889247*^9, 3.576795742354631*^9, 
   3.576983737685679*^9, 3.576983816630754*^9, 3.577215458396619*^9, 
   3.577278672041518*^9, 3.577283264755928*^9, 3.577296658768396*^9, 
   3.577383124155705*^9, 3.577401294547724*^9, 3.5776629313427362`*^9, 
   3.577663001736299*^9, 3.577669971516794*^9, 3.577675347002562*^9, 
   3.57767695171037*^9, 3.577816815140456*^9, 3.5778344786924067`*^9, 
   3.5779158530885677`*^9, 3.577928337073476*^9, 3.5779307998706627`*^9, 
   3.577931056204967*^9, 3.577934515825535*^9, 3.578330295542039*^9, 
   3.578342611323728*^9, 3.578344523246283*^9, 3.578494201206201*^9, 
   3.578756819578004*^9, 3.5788499573020697`*^9, 3.578850470373294*^9, 
   3.5788674842878942`*^9, 3.578953606529396*^9, 3.579005040321274*^9, 
   3.57900589727258*^9, 3.5790060588886757`*^9, 3.5790064523005123`*^9, 
   3.579007234414875*^9, 3.5790239329833403`*^9, 3.5791951466207848`*^9, 
   3.579216908699592*^9, 3.579282515553876*^9, 3.579283965873014*^9, 
   3.579299398324277*^9, {3.579303890213739*^9, 3.579303908241888*^9}, 
   3.5794523882869387`*^9, 3.579456351734716*^9, 3.579820883707974*^9, 
   3.579824010462659*^9, 3.580008812742504*^9, 3.580439168259222*^9, 
   3.580596056021659*^9, 3.580642968433015*^9, 3.580671590363386*^9, 
   3.580699193424552*^9, 3.580845936507781*^9, 3.581172079100061*^9, 
   3.581190361980523*^9, 3.581195616629908*^9, 3.58126897398454*^9, 
   3.581270928294229*^9, 3.5812763047743607`*^9, 3.5812918091517*^9, 
   3.5812955132767487`*^9, {3.581297622610643*^9, 3.581297649749373*^9}, 
   3.581298248507359*^9, 3.581298848183468*^9, 3.581346633140215*^9, 
   3.58136351998829*^9, 3.581369186696898*^9, 3.581369576723339*^9, 
   3.581442003963849*^9, 3.581450802313902*^9, 3.581757917514182*^9, 
   3.581915393746087*^9, 3.582021741739171*^9, 3.58248346145119*^9, 
   3.584065499096163*^9, 3.5841098278122883`*^9, 3.584110059134514*^9, 
   3.584208682873699*^9, 3.584208891683762*^9, 3.584211091009077*^9, 
   3.584211267892787*^9, 3.584213610121166*^9, 3.5842141571299553`*^9, 
   3.5842214164966717`*^9, 3.584224090116034*^9, 3.5842797645059013`*^9, 
   3.584317076267603*^9, 3.584362237893867*^9, 3.584383354524911*^9, 
   3.584448807849901*^9, 3.5844533037334003`*^9, 3.584453386222417*^9, 
   3.58445359193292*^9, 3.584453831366433*^9, 3.584479568427314*^9, 
   3.5844851783066*^9, 3.584708492465097*^9, 3.584720378083254*^9, 
   3.584725512986198*^9, 3.5848746977595453`*^9, 3.5848747518258057`*^9, 
   3.58487600432936*^9, 3.584879548269713*^9, 3.591549616229661*^9, 
   3.6037557106493397`*^9, 3.6037574510589027`*^9, 3.603849874154615*^9, 
   3.6038502002969112`*^9, 3.603853950355564*^9, 3.6039255777520323`*^9, 
   3.604157597433237*^9, 3.6042363928341427`*^9, 3.605050446218274*^9, 
   3.605452230285342*^9, 3.605453007370535*^9, 3.612794824518709*^9, 
   3.612794955721298*^9, 3.612798666470744*^9, 3.612798791123231*^9, 
   3.612800462127021*^9, 3.6133202942316713`*^9, 3.613578436790884*^9, 
   3.6746063624757338`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"C0temp", "=", 
  RowBox[{"c0", " ", 
   RowBox[{"Intfuncgen", "[", "integrandC0temp", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.575479584854576*^9, 3.5754795944663277`*^9}, {
  3.575479648296536*^9, 3.575479648959216*^9}, {3.575482121217411*^9, 
  3.5754821213526897`*^9}, {3.575482209627096*^9, 3.5754822099219923`*^9}, {
  3.575484562751299*^9, 3.575484563679084*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "16"}], " ", 
  SuperscriptBox["\[Pi]", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "m2", " ", "m3"}], "-", 
        RowBox[{"m1", " ", 
         RowBox[{"(", 
          RowBox[{"m2", "+", "m3"}], ")"}]}]}], ")"}], " ", "qsq"}], 
     RowBox[{"32", " ", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "m2"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "m3"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m2", "-", "m3"}], ")"}], "2"], " ", 
      SuperscriptBox["\[Pi]", "2"]}]], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["m1", 
        RowBox[{"16", " ", 
         RowBox[{"(", 
          RowBox[{"m1", "-", "m2"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"m1", "-", "m3"}], ")"}], " ", 
         SuperscriptBox["\[Pi]", "2"]}]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["m1", "2"], " ", "qsq"}], 
        RowBox[{"32", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"m1", "-", "m2"}], ")"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"m1", "-", "m3"}], ")"}], "2"], " ", 
         SuperscriptBox["\[Pi]", "2"]}]]}], ")"}], " ", 
     RowBox[{"Log", "[", "m1", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["m2", 
         RowBox[{"16", " ", 
          RowBox[{"(", 
           RowBox[{"m1", "-", "m2"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"m2", "-", "m3"}], ")"}], " ", 
          SuperscriptBox["\[Pi]", "2"]}]]}], "-", 
       FractionBox[
        RowBox[{"m2", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["m2", "2"], "-", 
           RowBox[{"2", " ", "m1", " ", "m3"}], "+", 
           RowBox[{"m2", " ", "m3"}]}], ")"}], " ", "qsq"}], 
        RowBox[{"32", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"m1", "-", "m2"}], ")"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"m2", "-", "m3"}], ")"}], "3"], " ", 
         SuperscriptBox["\[Pi]", "2"]}]]}], ")"}], " ", 
     RowBox[{"Log", "[", "m2", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["m3", 
         RowBox[{"16", " ", 
          RowBox[{"(", 
           RowBox[{"m1", "-", "m3"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "m2"}], "+", "m3"}], ")"}], " ", 
          SuperscriptBox["\[Pi]", "2"]}]]}], "-", 
       FractionBox[
        RowBox[{"m3", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "m1", " ", "m2"}], "+", 
           RowBox[{"m3", " ", 
            RowBox[{"(", 
             RowBox[{"m2", "+", "m3"}], ")"}]}]}], ")"}], " ", "qsq"}], 
        RowBox[{"32", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"m1", "-", "m3"}], ")"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "m2"}], "+", "m3"}], ")"}], "3"], " ", 
         SuperscriptBox["\[Pi]", "2"]}]]}], ")"}], " ", 
     RowBox[{"Log", "[", "m3", "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.575479594847238*^9, 3.575479637396659*^9}, {
   3.575479715748292*^9, 3.575479732502356*^9}, 3.57547988105416*^9, {
   3.575482107915501*^9, 3.575482122095173*^9}, {3.575482191210232*^9, 
   3.5754822177962933`*^9}, 3.575482704098876*^9, 3.57548456738776*^9, 
   3.5754847670328007`*^9, {3.5754853703476973`*^9, 3.575485390675375*^9}, 
   3.5754911894838142`*^9, 3.57550379626178*^9, 3.575503962490556*^9, 
   3.575741184475408*^9, 3.575742892989759*^9, 3.57581853733773*^9, 
   3.5759271453126383`*^9, 3.575928274223325*^9, 3.575930566940432*^9, 
   3.5759313118375893`*^9, 3.575932804019916*^9, 3.575933090120858*^9, 
   3.575933676469391*^9, 3.575934956606379*^9, 3.575935241184094*^9, 
   3.575935877001172*^9, 3.575938358720821*^9, 3.575938622759902*^9, 
   3.575939414825679*^9, 3.575940271057618*^9, 3.575940606963523*^9, 
   3.5759430082667437`*^9, 3.5759445184522457`*^9, 3.5759459384478273`*^9, 
   3.576007706625781*^9, 3.576008620860713*^9, 3.576015065613367*^9, 
   3.576097311673244*^9, 3.576099972690576*^9, 3.576192437342389*^9, 
   3.576195000221588*^9, 3.576198778134845*^9, 3.576245993602582*^9, {
   3.576251923828061*^9, 3.576251939183343*^9}, 3.576253348809284*^9, 
   3.576359016315908*^9, 3.5763632011287413`*^9, 3.576364097246559*^9, 
   3.576364223215713*^9, 3.576364304346876*^9, 3.5763644426735573`*^9, 
   3.576372544607975*^9, 3.5764291326780653`*^9, 3.5765367086225653`*^9, 
   3.576539475699189*^9, 3.57653981136693*^9, 3.576690431320619*^9, 
   3.576692897788866*^9, 3.576712136267928*^9, 3.576795742710799*^9, 
   3.576983737951235*^9, 3.5769838169248037`*^9, 3.577215458808367*^9, 
   3.5772786723101873`*^9, 3.577283265180861*^9, 3.57729665905128*^9, 
   3.5773831244479094`*^9, 3.57740129482316*^9, 3.577662935620831*^9, 
   3.5776630051354313`*^9, 3.577669983482614*^9, 3.577675351636354*^9, 
   3.5776769564662027`*^9, 3.5778168205116673`*^9, 3.577834483614785*^9, 
   3.577915857642144*^9, 3.577928342278665*^9, 3.577930804653612*^9, 
   3.577931057316371*^9, 3.577934516946933*^9, 3.5783302966676493`*^9, 
   3.57834261248985*^9, 3.578344524351026*^9, 3.578494202282445*^9, 
   3.5787568208804483`*^9, 3.5788499584453173`*^9, 3.578850471656389*^9, 
   3.578867485397768*^9, 3.578953607970195*^9, 3.57900504153522*^9, 
   3.5790058983788147`*^9, 3.579006060057941*^9, 3.579006453021908*^9, 
   3.579007234487406*^9, 3.579023934064056*^9, 3.579195147750002*^9, 
   3.579216909799162*^9, 3.579282516632875*^9, 3.5792839684285917`*^9, 
   3.5792994004215*^9, {3.57930389141523*^9, 3.579303908331154*^9}, 
   3.579452389391515*^9, 3.579456352840342*^9, 3.579820884794875*^9, 
   3.579824011609057*^9, 3.580008813877556*^9, 3.580439169312058*^9, 
   3.5805960573187943`*^9, 3.580642969534569*^9, 3.580671591428751*^9, 
   3.580699194673365*^9, 3.5808459378832283`*^9, 3.581172080439109*^9, 
   3.5811903633109217`*^9, 3.581195617717355*^9, 3.581268975102098*^9, 
   3.581270929403399*^9, 3.581276305885219*^9, 3.581291810332354*^9, 
   3.581295514388138*^9, {3.581297623722518*^9, 3.58129765080888*^9}, 
   3.581298249620181*^9, 3.5812988493083057`*^9, 3.581346634492612*^9, 
   3.581363521528816*^9, 3.581369188119364*^9, 3.5813695781981277`*^9, 
   3.581442005273967*^9, 3.581450803810444*^9, 3.581757919038844*^9, 
   3.5819153954210653`*^9, 3.582021743106496*^9, 3.582483462879867*^9, 
   3.584065500605393*^9, 3.584109829463416*^9, 3.584110060654933*^9, 
   3.584208684398136*^9, 3.584208893206996*^9, 3.584211092538364*^9, 
   3.584211269393071*^9, 3.584213611619278*^9, 3.584214158666337*^9, 
   3.5842214180116*^9, 3.584224091642034*^9, 3.584279766069544*^9, 
   3.5843170778312597`*^9, 3.584362239454967*^9, 3.584383356792844*^9, 
   3.584448809364979*^9, 3.584453305382552*^9, 3.5844533878854647`*^9, 
   3.584453593475223*^9, 3.584453832891305*^9, 3.584479569997817*^9, 
   3.584485179830591*^9, 3.584708494017764*^9, 3.5847203796176453`*^9, 
   3.584725514524268*^9, 3.584874699294819*^9, 3.5848747533339233`*^9, 
   3.584876005834486*^9, 3.584879549787281*^9, 3.5915496178775377`*^9, 
   3.603755712216674*^9, 3.6037574524949913`*^9, 3.603849877536108*^9, 
   3.6038502022792587`*^9, 3.603853951865204*^9, 3.6039255791825447`*^9, 
   3.6041575988498907`*^9, 3.6042363944476547`*^9, 3.60505044780527*^9, 
   3.6054522318852987`*^9, 3.605453008965131*^9, 3.61279482621525*^9, 
   3.6127949563401527`*^9, 3.612798669996023*^9, 3.612798792847636*^9, 
   3.612800463592757*^9, 3.613320295703375*^9, 3.613578438200706*^9, 
   3.674606364425667*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"C1", " ", "and", " ", "C2", " ", "with", " ", 
     SuperscriptBox["p1", "2"]}], "=", 
    RowBox[{
     SuperscriptBox["p2", "2"], "=", 
     RowBox[{
      RowBox[{
      "0", " ", "and", " ", "expanded", " ", "to", " ", "first", " ", "order",
        " ", "around", " ", "p1dotp2"}], "=", "0"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Use", " ", 
     RowBox[{"identity", ":", " ", 
      RowBox[{"\[Integral]", " ", 
       RowBox[{
        SuperscriptBox["d", "4"], "k", " ", 
        SuperscriptBox["k", "\[Mu]"], 
        SuperscriptBox["k", "\[Nu]"], 
        SuperscriptBox["k", "\[Rho]"], 
        SuperscriptBox["k", "\[Sigma]"], 
        RowBox[{"f", "[", 
         SuperscriptBox["k", "2"], "]"}]}]}]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"1", "/", "24"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Eta]", "\[Mu]\[Nu]"], 
        SuperscriptBox["\[Eta]", "\[Rho]\[Sigma]"]}], "+", 
       RowBox[{
        SuperscriptBox["\[Eta]", "\[Mu]\[Rho]"], 
        SuperscriptBox["\[Eta]", "\[Nu]\[Sigma]"]}], "+", 
       RowBox[{
        SuperscriptBox["\[Eta]", "\[Mu]\[Sigma]"], 
        SuperscriptBox["\[Eta]", "\[Nu]\[Rho]"]}]}], ")"}], 
     RowBox[{"\[Integral]", " ", 
      RowBox[{
       SuperscriptBox["d", "4"], "k", " ", 
       SuperscriptBox["k", "4"], 
       RowBox[{"f", "[", 
        SuperscriptBox["k", "2"], "]"}]}]}]}]}], " ", "*)"}], 
  RowBox[{"integrandCitemp", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Expand", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Normal", "[", 
                 RowBox[{"Series", "[", 
                  RowBox[{
                   RowBox[{"\[Epsilon]", " ", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"k\[Mu]", "/", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["k", "2"], "+", "m1"}], ")"}]}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["k", "2"], "+", 
                    RowBox[{"2", "\[Epsilon]", " ", "kdotp1"}], "+", "m2"}], 
                    ")"}]}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["k", "2"], "+", 
                    RowBox[{"2", "\[Epsilon]", " ", "kdotp2"}], "+", "m3"}], 
                    ")"}]}]}], ",", 
                   RowBox[{"{", 
                    RowBox[{"\[Epsilon]", ",", "0", ",", "4"}], "}"}]}], 
                  "]"}], "]"}], "/.", 
                RowBox[{
                 SuperscriptBox["\[Epsilon]", "k_"], "\[RuleDelayed]", 
                 RowBox[{"1", "/;", 
                  RowBox[{"EvenQ", "[", "k", "]"}]}]}]}], "/.", 
               RowBox[{"\[Epsilon]", "\[Rule]", "0"}]}], "]"}], "/.", 
             RowBox[{
              SuperscriptBox["kdotp2", "3"], "\[Rule]", "0"}]}], "/.", 
            RowBox[{
             SuperscriptBox["kdotp1", "3"], "\[Rule]", "0"}]}], "/.", 
           RowBox[{
            RowBox[{"kdotp1", " ", 
             SuperscriptBox["kdotp2", "2"], " ", "k\[Mu]"}], "\[Rule]", 
            RowBox[{
             RowBox[{
              RowBox[{"1", "/", "d"}], "/", 
              RowBox[{"(", 
               RowBox[{"d", "+", "2"}], ")"}]}], 
             RowBox[{"(", 
              RowBox[{"2", "p2\[Mu]", " ", "p1dotp2", " ", 
               SuperscriptBox["k", "4"]}], ")"}]}]}]}], "/.", 
          RowBox[{
           RowBox[{"kdotp2", " ", 
            SuperscriptBox["kdotp1", "2"], " ", "k\[Mu]"}], "\[Rule]", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", "d"}], "/", 
             RowBox[{"(", 
              RowBox[{"d", "+", "2"}], ")"}]}], 
            RowBox[{"(", 
             RowBox[{"2", "p1\[Mu]", " ", "p1dotp2", " ", 
              SuperscriptBox["k", "4"]}], ")"}]}]}]}], "/.", 
         RowBox[{
          RowBox[{"kdotp1", " ", "k\[Mu]"}], "\[Rule]", 
          RowBox[{
           RowBox[{"1", "/", "d"}], " ", "p1\[Mu]", " ", 
           SuperscriptBox["k", "2"]}]}]}], "/.", 
        RowBox[{
         RowBox[{"kdotp2", " ", "k\[Mu]"}], "\[Rule]", 
         RowBox[{
          RowBox[{"1", "/", "d"}], " ", "p2\[Mu]", " ", 
          SuperscriptBox["k", "2"]}]}]}], "/.", 
       RowBox[{"d", "\[Rule]", 
        RowBox[{"4", "-", "\[Delta]"}]}]}], "/.", 
      RowBox[{"p1dotp2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "qsq"}], "/", "2"}]}]}], ",", "qsq", ",", 
     "FullSimplify"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5748976889729156`*^9, 3.574897691258231*^9}, {
  3.574897729583708*^9, 3.574897823658194*^9}, {3.574898685850213*^9, 
  3.574898691201762*^9}, {3.574898766358665*^9, 3.574898876629177*^9}, {
  3.574900204022066*^9, 3.574900207477779*^9}, {3.574901764123354*^9, 
  3.574901768636355*^9}, {3.577670198760721*^9, 3.57767021254214*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"m3", " ", "p1\[Mu]"}], "+", 
      RowBox[{"m2", " ", "p2\[Mu]"}], "+", 
      RowBox[{
       SuperscriptBox["k", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"p1\[Mu]", "+", "p2\[Mu]"}], ")"}]}]}], ")"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["k", "2"], "+", "m1"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["k", "2"], "+", "m2"}], ")"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["k", "2"], "+", "m3"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "4"}], "+", "\[Delta]"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"8", " ", 
    SuperscriptBox["k", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"m3", " ", "p1\[Mu]"}], "+", 
      RowBox[{"m2", " ", "p2\[Mu]"}], "+", 
      RowBox[{
       SuperscriptBox["k", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"p1\[Mu]", "+", "p2\[Mu]"}], ")"}]}]}], ")"}], " ", "qsq"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["k", "2"], "+", "m1"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["k", "2"], "+", "m2"}], ")"}], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["k", "2"], "+", "m3"}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "6"}], "+", "\[Delta]"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "4"}], "+", "\[Delta]"}], ")"}]}]]}]], "Output",
 CellChangeTimes->{
  3.574897694554819*^9, {3.574897729876338*^9, 3.574897823914639*^9}, {
   3.5748988114166813`*^9, 3.5748988769702797`*^9}, 3.57490020866156*^9, 
   3.574901769246704*^9, 3.574903937167047*^9, 3.57502443088159*^9, 
   3.575037182696754*^9, 3.57503934947077*^9, 3.575043109302827*^9, 
   3.575071484006803*^9, 3.5751217153244877`*^9, 3.575199796767825*^9, 
   3.575410797278654*^9, 3.5754140298781557`*^9, 3.5754141037017193`*^9, 
   3.575431645508463*^9, 3.575477373195034*^9, 3.575478072218609*^9, 
   3.5754822248334103`*^9, 3.575484775111083*^9, {3.575485370506456*^9, 
   3.575485390752357*^9}, 3.575491189627239*^9, 3.575503796365918*^9, 
   3.575503962653985*^9, 3.57574118467192*^9, 3.57574289319025*^9, 
   3.575818537523657*^9, 3.575927145435795*^9, 3.575928274413784*^9, 
   3.5759305671405888`*^9, 3.5759313119664917`*^9, 3.575932804234084*^9, 
   3.575933090297289*^9, 3.575933676669478*^9, 3.5759349567293777`*^9, 
   3.5759352414580107`*^9, 3.575935877126739*^9, 3.575938358931305*^9, 
   3.575938623039089*^9, 3.575939415101828*^9, 3.5759402712534122`*^9, 
   3.5759406070897217`*^9, 3.575943008453589*^9, 3.57594451862199*^9, 
   3.575945938568503*^9, 3.576007706748529*^9, 3.5760086209792643`*^9, 
   3.5760150657921124`*^9, 3.576097311799138*^9, 3.5760999735385723`*^9, 
   3.576192437510195*^9, 3.576195000340208*^9, 3.576198778248827*^9, 
   3.57624599371978*^9, {3.5762519240073347`*^9, 3.576251939372117*^9}, 
   3.576253348987006*^9, 3.576359016435689*^9, 3.576363201318983*^9, 
   3.5763640974400053`*^9, 3.576364223409853*^9, 3.576364304520144*^9, 
   3.576364442864559*^9, 3.576372544765291*^9, 3.576429132851812*^9, 
   3.5765367087431107`*^9, 3.576539475864398*^9, 3.576539811564187*^9, 
   3.576690431449093*^9, 3.5766928979532948`*^9, 3.576712136428516*^9, 
   3.576795742824913*^9, 3.5769837381052437`*^9, 3.576983817035984*^9, 
   3.577215459074924*^9, 3.577278672412168*^9, 3.577283265357583*^9, 
   3.5772966592646923`*^9, 3.5773831245587587`*^9, 3.577401294928899*^9, 
   3.5776629383588*^9, 3.577663005440504*^9, 3.577670212849998*^9, 
   3.577675351897521*^9, 3.57767695681089*^9, 3.5778168207099953`*^9, 
   3.577834483874399*^9, 3.57791585791654*^9, 3.5779283425828047`*^9, 
   3.5779308049184237`*^9, 3.5779310575775757`*^9, 3.577934517226025*^9, 
   3.578330296898347*^9, 3.578342612735879*^9, 3.578344524540621*^9, 
   3.578494202537354*^9, 3.578756821045464*^9, 3.578849958665052*^9, 
   3.578850471811002*^9, 3.5788674855820704`*^9, 3.578953608175374*^9, 
   3.579005041736212*^9, 3.579005898553217*^9, 3.5790060603043118`*^9, 
   3.579006453132428*^9, 3.579007234564199*^9, 3.579023934278008*^9, 
   3.579195147971525*^9, 3.579216910038802*^9, 3.579282516921422*^9, 
   3.5792839686229887`*^9, 3.579299401804196*^9, {3.5793038921470823`*^9, 
   3.579303908407893*^9}, 3.579452390278232*^9, 3.579456353592074*^9, 
   3.579820885534111*^9, 3.57982401265423*^9, 3.5800088146292973`*^9, 
   3.5804391699545727`*^9, 3.580596058097227*^9, 3.58064297022059*^9, 
   3.58067159211171*^9, 3.580699195685524*^9, 3.580845938742909*^9, 
   3.58117208122118*^9, 3.581190364170301*^9, 3.581195618592299*^9, 
   3.581268975834857*^9, 3.5812709300569477`*^9, 3.581276306591577*^9, 
   3.581291811083349*^9, 3.581295515056727*^9, {3.581297624098563*^9, 
   3.581297651480626*^9}, 3.5812982502675734`*^9, 3.581298849985106*^9, 
   3.581346635612508*^9, 3.5813635228091583`*^9, 3.581369189298553*^9, 
   3.58136957940625*^9, 3.581442006132201*^9, 3.581450805062904*^9, 
   3.581757920801672*^9, 3.5819153971578007`*^9, 3.582021744551075*^9, 
   3.5824834644723*^9, 3.5840655020594177`*^9, 3.584109831076742*^9, 
   3.584110062108734*^9, 3.584208685854022*^9, 3.584208894649384*^9, 
   3.584211093978402*^9, 3.584211270855173*^9, 3.584213613100418*^9, 
   3.584214160144719*^9, 3.584221419498605*^9, 3.584224093195972*^9, 
   3.584279767611848*^9, 3.5843170795001497`*^9, 3.5843622409924726`*^9, 
   3.584383358297223*^9, 3.5844488108549213`*^9, 3.584453307542584*^9, 
   3.584453389994856*^9, 3.5844535949845057`*^9, 3.5844538343982363`*^9, 
   3.5844795714936657`*^9, 3.58448518131697*^9, 3.584708495535576*^9, 
   3.5847203810761623`*^9, 3.584725516048696*^9, 3.584874700742361*^9, 
   3.5848747548209333`*^9, 3.584876007280059*^9, 3.584879551290291*^9, 
   3.591549619509108*^9, 3.603755713957312*^9, 3.603757454323119*^9, 
   3.603849879068503*^9, 3.6038502040267076`*^9, 3.603853953518382*^9, 
   3.603925580705411*^9, 3.604157600421795*^9, 3.604236396150535*^9, 
   3.605050449409163*^9, 3.6054522334173193`*^9, 3.605453010486803*^9, 
   3.612794827051921*^9, 3.612794957750637*^9, 3.612798675942835*^9, 
   3.612798793201537*^9, 3.612800463868018*^9, 3.613320295952928*^9, 
   3.613578438420072*^9, 3.674606364765926*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"C1temp", "=", 
  RowBox[{
   RowBox[{"c1", " ", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Intfuncgen", "[", "integrandCitemp", "]"}], ",", "p1\[Mu]"}], 
     "]"}]}], "/.", "subtry"}]}], "\[IndentingNewLine]", 
 RowBox[{"C2temp", "=", 
  RowBox[{
   RowBox[{"c1", " ", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Intfuncgen", "[", "integrandCitemp", "]"}], ",", "p2\[Mu]"}], 
     "]"}]}], "/.", "subtry"}]}]}], "Input",
 CellChangeTimes->{{3.5754822310664673`*^9, 3.575482268068571*^9}, {
  3.575482933862275*^9, 3.575482963701426*^9}, {3.575484574024372*^9, 
  3.5754845790335503`*^9}, {3.577296613684626*^9, 3.577296616681299*^9}, {
  3.577675310653458*^9, 3.577675311019451*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "16"}], " ", 
  SuperscriptBox["\[Pi]", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    FractionBox["m2", 
     RowBox[{"32", " ", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "m2"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"m2", "-", "m3"}], ")"}], " ", 
      SuperscriptBox["\[Pi]", "2"]}]], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["m2", "2"]}], " ", "m3", " ", 
         RowBox[{"(", 
          RowBox[{"m2", "+", 
           RowBox[{"5", " ", "m3"}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["m1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["m2", "2"], "-", 
           RowBox[{"5", " ", "m2", " ", "m3"}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["m3", "2"]}]}], ")"}]}], "+", 
        RowBox[{"m1", " ", "m2", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["m2", "2"], "+", 
           RowBox[{"2", " ", "m2", " ", "m3"}], "+", 
           RowBox[{"9", " ", 
            SuperscriptBox["m3", "2"]}]}], ")"}]}]}], ")"}], " ", "qsq"}], 
     RowBox[{"96", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m1", "-", "m2"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "m3"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m2", "-", "m3"}], ")"}], "3"], " ", 
      SuperscriptBox["\[Pi]", "2"]}]], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         SuperscriptBox["m1", "2"], 
         RowBox[{"32", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"m1", "-", "m2"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"m1", "-", "m3"}], ")"}], " ", 
          SuperscriptBox["\[Pi]", "2"]}]]}], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["m1", "3"], " ", "qsq"}], 
        RowBox[{"48", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"m1", "-", "m2"}], ")"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"m1", "-", "m3"}], ")"}], "2"], " ", 
         SuperscriptBox["\[Pi]", "2"]}]]}], ")"}], " ", 
     RowBox[{"Log", "[", "m1", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"m2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"m1", " ", 
            RowBox[{"(", 
             RowBox[{"m2", "-", 
              RowBox[{"2", " ", "m3"}]}], ")"}]}], "+", 
           RowBox[{"m2", " ", "m3"}]}], ")"}]}], 
        RowBox[{"32", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"m1", "-", "m2"}], ")"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"m2", "-", "m3"}], ")"}], "2"], " ", 
         SuperscriptBox["\[Pi]", "2"]}]], "+", 
       FractionBox[
        RowBox[{"m2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["m1", "2"], " ", 
            SuperscriptBox["m3", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["m2", "2"], " ", "m3", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "m2"}], "+", "m3"}], ")"}]}], "+", 
           RowBox[{"m1", " ", "m2", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["m2", "2"], "-", 
              RowBox[{"4", " ", "m2", " ", "m3"}], "-", 
              RowBox[{"3", " ", 
               SuperscriptBox["m3", "2"]}]}], ")"}]}]}], ")"}], " ", "qsq"}], 
        
        RowBox[{"48", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"m1", "-", "m2"}], ")"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"m2", "-", "m3"}], ")"}], "4"], " ", 
         SuperscriptBox["\[Pi]", "2"]}]]}], ")"}], " ", 
     RowBox[{"Log", "[", "m2", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        SuperscriptBox["m3", "2"], 
        RowBox[{"32", " ", 
         RowBox[{"(", 
          RowBox[{"m1", "-", "m3"}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"m2", "-", "m3"}], ")"}], "2"], " ", 
         SuperscriptBox["\[Pi]", "2"]}]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["m3", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "3"}], " ", "m1", " ", "m2"}], "+", 
           RowBox[{"m3", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "m2"}], "+", "m3"}], ")"}]}]}], ")"}], " ", 
         "qsq"}], 
        RowBox[{"48", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"m1", "-", "m3"}], ")"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"m2", "-", "m3"}], ")"}], "4"], " ", 
         SuperscriptBox["\[Pi]", "2"]}]]}], ")"}], " ", 
     RowBox[{"Log", "[", "m3", "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.5754822595354967`*^9, 3.575482717204527*^9, {3.575482807648204*^9, 
   3.5754828291296463`*^9}, {3.575482926918315*^9, 3.5754829639233828`*^9}, 
   3.5754846116965017`*^9, 3.5754847767699614`*^9, {3.5754853725296*^9, 
   3.5754853912184153`*^9}, 3.575491192157715*^9, 3.575503798482194*^9, 
   3.57550396472117*^9, 3.575741187585586*^9, 3.5757428961350927`*^9, 
   3.5758185404090137`*^9, 3.5759271483539124`*^9, 3.5759282773912086`*^9, 
   3.5759305700029917`*^9, 3.575931315097371*^9, 3.5759328071753893`*^9, 
   3.5759330932282963`*^9, 3.575933679567024*^9, 3.575934959895438*^9, 
   3.575935244549008*^9, 3.5759358799834557`*^9, 3.575938362003059*^9, 
   3.575938625997038*^9, 3.575939417973022*^9, 3.5759402741447687`*^9, 
   3.575940609992372*^9, 3.575943011361413*^9, 3.57594452150957*^9, 
   3.575945941472361*^9, 3.576007709742931*^9, 3.576008623967984*^9, 
   3.576015068808301*^9, 3.5760973146753902`*^9, 3.57609997651552*^9, 
   3.576192440466675*^9, 3.5761950031835613`*^9, 3.5761987811281347`*^9, 
   3.5762459966112213`*^9, {3.576251924422138*^9, 3.5762519422455482`*^9}, 
   3.576253352033868*^9, 3.5763590192992487`*^9, 3.576363204355481*^9, 
   3.576364100571808*^9, 3.57636422648999*^9, 3.576364307623331*^9, 
   3.576364445816478*^9, 3.576372547678439*^9, 3.576429135697431*^9, 
   3.576536711625822*^9, 3.576539478730389*^9, 3.576539814448132*^9, 
   3.5766904343489923`*^9, 3.576692900841967*^9, 3.57671213935498*^9, 
   3.576795745080434*^9, 3.57698374008147*^9, 3.576983820169694*^9, 
   3.577215461037088*^9, 3.5772786743476343`*^9, 3.5772832674156647`*^9, 
   3.5772966612778463`*^9, 3.5773831267020407`*^9, 3.577401296953652*^9, 
   3.5776629561269207`*^9, 3.577663019512335*^9, 3.5776702375799913`*^9, 
   3.577675371432786*^9, 3.577676977917088*^9, 3.577816844099495*^9, 
   3.5778345045779037`*^9, 3.5779158768503304`*^9, 3.5779283625629*^9, 
   3.577930821920948*^9, 3.577931061805299*^9, 3.577934521153883*^9, 
   3.578330301057623*^9, 3.578342616668209*^9, 3.5783445284833193`*^9, 
   3.5784942064398603`*^9, 3.578756825766122*^9, 3.578849962604244*^9, 
   3.578850476534955*^9, 3.5788674895758657`*^9, 3.578953613505374*^9, 
   3.579005045872016*^9, 3.5790059026683292`*^9, 3.5790060643795013`*^9, 
   3.579006455663219*^9, 3.579007235278796*^9, 3.5790239382197237`*^9, 
   3.5791951519631643`*^9, 3.5792169141460133`*^9, 3.579282520795487*^9, 
   3.579283972563745*^9, 3.5792994063719378`*^9, {3.579303895818735*^9, 
   3.579303908744062*^9}, 3.579452394135118*^9, 3.579456357618094*^9, 
   3.579820889567319*^9, 3.579824017239972*^9, 3.580008818816884*^9, 
   3.580439173732257*^9, 3.580596062790663*^9, 3.580642974106855*^9, 
   3.580671595960641*^9, 3.5806991996503887`*^9, 3.5808459427931967`*^9, 
   3.581172085950387*^9, 3.581190368255628*^9, 3.5811956226175737`*^9, 
   3.5812689798636627`*^9, 3.581270934018257*^9, 3.5812763107211437`*^9, 
   3.5812918153480177`*^9, 3.581295518972372*^9, {3.581297627305236*^9, 
   3.581297655450973*^9}, 3.581298254243938*^9, 3.58129885393552*^9, 
   3.581346640517611*^9, 3.5813635282755117`*^9, 3.581369194427376*^9, 
   3.581369584583631*^9, 3.581442010864999*^9, 3.5814508100382347`*^9, 
   3.58175792566466*^9, 3.5819154025892973`*^9, 3.582021749337229*^9, 
   3.58248346948032*^9, 3.5840655075074673`*^9, 3.5841098368240957`*^9, 
   3.584110067617313*^9, 3.584208691350688*^9, 3.584208900072899*^9, 
   3.584211099428808*^9, 3.584211276263479*^9, 3.584213618522097*^9, 
   3.584214165575383*^9, 3.584221424928316*^9, 3.584224098813429*^9, 
   3.584279773275197*^9, 3.584317085048935*^9, 3.584362246833229*^9, 
   3.584383363826952*^9, 3.584448816984511*^9, 3.5844533133343973`*^9, 
   3.584453395715345*^9, 3.58445360049219*^9, 3.584453839903584*^9, 
   3.584479577138777*^9, 3.58448518679587*^9, 3.584708501027782*^9, 
   3.584720386653994*^9, 3.58472552158075*^9, 3.584874706321282*^9, 
   3.584874760302898*^9, 3.584876012730761*^9, 3.5848795567464657`*^9, 
   3.591549625403561*^9, 3.603755719931258*^9, 3.6037574602951*^9, 
   3.603849884535861*^9, 3.603850210010413*^9, 3.603853958686137*^9, 
   3.603925585986068*^9, 3.604157605227705*^9, 3.604236401511125*^9, 
   3.6050504551693277`*^9, 3.605452239190099*^9, 3.6054530162399063`*^9, 
   3.612794832599655*^9, 3.612794959160706*^9, 3.6127986826620197`*^9, 
   3.612798799803097*^9, 3.6128004688369017`*^9, 3.613320301080969*^9, 
   3.613578443430953*^9, 3.67460636951483*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "16"}], " ", 
  SuperscriptBox["\[Pi]", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    FractionBox["m3", 
     RowBox[{"32", " ", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "m3"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "m2"}], "+", "m3"}], ")"}], " ", 
      SuperscriptBox["\[Pi]", "2"]}]], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"m2", " ", 
         SuperscriptBox["m3", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"5", " ", "m2"}], "+", "m3"}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["m1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["m2", "2"]}], "+", 
           RowBox[{"5", " ", "m2", " ", "m3"}], "-", 
           SuperscriptBox["m3", "2"]}], ")"}]}], "-", 
        RowBox[{"m1", " ", "m3", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"9", " ", 
            SuperscriptBox["m2", "2"]}], "+", 
           RowBox[{"2", " ", "m2", " ", "m3"}], "+", 
           SuperscriptBox["m3", "2"]}], ")"}]}]}], ")"}], " ", "qsq"}], 
     RowBox[{"96", " ", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "m2"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m1", "-", "m3"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m2", "-", "m3"}], ")"}], "3"], " ", 
      SuperscriptBox["\[Pi]", "2"]}]], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         SuperscriptBox["m1", "2"], 
         RowBox[{"32", " ", 
          RowBox[{"(", 
           RowBox[{"m1", "-", "m2"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"m1", "-", "m3"}], ")"}], "2"], " ", 
          SuperscriptBox["\[Pi]", "2"]}]]}], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["m1", "3"], " ", "qsq"}], 
        RowBox[{"48", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"m1", "-", "m2"}], ")"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"m1", "-", "m3"}], ")"}], "3"], " ", 
         SuperscriptBox["\[Pi]", "2"]}]]}], ")"}], " ", 
     RowBox[{"Log", "[", "m1", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        SuperscriptBox["m2", "2"], 
        RowBox[{"32", " ", 
         RowBox[{"(", 
          RowBox[{"m1", "-", "m2"}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"m2", "-", "m3"}], ")"}], "2"], " ", 
         SuperscriptBox["\[Pi]", "2"]}]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["m2", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["m2", "2"], "-", 
           RowBox[{"3", " ", "m1", " ", "m3"}], "+", 
           RowBox[{"2", " ", "m2", " ", "m3"}]}], ")"}], " ", "qsq"}], 
        RowBox[{"48", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"m1", "-", "m2"}], ")"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"m2", "-", "m3"}], ")"}], "4"], " ", 
         SuperscriptBox["\[Pi]", "2"]}]]}], ")"}], " ", 
     RowBox[{"Log", "[", "m2", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"m3", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"m2", " ", "m3"}], "+", 
           RowBox[{"m1", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "m2"}], "+", "m3"}], ")"}]}]}], 
          ")"}]}], 
        RowBox[{"32", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"m1", "-", "m3"}], ")"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"m2", "-", "m3"}], ")"}], "2"], " ", 
         SuperscriptBox["\[Pi]", "2"]}]], "+", 
       FractionBox[
        RowBox[{"m3", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["m1", "2"], " ", 
            SuperscriptBox["m2", "2"]}], "+", 
           RowBox[{"m2", " ", 
            SuperscriptBox["m3", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"m2", "+", 
              RowBox[{"2", " ", "m3"}]}], ")"}]}], "+", 
           RowBox[{"m1", " ", "m3", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "3"}], " ", 
               SuperscriptBox["m2", "2"]}], "-", 
              RowBox[{"4", " ", "m2", " ", "m3"}], "+", 
              SuperscriptBox["m3", "2"]}], ")"}]}]}], ")"}], " ", "qsq"}], 
        RowBox[{"48", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"m1", "-", "m3"}], ")"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"m2", "-", "m3"}], ")"}], "4"], " ", 
         SuperscriptBox["\[Pi]", "2"]}]]}], ")"}], " ", 
     RowBox[{"Log", "[", "m3", "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.5754822595354967`*^9, 3.575482717204527*^9, {3.575482807648204*^9, 
   3.5754828291296463`*^9}, {3.575482926918315*^9, 3.5754829639233828`*^9}, 
   3.5754846116965017`*^9, 3.5754847767699614`*^9, {3.5754853725296*^9, 
   3.5754853912184153`*^9}, 3.575491192157715*^9, 3.575503798482194*^9, 
   3.57550396472117*^9, 3.575741187585586*^9, 3.5757428961350927`*^9, 
   3.5758185404090137`*^9, 3.5759271483539124`*^9, 3.5759282773912086`*^9, 
   3.5759305700029917`*^9, 3.575931315097371*^9, 3.5759328071753893`*^9, 
   3.5759330932282963`*^9, 3.575933679567024*^9, 3.575934959895438*^9, 
   3.575935244549008*^9, 3.5759358799834557`*^9, 3.575938362003059*^9, 
   3.575938625997038*^9, 3.575939417973022*^9, 3.5759402741447687`*^9, 
   3.575940609992372*^9, 3.575943011361413*^9, 3.57594452150957*^9, 
   3.575945941472361*^9, 3.576007709742931*^9, 3.576008623967984*^9, 
   3.576015068808301*^9, 3.5760973146753902`*^9, 3.57609997651552*^9, 
   3.576192440466675*^9, 3.5761950031835613`*^9, 3.5761987811281347`*^9, 
   3.5762459966112213`*^9, {3.576251924422138*^9, 3.5762519422455482`*^9}, 
   3.576253352033868*^9, 3.5763590192992487`*^9, 3.576363204355481*^9, 
   3.576364100571808*^9, 3.57636422648999*^9, 3.576364307623331*^9, 
   3.576364445816478*^9, 3.576372547678439*^9, 3.576429135697431*^9, 
   3.576536711625822*^9, 3.576539478730389*^9, 3.576539814448132*^9, 
   3.5766904343489923`*^9, 3.576692900841967*^9, 3.57671213935498*^9, 
   3.576795745080434*^9, 3.57698374008147*^9, 3.576983820169694*^9, 
   3.577215461037088*^9, 3.5772786743476343`*^9, 3.5772832674156647`*^9, 
   3.5772966612778463`*^9, 3.5773831267020407`*^9, 3.577401296953652*^9, 
   3.5776629561269207`*^9, 3.577663019512335*^9, 3.5776702375799913`*^9, 
   3.577675371432786*^9, 3.577676977917088*^9, 3.577816844099495*^9, 
   3.5778345045779037`*^9, 3.5779158768503304`*^9, 3.5779283625629*^9, 
   3.577930821920948*^9, 3.577931061805299*^9, 3.577934521153883*^9, 
   3.578330301057623*^9, 3.578342616668209*^9, 3.5783445284833193`*^9, 
   3.5784942064398603`*^9, 3.578756825766122*^9, 3.578849962604244*^9, 
   3.578850476534955*^9, 3.5788674895758657`*^9, 3.578953613505374*^9, 
   3.579005045872016*^9, 3.5790059026683292`*^9, 3.5790060643795013`*^9, 
   3.579006455663219*^9, 3.579007235278796*^9, 3.5790239382197237`*^9, 
   3.5791951519631643`*^9, 3.5792169141460133`*^9, 3.579282520795487*^9, 
   3.579283972563745*^9, 3.5792994063719378`*^9, {3.579303895818735*^9, 
   3.579303908744062*^9}, 3.579452394135118*^9, 3.579456357618094*^9, 
   3.579820889567319*^9, 3.579824017239972*^9, 3.580008818816884*^9, 
   3.580439173732257*^9, 3.580596062790663*^9, 3.580642974106855*^9, 
   3.580671595960641*^9, 3.5806991996503887`*^9, 3.5808459427931967`*^9, 
   3.581172085950387*^9, 3.581190368255628*^9, 3.5811956226175737`*^9, 
   3.5812689798636627`*^9, 3.581270934018257*^9, 3.5812763107211437`*^9, 
   3.5812918153480177`*^9, 3.581295518972372*^9, {3.581297627305236*^9, 
   3.581297655450973*^9}, 3.581298254243938*^9, 3.58129885393552*^9, 
   3.581346640517611*^9, 3.5813635282755117`*^9, 3.581369194427376*^9, 
   3.581369584583631*^9, 3.581442010864999*^9, 3.5814508100382347`*^9, 
   3.58175792566466*^9, 3.5819154025892973`*^9, 3.582021749337229*^9, 
   3.58248346948032*^9, 3.5840655075074673`*^9, 3.5841098368240957`*^9, 
   3.584110067617313*^9, 3.584208691350688*^9, 3.584208900072899*^9, 
   3.584211099428808*^9, 3.584211276263479*^9, 3.584213618522097*^9, 
   3.584214165575383*^9, 3.584221424928316*^9, 3.584224098813429*^9, 
   3.584279773275197*^9, 3.584317085048935*^9, 3.584362246833229*^9, 
   3.584383363826952*^9, 3.584448816984511*^9, 3.5844533133343973`*^9, 
   3.584453395715345*^9, 3.58445360049219*^9, 3.584453839903584*^9, 
   3.584479577138777*^9, 3.58448518679587*^9, 3.584708501027782*^9, 
   3.584720386653994*^9, 3.58472552158075*^9, 3.584874706321282*^9, 
   3.584874760302898*^9, 3.584876012730761*^9, 3.5848795567464657`*^9, 
   3.591549625403561*^9, 3.603755719931258*^9, 3.6037574602951*^9, 
   3.603849884535861*^9, 3.603850210010413*^9, 3.603853958686137*^9, 
   3.603925585986068*^9, 3.604157605227705*^9, 3.604236401511125*^9, 
   3.6050504551693277`*^9, 3.605452239190099*^9, 3.6054530162399063`*^9, 
   3.612794832599655*^9, 3.612794959160706*^9, 3.6127986826620197`*^9, 
   3.612798799803097*^9, 3.6128004688369017`*^9, 3.613320301080969*^9, 
   3.613578443430953*^9, 3.67460636977637*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Cij", " ", "with", " ", 
     SuperscriptBox["p1", "2"]}], "=", 
    RowBox[{
     SuperscriptBox["p2", "2"], "=", 
     RowBox[{
      RowBox[{
      "0", " ", "and", " ", "expanded", " ", "to", " ", "first", " ", "order",
        " ", "around", " ", "p1dotp2"}], "=", "0"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Use", " ", 
     RowBox[{"identity", ":", " ", 
      RowBox[{"\[Integral]", " ", 
       RowBox[{
        SuperscriptBox["d", "4"], "k", " ", 
        SuperscriptBox["k", "\[Mu]"], 
        SuperscriptBox["k", "\[Nu]"], 
        SuperscriptBox["k", "\[Rho]"], 
        SuperscriptBox["k", "\[Sigma]"], 
        SuperscriptBox["k", "\[Alpha]"], 
        SuperscriptBox["k", "\[Beta]"], 
        RowBox[{"f", "[", 
         SuperscriptBox["k", "2"], "]"}]}]}]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"1", "/", "192"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Eta]", "\[Mu]\[Nu]"], 
        SuperscriptBox["\[Eta]", "\[Rho]\[Sigma]"], 
        SuperscriptBox["\[Eta]", "\[Alpha]\[Beta]"]}], "+", "perms"}], ")"}], 
     
     RowBox[{"\[Integral]", " ", 
      RowBox[{
       SuperscriptBox["d", "4"], "k", " ", 
       SuperscriptBox["k", "6"], 
       RowBox[{"f", "[", 
        SuperscriptBox["k", "2"], "]"}]}]}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"integrandCijtemp", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Expand", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"Normal", "[", 
                    RowBox[{"Series", "[", 
                    RowBox[{
                    RowBox[{"k\[Mu]", " ", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"k\[Nu]", "/", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["k", "2"], "+", "m1"}], ")"}]}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["k", "2"], "+", 
                    RowBox[{"2", "\[Epsilon]", " ", "kdotp1"}], "+", "m2"}], 
                    ")"}]}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["k", "2"], "+", 
                    RowBox[{"2", "\[Epsilon]", " ", "kdotp2"}], "+", "m3"}], 
                    ")"}]}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Epsilon]", ",", "0", ",", "4"}], "}"}]}], 
                    "]"}], "]"}], "/.", 
                   RowBox[{
                    SuperscriptBox["\[Epsilon]", "k_"], "\[RuleDelayed]", 
                    RowBox[{"1", "/;", 
                    RowBox[{"EvenQ", "[", "k", "]"}]}]}]}], "/.", 
                  RowBox[{"\[Epsilon]", "\[Rule]", "0"}]}], "/.", 
                 RowBox[{
                  SuperscriptBox["kdotp2", "4"], "\[Rule]", "0"}]}], "/.", 
                RowBox[{
                 SuperscriptBox["kdotp1", "4"], "\[Rule]", "0"}]}], "]"}], "/.", 
              RowBox[{
               RowBox[{"kdotp1", " ", 
                SuperscriptBox["kdotp2", "3"], " ", "k\[Mu]", " ", "k\[Nu]"}],
                "\[Rule]", 
               RowBox[{
                RowBox[{"1", "/", 
                 RowBox[{"(", 
                  RowBox[{"d", 
                   RowBox[{"(", 
                    RowBox[{"d", "+", "2"}], ")"}], 
                   RowBox[{"(", 
                    RowBox[{"d", "+", "4"}], ")"}]}], ")"}]}], " ", 
                RowBox[{"(", 
                 RowBox[{
                 "6", "p1dotp2", " ", "p2\[Mu]", " ", "p2\[Nu]", " ", 
                  SuperscriptBox["k", "6"]}], ")"}]}]}]}], "/.", 
             RowBox[{
              RowBox[{
               SuperscriptBox["kdotp1", "3"], " ", "kdotp2", " ", "k\[Mu]", 
               " ", "k\[Nu]"}], "\[Rule]", 
              RowBox[{
               RowBox[{"1", "/", 
                RowBox[{"(", 
                 RowBox[{"d", 
                  RowBox[{"(", 
                   RowBox[{"d", "+", "2"}], ")"}], 
                  RowBox[{"(", 
                   RowBox[{"d", "+", "4"}], ")"}]}], ")"}]}], " ", 
               RowBox[{"(", 
                RowBox[{"6", "p1dotp2", " ", "p1\[Mu]", " ", "p1\[Nu]", " ", 
                 SuperscriptBox["k", "6"]}], ")"}]}]}]}], "/.", 
            RowBox[{
             RowBox[{
              SuperscriptBox["kdotp1", "2"], " ", 
              SuperscriptBox["kdotp2", "2"], "k\[Mu]", " ", "k\[Nu]"}], 
             "\[Rule]", 
             RowBox[{
              RowBox[{"1", "/", 
               RowBox[{"(", 
                RowBox[{"d", 
                 RowBox[{"(", 
                  RowBox[{"d", "+", "2"}], ")"}], 
                 RowBox[{"(", 
                  RowBox[{"d", "+", "4"}], ")"}]}], ")"}]}], 
              RowBox[{"(", 
               RowBox[{"4", "p1dotp2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"p1\[Mu]", " ", "p2\[Nu]"}], "+", 
                  RowBox[{"p2\[Mu]", " ", "p1\[Nu]"}]}], ")"}]}], ")"}]}]}]}],
            "/.", 
           RowBox[{
            RowBox[{
             SuperscriptBox["kdotp2", "2"], " ", "k\[Mu]", " ", "k\[Nu]"}], 
            "\[Rule]", 
            RowBox[{
             RowBox[{"1", "/", 
              RowBox[{"(", 
               RowBox[{"d", 
                RowBox[{"(", 
                 RowBox[{"d", "+", "2"}], ")"}]}], ")"}]}], 
             RowBox[{"(", 
              RowBox[{"2", "p2\[Mu]", " ", "p2\[Nu]", " ", 
               SuperscriptBox["k", "4"]}], ")"}]}]}]}], "/.", 
          RowBox[{
           RowBox[{
            SuperscriptBox["kdotp1", "2"], " ", "k\[Mu]", " ", "k\[Nu]"}], 
           "\[Rule]", 
           RowBox[{
            RowBox[{"1", "/", 
             RowBox[{"(", 
              RowBox[{"d", 
               RowBox[{"(", 
                RowBox[{"d", "+", "2"}], ")"}]}], ")"}]}], 
            RowBox[{"(", 
             RowBox[{"2", "p1\[Mu]", " ", "p1\[Nu]", " ", 
              SuperscriptBox["k", "4"]}], ")"}]}]}]}], "/.", 
         RowBox[{
          RowBox[{"kdotp1", " ", "kdotp2", " ", "k\[Mu]", " ", "k\[Nu]"}], 
          "\[Rule]", 
          RowBox[{
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"d", 
              RowBox[{"(", 
               RowBox[{"d", "+", "2"}], ")"}]}], ")"}]}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"p1dotp2", " ", "\[Eta]\[Mu]\[Nu]"}], "+", 
             RowBox[{"p1\[Mu]", " ", "p2\[Nu]"}], "+", 
             RowBox[{"p2\[Mu]", " ", "p1\[Nu]"}]}], ")"}], 
           SuperscriptBox["k", "4"]}]}]}], "/.", 
        RowBox[{
         RowBox[{"k\[Mu]", " ", "k\[Nu]"}], "\[Rule]", 
         RowBox[{
          RowBox[{"1", "/", "d"}], " ", "\[Eta]\[Mu]\[Nu]", " ", 
          SuperscriptBox["k", "2"]}]}]}], "/.", 
       RowBox[{"d", "\[Rule]", 
        RowBox[{"4", "-", "\[Delta]"}]}]}], "/.", 
      RowBox[{"p1dotp2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "qsq"}], "/", "2"}]}]}], ",", "qsq", ",", 
     "FullSimplify"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.574900226988413*^9, 3.574900264108863*^9}, {
  3.574900328087408*^9, 3.574900396959166*^9}, {3.574901224333816*^9, 
  3.574901243102832*^9}, {3.574901702649322*^9, 3.5749017754695377`*^9}, {
  3.574901849582118*^9, 3.5749019113833723`*^9}, {3.5749026103462667`*^9, 
  3.574902628406314*^9}, {3.574903114210644*^9, 3.5749032650500603`*^9}, {
  3.574903473994944*^9, 3.574903484149876*^9}, {3.5776702440754642`*^9, 
  3.577670273015163*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"2", " ", "qsq", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"8", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["k", "2"], "+", "m3"}], ")"}], " ", "p1\[Nu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["k", "6"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["k", "2"], "+", "m3"}], ")"}], " ", "p1\[Mu]"}], 
          "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["k", "2"], "+", "m2"}], ")"}], " ", "p2\[Mu]"}]}],
          ")"}]}], "+", 
       RowBox[{"8", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["k", "2"], "+", "m2"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["k", "2"], "+", "m3"}], ")"}], " ", "p1\[Mu]"}], 
          "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["k", "6"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["k", "2"], "+", "m2"}], ")"}], " ", "p2\[Mu]"}]}],
          ")"}], " ", "p2\[Nu]"}], "-", 
       RowBox[{
        SuperscriptBox["k", "4"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["k", "2"], "+", "m2"}], ")"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["k", "2"], "+", "m3"}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "8"}], "+", "\[Delta]"}], ")"}], " ", 
        "\[Eta]\[Mu]\[Nu]"}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["k", "2"], "+", "m1"}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["k", "2"], "+", "m2"}], ")"}], "4"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["k", "2"], "+", "m3"}], ")"}], "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "8"}], "+", "\[Delta]"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "6"}], "+", "\[Delta]"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "4"}], "+", "\[Delta]"}], ")"}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["k", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["k", "2"], "+", "m3"}], ")"}], " ", "p1\[Nu]", " ", 
         
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["k", "2"], "+", "m3"}], ")"}], " ", "p1\[Mu]"}], 
           "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["k", "2"], "+", "m2"}], ")"}], " ", 
            "p2\[Mu]"}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["k", "2"], "+", "m2"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["k", "2"], "+", "m3"}], ")"}], " ", "p1\[Mu]"}], 
           "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["k", "2"], "+", "m2"}], ")"}], " ", 
            "p2\[Mu]"}]}], ")"}], " ", "p2\[Nu]"}]}], ")"}]}], "-", 
     RowBox[{
      SuperscriptBox["k", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["k", "2"], "+", "m2"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["k", "2"], "+", "m3"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "6"}], "+", "\[Delta]"}], ")"}], " ", 
      "\[Eta]\[Mu]\[Nu]"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["k", "2"], "+", "m1"}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["k", "2"], "+", "m2"}], ")"}], "3"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["k", "2"], "+", "m3"}], ")"}], "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "6"}], "+", "\[Delta]"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "4"}], "+", "\[Delta]"}], ")"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.5749003482155657`*^9, 3.574900397282271*^9}, {
   3.574901224849764*^9, 3.574901243739356*^9}, 3.5749017572444277`*^9, 
   3.574901892182584*^9, 3.5749031047355757`*^9, {3.5749031588367558`*^9, 
   3.574903169441737*^9}, {3.574903212988481*^9, 3.574903265493743*^9}, {
   3.5749034744616623`*^9, 3.574903485226489*^9}, 3.5749039615577087`*^9, 
   3.575024456561544*^9, 3.575037209136154*^9, 3.575039377105245*^9, 
   3.575043135943554*^9, 3.575071512099782*^9, 3.575121741757475*^9, 
   3.5751998212685747`*^9, 3.5754108225789013`*^9, 3.575414054634507*^9, 
   3.575414128647138*^9, 3.575431670068425*^9, 3.5754773996950607`*^9, 
   3.575478098534864*^9, 3.57548294393124*^9, 3.575484780813212*^9, {
   3.5754853737552567`*^9, 3.575485391985918*^9}, 3.5754911936709414`*^9, 
   3.57550379969281*^9, 3.5755039658637466`*^9, 3.5757411887625723`*^9, 
   3.575742897496097*^9, 3.575818541541054*^9, 3.5759271495634117`*^9, 
   3.575928278556176*^9, 3.5759305711289454`*^9, 3.575931316295546*^9, 
   3.575932808318329*^9, 3.5759330943719387`*^9, 3.575933680707403*^9, 
   3.575934961166813*^9, 3.5759352456907883`*^9, 3.575935881102968*^9, 
   3.575938363185979*^9, 3.57593862714336*^9, 3.5759394191002817`*^9, 
   3.575940275314741*^9, 3.57594061112265*^9, 3.575943012507538*^9, 
   3.575944522638999*^9, 3.575945942590623*^9, 3.576007710919854*^9, 
   3.5760086251129637`*^9, 3.576015069983117*^9, 3.576097315799981*^9, 
   3.576099977665805*^9, 3.576192441595172*^9, 3.5761950042973127`*^9, 
   3.576198782232785*^9, 3.5762459977491426`*^9, 3.576251943399746*^9, 
   3.576253353245831*^9, 3.576359020433177*^9, 3.576363205562458*^9, 
   3.57636410178935*^9, 3.576364227724944*^9, 3.576364308860017*^9, 
   3.576364446972472*^9, 3.57637254881353*^9, 3.576429136814*^9, 
   3.576536712799259*^9, 3.576539479854055*^9, 3.576539815640511*^9, 
   3.5766904354354067`*^9, 3.5766929019772463`*^9, 3.576712140493822*^9, 
   3.57679574650597*^9, 3.576983741330303*^9, 3.576983821364303*^9, 
   3.577215462248797*^9, 3.577278675518199*^9, 3.5772832686071587`*^9, 
   3.5772966624807568`*^9, 3.577383127924925*^9, 3.577401298147332*^9, 
   3.577662957543198*^9, 3.577663020492921*^9, 3.577670274641251*^9, 
   3.577675373136271*^9, 3.577676979702888*^9, 3.577816846100312*^9, 
   3.5778345063464518`*^9, 3.577915878491005*^9, 3.5779283641962748`*^9, 
   3.577930912878531*^9, 3.577931063535254*^9, 3.577934522851131*^9, 
   3.578330302846408*^9, 3.5783426183159227`*^9, 3.578344530044507*^9, 
   3.578494208063204*^9, 3.578756827600235*^9, 3.578849964227969*^9, 
   3.5788504783024483`*^9, 3.5788674911408978`*^9, 3.578953615727113*^9, 
   3.57900504755075*^9, 3.5790059043699903`*^9, 3.579006066069569*^9, 
   3.579006456900304*^9, 3.579007235737961*^9, 3.579023939816044*^9, 
   3.5791951535440187`*^9, 3.5792169157602053`*^9, 3.579282522406*^9, 
   3.579283974116014*^9, 3.579299470395026*^9, 3.579303911111755*^9, 
   3.579452397353187*^9, 3.5794563610592823`*^9, 3.57982089283971*^9, 
   3.579824020863618*^9, 3.580008824525156*^9, 3.580439176724121*^9, 
   3.580596066566815*^9, 3.5806429771996317`*^9, 3.580671599098812*^9, 
   3.5806992030059547`*^9, 3.58084594637869*^9, 3.581172089734984*^9, 
   3.581190371910972*^9, 3.581195626095956*^9, 3.5812689831645393`*^9, 
   3.58127093733146*^9, 3.5812763139178743`*^9, 3.5812918185811872`*^9, 
   3.581295522052093*^9, 3.5812976585469513`*^9, 3.5812982574475927`*^9, 
   3.5812988570268373`*^9, 3.581346644773817*^9, 3.581363536394248*^9, 
   3.581369198925891*^9, 3.5813695894487953`*^9, 3.5814420144810534`*^9, 
   3.581450814461768*^9, 3.581757931633772*^9, 3.5819154083993607`*^9, 
   3.582021754668507*^9, 3.582483475137041*^9, 3.584065516833695*^9, 
   3.584109846412675*^9, 3.584110077018704*^9, 3.58420870069386*^9, 
   3.584208909268894*^9, 3.584211108609633*^9, 3.5842112854720497`*^9, 
   3.584213627830373*^9, 3.5842141747538633`*^9, 3.5842214341906147`*^9, 
   3.58422410861558*^9, 3.584279782756023*^9, 3.58431709450109*^9, 
   3.584362256837635*^9, 3.58438337316427*^9, 3.584448826916868*^9, 
   3.5844533235998087`*^9, 3.584453405830868*^9, 3.584453609839066*^9, 
   3.5844538493873053`*^9, 3.5844795866703053`*^9, 3.584485196087447*^9, 
   3.584708510379219*^9, 3.5847203961501427`*^9, 3.5847255309862623`*^9, 
   3.584874769515232*^9, 3.5848760219644012`*^9, 3.58487956604624*^9, 
   3.591549635471657*^9, 3.603755726414506*^9, 3.603757468095469*^9, 
   3.603849890612577*^9, 3.603850216852721*^9, 3.603853965167159*^9, 
   3.6039255915325947`*^9, 3.604157610672423*^9, 3.6042364080129137`*^9, 
   3.605050464947919*^9, 3.60545224902628*^9, 3.605453025993805*^9, 
   3.6127948366700287`*^9, 3.612794963967465*^9, 3.612798702897789*^9, 
   3.612798801750823*^9, 3.6128004708488827`*^9, 3.6133203037659283`*^9, 
   3.613578445393116*^9, 3.67460637130641*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cijtemp", "=", 
   RowBox[{"Intfuncgen", "[", "integrandCijtemp", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5754829785813828`*^9, 3.575482980173191*^9}, {
  3.5754847863059807`*^9, 3.5754847893206453`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"C00temp", "=", 
   RowBox[{
    RowBox[{"c00", " ", 
     RowBox[{"D", "[", 
      RowBox[{"Cijtemp", ",", "\[Eta]\[Mu]\[Nu]"}], "]"}]}], "/.", 
    "subtry"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"C11temp", "=", 
   RowBox[{
    RowBox[{"c11", " ", 
     RowBox[{"D", "[", 
      RowBox[{"Cijtemp", ",", "p1\[Mu]", ",", "p1\[Nu]"}], "]"}]}], "/.", 
    "subtry"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"C12temp", "=", 
   RowBox[{
    RowBox[{"c12", " ", 
     RowBox[{"D", "[", 
      RowBox[{"Cijtemp", ",", "p1\[Mu]", ",", "p2\[Nu]"}], "]"}]}], "/.", 
    "subtry"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"C22temp", "=", 
   RowBox[{
    RowBox[{"c22", " ", 
     RowBox[{"D", "[", 
      RowBox[{"Cijtemp", ",", "p2\[Mu]", ",", "p2\[Nu]"}], "]"}]}], "/.", 
    "subtry"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.575482955815819*^9, 3.575482975374505*^9}, {
  3.575484938445628*^9, 3.575484976569477*^9}, {3.575498108963306*^9, 
  3.575498120837516*^9}, {3.57729663952792*^9, 3.577296651078128*^9}, {
  3.577675322044446*^9, 3.5776753315322533`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DefineIntegralFunction3", "[", 
   RowBox[{"funcname_", ",", "funcexpr_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"singlist", "=", 
      RowBox[{"Sort", "[", 
       RowBox[{"SingularityList", "[", 
        RowBox[{"{", 
         RowBox[{"m1temp", ",", "m2temp", ",", "m3temp"}], "}"}], "]"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"funcsinglist", "=", 
      RowBox[{"Collect", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Normal", "[", 
           RowBox[{"Simplify", "[", 
            RowBox[{"Series", "[", 
             RowBox[{
              RowBox[{"Series", "[", 
               RowBox[{"funcexpr", ",", 
                RowBox[{"{", 
                 RowBox[{"m1", ",", 
                  RowBox[{"singlist", "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", "0"}], "}"}], 
                ",", 
                RowBox[{"{", 
                 RowBox[{"m2", ",", 
                  RowBox[{"singlist", "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", "0"}], 
                 "}"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"m3", ",", 
                RowBox[{"singlist", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", "3"}], "]"}], "]"}], ",", "0"}], "}"}]}], 
             "]"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "singlist", "]"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"qsq", ",", 
          RowBox[{"Log", "[", "x_", "]"}]}], "}"}], ",", "FullSimplify"}], 
       "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"singlist2", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"singlist", "/.", 
         RowBox[{"m1temp", "\[Rule]", "m1temp_"}]}], "/.", 
        RowBox[{"m2temp", "\[Rule]", "m2temp_"}]}], "/.", 
       RowBox[{"m3temp", "\[Rule]", "m3temp_"}]}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"funcname", "[", 
         RowBox[{"qsqsub_", ",", 
          RowBox[{"singlist2", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{"singlist2", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
          RowBox[{"singlist2", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}], ":=", 
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{"funcsinglist", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "/.", 
          RowBox[{"qsq", "\[Rule]", "qsqsub"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "singlist", "]"}]}], "}"}]}], "]"}], ";"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.57901413783385*^9, 3.579014325937989*^9}, {
   3.579014547976462*^9, 3.579014550384428*^9}, {3.579014752081843*^9, 
   3.5790147649070177`*^9}, {3.579015630404708*^9, 3.5790157011872063`*^9}, {
   3.579015733662081*^9, 3.579015790749215*^9}, {3.579015854522386*^9, 
   3.5790158760769176`*^9}, {3.579015921525936*^9, 3.579015933441277*^9}, {
   3.579016053813599*^9, 3.579016186150105*^9}, {3.579016254715197*^9, 
   3.579016275169539*^9}, {3.5790163133645163`*^9, 3.579016350792935*^9}, {
   3.579016490272854*^9, 3.579016534589794*^9}, {3.579016657549486*^9, 
   3.5790166582117147`*^9}, {3.579016688907885*^9, 3.5790166906428337`*^9}, {
   3.5792987497757893`*^9, 3.579298756263137*^9}, {3.579298853761538*^9, 
   3.579298879486006*^9}, {3.579298931988661*^9, 3.5792989339866467`*^9}, {
   3.579298996409422*^9, 3.579298998808318*^9}, {3.579299340659553*^9, 
   3.579299392896328*^9}, 3.57929943963704*^9, {3.581757828348566*^9, 
   3.581757837070115*^9}, {3.58248343250801*^9, 3.582483434486802*^9}, 
   3.6128003900371637`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DefineIntegralFunction3noq", "[", 
   RowBox[{"funcname_", ",", "funcexpr_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"singlist", "=", 
      RowBox[{"Sort", "[", 
       RowBox[{"SingularityList", "[", 
        RowBox[{"{", 
         RowBox[{"m1temp", ",", "m2temp", ",", "m3temp"}], "}"}], "]"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"funcsinglist", "=", 
      RowBox[{"Collect", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Normal", "[", 
           RowBox[{"Simplify", "[", 
            RowBox[{"Series", "[", 
             RowBox[{
              RowBox[{"Series", "[", 
               RowBox[{"funcexpr", ",", 
                RowBox[{"{", 
                 RowBox[{"m1", ",", 
                  RowBox[{"singlist", "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", "0"}], "}"}], 
                ",", 
                RowBox[{"{", 
                 RowBox[{"m2", ",", 
                  RowBox[{"singlist", "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", "0"}], 
                 "}"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"m3", ",", 
                RowBox[{"singlist", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", "3"}], "]"}], "]"}], ",", "0"}], "}"}]}], 
             "]"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "singlist", "]"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"qsq", ",", 
          RowBox[{"Log", "[", "x_", "]"}]}], "}"}], ",", "FullSimplify"}], 
       "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"singlist2", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"singlist", "/.", 
         RowBox[{"m1temp", "\[Rule]", "m1temp_"}]}], "/.", 
        RowBox[{"m2temp", "\[Rule]", "m2temp_"}]}], "/.", 
       RowBox[{"m3temp", "\[Rule]", "m3temp_"}]}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"funcname", "[", 
         RowBox[{
          RowBox[{"singlist2", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{"singlist2", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
          RowBox[{"singlist2", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}], ":=", 
        RowBox[{"Evaluate", "[", 
         RowBox[{"funcsinglist", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "singlist", "]"}]}], "}"}]}], "]"}], ";"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.67460638285972*^9, 3.674606392482583*^9}}],

Cell[BoxData[
 RowBox[{"DefineIntegralFunction3", "[", 
  RowBox[{"C0func", ",", "C0temp"}], "]"}]], "Input",
 CellChangeTimes->{{3.5749009810253077`*^9, 3.574900988368102*^9}, 
   3.612800390038518*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefineIntegralFunction3", "[", 
   RowBox[{"C1func", ",", "C1temp"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefineIntegralFunction3", "[", 
   RowBox[{"C2func", ",", "C2temp"}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.574900994519381*^9, 3.5749010085697536`*^9}, 
   3.574901180537326*^9, 3.612800390039652*^9}],

Cell[BoxData[{
 RowBox[{"DefineIntegralFunction3", "[", 
  RowBox[{"C00func", ",", "C00temp"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"DefineIntegralFunction3", "[", 
  RowBox[{"C11func", ",", "C11temp"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"DefineIntegralFunction3", "[", 
  RowBox[{"C12func", ",", "C12temp"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"DefineIntegralFunction3", "[", 
  RowBox[{"C22func", ",", "C22temp"}], "]"}]}], "Input",
 CellChangeTimes->{{3.5749035939810133`*^9, 3.574903596019415*^9}, {
   3.574903664023815*^9, 3.574903670719805*^9}, {3.575498116770997*^9, 
   3.5754981249616213`*^9}, 3.6128003900407953`*^9}],

Cell[BoxData[
 RowBox[{"DefineIntegralFunction3noq", "[", 
  RowBox[{"C0func0", ",", 
   RowBox[{"C0temp", "/.", 
    RowBox[{"qsq", "\[Rule]", "0"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5749009810253077`*^9, 3.574900988368102*^9}, 
   3.612800390038518*^9, {3.674606425706779*^9, 3.6746064358663197`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefineIntegralFunction3noq", "[", 
   RowBox[{"C1func0", ",", 
    RowBox[{"C1temp", "/.", 
     RowBox[{"qsq", "\[Rule]", "0"}]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefineIntegralFunction3noq", "[", 
   RowBox[{"C2func0", ",", 
    RowBox[{"C2temp", "/.", 
     RowBox[{"qsq", "\[Rule]", "0"}]}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.574900994519381*^9, 3.5749010085697536`*^9}, 
   3.574901180537326*^9, 3.612800390039652*^9, {3.674606437483596*^9, 
   3.674606456604624*^9}}],

Cell[BoxData[{
 RowBox[{"DefineIntegralFunction3noq", "[", 
  RowBox[{"C00func0", ",", 
   RowBox[{"C00temp", "/.", 
    RowBox[{"qsq", "\[Rule]", "0"}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"DefineIntegralFunction3noq", "[", 
  RowBox[{"C11func0", ",", 
   RowBox[{"C11temp", "/.", 
    RowBox[{"qsq", "\[Rule]", "0"}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"DefineIntegralFunction3noq", "[", 
  RowBox[{"C12func0", ",", 
   RowBox[{"C12temp", "/.", 
    RowBox[{"qsq", "\[Rule]", "0"}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"DefineIntegralFunction3noq", "[", 
  RowBox[{"C22func0", ",", 
   RowBox[{"C22temp", "/.", 
    RowBox[{"qsq", "\[Rule]", "0"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5749035939810133`*^9, 3.574903596019415*^9}, {
   3.574903664023815*^9, 3.574903670719805*^9}, {3.575498116770997*^9, 
   3.5754981249616213`*^9}, 3.6128003900407953`*^9, {3.6746064406197433`*^9, 
   3.674606460725768*^9}}],

Cell[BoxData[
 RowBox[{"DefineIntegralFunction3noq", "[", 
  RowBox[{"C0func1", ",", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"C0temp", ",", "qsq"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5749009810253077`*^9, 3.574900988368102*^9}, 
   3.612800390038518*^9, {3.674606425706779*^9, 3.6746064358663197`*^9}, {
   3.6746064804372263`*^9, 3.674606486910696*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefineIntegralFunction3noq", "[", 
   RowBox[{"C1func1", ",", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"C1temp", ",", "qsq"}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefineIntegralFunction3noq", "[", 
   RowBox[{"C2func1", ",", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"C2temp", ",", "qsq"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.574900994519381*^9, 3.5749010085697536`*^9}, 
   3.574901180537326*^9, 3.612800390039652*^9, {3.674606437483596*^9, 
   3.674606456604624*^9}, {3.674606488820941*^9, 3.674606521470648*^9}}],

Cell[BoxData[{
 RowBox[{"DefineIntegralFunction3noq", "[", 
  RowBox[{"C00func1", ",", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"C00temp", ",", "qsq"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"DefineIntegralFunction3noq", "[", 
  RowBox[{"C11func1", ",", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"C11temp", ",", "qsq"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"DefineIntegralFunction3noq", "[", 
  RowBox[{"C12func1", ",", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"C12temp", ",", "qsq"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"DefineIntegralFunction3noq", "[", 
  RowBox[{"C22func1", ",", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"C22temp", ",", "qsq"}], "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5749035939810133`*^9, 3.574903596019415*^9}, {
   3.574903664023815*^9, 3.574903670719805*^9}, {3.575498116770997*^9, 
   3.5754981249616213`*^9}, 3.6128003900407953`*^9, {3.6746064406197433`*^9, 
   3.674606460725768*^9}, {3.674606494327248*^9, 3.674606525464456*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Need 4-pt integrals D0, D1, D2, D3, D00 for p1 = p2 = 0 and general m1, m2, m3\
\>", "Subsection",
 CellChangeTimes->{{3.574023579872418*^9, 3.574023598464611*^9}, {
  3.5741818782741623`*^9, 3.5741819009536943`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"integrandD0temp", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["k", "2"], "+", "m1"}], ")"}]}], "/", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["k", "2"], "+", "m2"}], ")"}]}], "/", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["k", "2"], "+", "m3"}], ")"}]}], "/", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["k", "2"], "+", "m4"}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5754850105398417`*^9, 3.57548502523773*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D0temp", "=", 
  RowBox[{
   RowBox[{"dd", " ", 
    RowBox[{"Intfuncgen", "[", "integrandD0temp", "]"}]}], "/.", 
   "subtry"}]}]], "Input",
 CellChangeTimes->{{3.575485028417182*^9, 3.5754850538713303`*^9}}],

Cell[BoxData[
 RowBox[{"16", " ", 
  SuperscriptBox["\[Pi]", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"m1", " ", 
       RowBox[{"Log", "[", "m1", "]"}]}], 
      RowBox[{"16", " ", 
       RowBox[{"(", 
        RowBox[{"m1", "-", "m2"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"m1", "-", "m3"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"m1", "-", "m4"}], ")"}], " ", 
       SuperscriptBox["\[Pi]", "2"]}]]}], "+", 
    FractionBox[
     RowBox[{"m2", " ", 
      RowBox[{"Log", "[", "m2", "]"}]}], 
     RowBox[{"16", " ", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "m2"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"m2", "-", "m3"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"m2", "-", "m4"}], ")"}], " ", 
      SuperscriptBox["\[Pi]", "2"]}]], "+", 
    FractionBox[
     RowBox[{"m3", " ", 
      RowBox[{"Log", "[", "m3", "]"}]}], 
     RowBox[{"16", " ", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "m3"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "m2"}], "+", "m3"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"m3", "-", "m4"}], ")"}], " ", 
      SuperscriptBox["\[Pi]", "2"]}]], "+", 
    FractionBox[
     RowBox[{"m4", " ", 
      RowBox[{"Log", "[", "m4", "]"}]}], 
     RowBox[{"16", " ", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "m4"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "m2"}], "+", "m4"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "m3"}], "+", "m4"}], ")"}], " ", 
      SuperscriptBox["\[Pi]", "2"]}]]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.575485034711784*^9, 3.575485054103401*^9}, 
   3.575485413817238*^9, 3.575491226221959*^9, 3.5755038264652767`*^9, 
   3.575503991148119*^9, 3.5757412280422297`*^9, 3.57574293636331*^9, 
   3.5758185795984793`*^9, 3.575927188956048*^9, 3.575928317938182*^9, 
   3.575930609213266*^9, 3.575931355500208*^9, 3.575932846093258*^9, 
   3.575933132131032*^9, 3.575933719312051*^9, 3.5759350001622257`*^9, 
   3.575935285181583*^9, 3.575935918975185*^9, 3.575938402292893*^9, 
   3.575938666295182*^9, 3.575939457149445*^9, 3.575940313512594*^9, 
   3.5759406495429783`*^9, 3.575943051259469*^9, 3.5759445614308987`*^9, 
   3.575945981030498*^9, 3.57600775083683*^9, 3.576008664870023*^9, 
   3.576015108933619*^9, 3.576097353931408*^9, 3.576100016121139*^9, 
   3.5761924799172792`*^9, 3.576195043952577*^9, 3.576198822475027*^9, 
   3.576246036883634*^9, 3.576251981230803*^9, 3.57625339363242*^9, 
   3.576359058749271*^9, 3.576363246196858*^9, 3.576364141914379*^9, 
   3.576364268229197*^9, 3.576364349533031*^9, 3.57636448635546*^9, 
   3.576372588724536*^9, 3.576429174572885*^9, 3.576536750779069*^9, 
   3.5765395187679253`*^9, 3.5765398537493343`*^9, 3.5766904744846497`*^9, 
   3.576692940037777*^9, 3.57671217927271*^9, 3.576795773185478*^9, 
   3.576983766508754*^9, 3.576983846356717*^9, 3.577215487831141*^9, 
   3.577278700046921*^9, 3.5772832938042593`*^9, 3.57729668975837*^9, 
   3.577383153476657*^9, 3.577401323262219*^9, 3.577663086150381*^9, 
   3.5776750171936607`*^9, 3.5776754857005997`*^9, 3.577677099079544*^9, 
   3.577816977530044*^9, 3.577834619522955*^9, 3.577915988768738*^9, 
   3.5779284737242813`*^9, 3.577931075802031*^9, 3.577934535352497*^9, 
   3.5783303155097*^9, 3.578342630224782*^9, 3.57834454155907*^9, 
   3.578494219655011*^9, 3.578756841682351*^9, 3.578849976026948*^9, 
   3.578850492428749*^9, 3.578867503095461*^9, 3.578953631562373*^9, 
   3.579005060543173*^9, 3.5790059160877733`*^9, 3.579006078504531*^9, 
   3.579006464886964*^9, 3.5790072377267523`*^9, 3.579008086840527*^9, 
   3.579016660171298*^9, 3.5790166995312243`*^9, 3.579023951656969*^9, 
   3.5791951657534*^9, 3.579216927595499*^9, 3.579282533987309*^9, 
   3.57928398606114*^9, 3.579303930170581*^9, 3.579452413951302*^9, 
   3.579456378931066*^9, 3.5798209101685457`*^9, 3.579824038956008*^9, 
   3.5800088424829082`*^9, 3.5804391932110023`*^9, 3.5805960869866858`*^9, 
   3.580642994299836*^9, 3.580671616622801*^9, 3.580699221028075*^9, 
   3.580845963692535*^9, 3.5811721100498323`*^9, 3.581190390407308*^9, 
   3.581195643541976*^9, 3.5812690004101667`*^9, 3.5812709542716837`*^9, 
   3.581276331241444*^9, 3.5812918359994*^9, 3.581295539263784*^9, 
   3.581297675258947*^9, 3.581298274495956*^9, 3.5812988739779577`*^9, 
   3.5813466674650583`*^9, 3.5813635629899187`*^9, 3.58136922300775*^9, 
   3.581369613268178*^9, 3.581442035208076*^9, 3.58145083787671*^9, 
   3.581757960496751*^9, 3.58191543666152*^9, 3.582021782036036*^9, 
   3.58248350331444*^9, 3.584065547214787*^9, 3.584109877414509*^9, 
   3.5841101074267282`*^9, 3.5842087312262297`*^9, 3.584208939337288*^9, 
   3.584211315626597*^9, 3.5842136579906263`*^9, 3.584214204710218*^9, 
   3.584221464244378*^9, 3.584224139451276*^9, 3.5842798134860983`*^9, 
   3.5843171251474867`*^9, 3.5843622878564997`*^9, 3.58438340364123*^9, 
   3.584448857625448*^9, 3.584453355578541*^9, 3.584453438050743*^9, 
   3.58445364061477*^9, 3.584453879684752*^9, 3.584479617309289*^9, 
   3.5844852265097513`*^9, 3.584708540963167*^9, 3.584720427223782*^9, 
   3.584725561668372*^9, 3.5848747996849422`*^9, 3.584876052486671*^9, 
   3.5848795965281477`*^9, 3.603755757809717*^9, 3.603757501272311*^9, 
   3.603849920957456*^9, 3.603850247450832*^9, 3.603853994029736*^9, 
   3.603925620320712*^9, 3.6041576383738937`*^9, 3.604236439642579*^9, 
   3.605050497170291*^9, 3.6054522806100082`*^9, 3.605453057614736*^9, 
   3.612794860080533*^9, 3.6127949835700407`*^9, 3.612798726872349*^9, 
   3.612798817558694*^9, 3.612800504954626*^9, 3.6133199373820257`*^9, 
   3.613320343767077*^9, 3.613578477691184*^9, 3.6148130481950607`*^9, 
   3.674606543313937*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"integrandD1temp", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"2", "/", "d"}], " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["k", "2"], "/", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["k", "2"], "+", "m1"}], ")"}]}], "/", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["k", "2"], "+", "m2"}], ")"}], "2"]}], "/", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["k", "2"], "+", "m3"}], ")"}]}], "/", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["k", "2"], "+", "m4"}], ")"}]}]}], "/.", 
    RowBox[{"d", "\[Rule]", 
     RowBox[{"4", "-", "\[Delta]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"integrandD2temp", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"2", "/", "d"}], " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["k", "2"], "/", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["k", "2"], "+", "m1"}], ")"}]}], "/", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["k", "2"], "+", "m2"}], ")"}]}], "/", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["k", "2"], "+", "m3"}], ")"}], "2"]}], "/", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["k", "2"], "+", "m4"}], ")"}]}]}], "/.", 
    RowBox[{"d", "\[Rule]", 
     RowBox[{"4", "-", "\[Delta]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"integrandD3temp", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"2", "/", "d"}], " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["k", "2"], "/", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["k", "2"], "+", "m1"}], ")"}]}], "/", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["k", "2"], "+", "m2"}], ")"}]}], "/", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["k", "2"], "+", "m3"}], ")"}]}], "/", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["k", "2"], "+", "m4"}], ")"}], "2"]}]}], "/.", 
    RowBox[{"d", "\[Rule]", 
     RowBox[{"4", "-", "\[Delta]"}]}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.575485068835237*^9, 3.575485120738412*^9}, {
  3.57767519894655*^9, 3.577675227490499*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"D1temp", "=", 
  RowBox[{
   RowBox[{"-", "dd"}], " ", 
   RowBox[{
   "Intfuncgen", "[", "integrandD1temp", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"D2temp", "=", 
  RowBox[{
   RowBox[{"-", "dd"}], " ", 
   RowBox[{
   "Intfuncgen", "[", "integrandD2temp", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"D3temp", "=", 
  RowBox[{
   RowBox[{"-", "dd"}], " ", 
   RowBox[{
   "Intfuncgen", "[", "integrandD3temp", 
    "]"}]}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.575485125934366*^9, 3.575485151418535*^9}, {
  3.575485237243656*^9, 3.575485237698687*^9}, {3.613319922975912*^9, 
  3.6133199321501923`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "16"}], " ", 
  SuperscriptBox["\[Pi]", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    FractionBox["m2", 
     RowBox[{"32", " ", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "m2"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"m2", "-", "m3"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"m2", "-", "m4"}], ")"}], " ", 
      SuperscriptBox["\[Pi]", "2"]}]], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["m1", "2"], " ", 
      RowBox[{"Log", "[", "m1", "]"}]}], 
     RowBox[{"32", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m1", "-", "m2"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "m3"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "m4"}], ")"}], " ", 
      SuperscriptBox["\[Pi]", "2"]}]], "+", 
    FractionBox[
     RowBox[{"m2", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["m2", "3"], "+", 
        RowBox[{"2", " ", "m1", " ", "m3", " ", "m4"}], "-", 
        RowBox[{"m2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"m3", " ", "m4"}], "+", 
           RowBox[{"m1", " ", 
            RowBox[{"(", 
             RowBox[{"m3", "+", "m4"}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
      RowBox[{"Log", "[", "m2", "]"}]}], 
     RowBox[{"32", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m1", "-", "m2"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m2", "-", "m3"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m2", "-", "m4"}], ")"}], "2"], " ", 
      SuperscriptBox["\[Pi]", "2"]}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["m3", "2"], " ", 
      RowBox[{"Log", "[", "m3", "]"}]}], 
     RowBox[{"32", " ", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "m3"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m2", "-", "m3"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"m3", "-", "m4"}], ")"}], " ", 
      SuperscriptBox["\[Pi]", "2"]}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["m4", "2"], " ", 
      RowBox[{"Log", "[", "m4", "]"}]}], 
     RowBox[{"32", " ", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "m4"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m2", "-", "m4"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "m3"}], "+", "m4"}], ")"}], " ", 
      SuperscriptBox["\[Pi]", "2"]}]]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.5754851334620256`*^9, 3.575485151760275*^9}, 
   3.575485237957575*^9, 3.575485414026136*^9, 3.57549122643036*^9, 
   3.575503826674211*^9, 3.5755039913916807`*^9, 3.575741228272266*^9, 
   3.5757429366240873`*^9, 3.575818579841455*^9, 3.5759271892066174`*^9, 
   3.575928318178528*^9, 3.575930609470294*^9, 3.575931355756001*^9, 
   3.575932846326412*^9, 3.5759331323645267`*^9, 3.575933719543247*^9, 
   3.5759350003859043`*^9, 3.575935285404949*^9, 3.575935919241797*^9, 
   3.575938402541052*^9, 3.5759386665746393`*^9, 3.575939457380842*^9, 
   3.575940313757991*^9, 3.575940649796879*^9, 3.575943051479282*^9, 
   3.575944561671377*^9, 3.575945981249181*^9, 3.5760077510567427`*^9, 
   3.576008665128105*^9, 3.5760151091671677`*^9, 3.576097354184353*^9, 
   3.576100016360208*^9, 3.576192480169691*^9, 3.576195044179431*^9, 
   3.576198822688588*^9, 3.57624603709592*^9, 3.576251981481688*^9, 
   3.576253393856606*^9, 3.57635905896844*^9, 3.576363246421652*^9, 
   3.576364142173952*^9, 3.5763642684832907`*^9, 3.57636434977099*^9, 
   3.576364486614077*^9, 3.576372588940572*^9, 3.576429174808331*^9, 
   3.576536750989402*^9, 3.576539519005745*^9, 3.576539853987096*^9, 
   3.576690474695641*^9, 3.5766929402489777`*^9, 3.576712179506568*^9, 
   3.576795773388871*^9, 3.576983766737238*^9, 3.576983846581143*^9, 
   3.577215488038548*^9, 3.577278700231367*^9, 3.577283293994624*^9, 
   3.577296690005501*^9, 3.577383153662348*^9, 3.5774013234455843`*^9, 
   3.5776630874597063`*^9, {3.5776752132862997`*^9, 3.577675230222495*^9}, 
   3.5776754870079813`*^9, 3.577677100256071*^9, 3.577816978903994*^9, 
   3.577834620689064*^9, 3.577915989965722*^9, 3.577928474887126*^9, 
   3.577931077221633*^9, 3.577934537207737*^9, 3.5783303171343727`*^9, 
   3.5783426315979147`*^9, 3.578344542892704*^9, 3.5784942210094624`*^9, 
   3.578756843396254*^9, 3.5788499774245577`*^9, 3.578850494071684*^9, 
   3.578867504434476*^9, 3.5789536333990593`*^9, 3.579005061907187*^9, 
   3.5790059176168413`*^9, 3.579006079945463*^9, 3.579006466009828*^9, 
   3.579007237838382*^9, 3.579016664137938*^9, 3.579016701122136*^9, 
   3.57902395369766*^9, 3.5791951680588083`*^9, 3.5792169296329527`*^9, 
   3.5792825360904493`*^9, 3.579283988125764*^9, 3.579303933071027*^9, 
   3.579452416065567*^9, 3.579456381145067*^9, 3.579820912322165*^9, 
   3.579824041281846*^9, 3.580008844640867*^9, 3.5804391952511253`*^9, 
   3.580596089430189*^9, 3.5806429970184793`*^9, 3.580671618809381*^9, 
   3.580699223314061*^9, 3.5808459659360743`*^9, 3.581172112488388*^9, 
   3.58119039288946*^9, 3.581195645808908*^9, 3.581269002564117*^9, 
   3.58127095647579*^9, 3.5812763333248167`*^9, 3.581291838174244*^9, 
   3.581295541347492*^9, 3.5812976773007727`*^9, 3.5812982765610943`*^9, 
   3.581298876112742*^9, 3.5813466702890263`*^9, 3.581363566406095*^9, 
   3.581369226054878*^9, 3.581369616299371*^9, 3.581442037638076*^9, 
   3.581450840802713*^9, 3.58175796424507*^9, 3.581915440103265*^9, 
   3.58202178551322*^9, 3.582483507074375*^9, 3.5840655510092487`*^9, 
   3.584109881234305*^9, 3.584110111211309*^9, 3.584208735061964*^9, 
   3.584208943113117*^9, 3.58421131939331*^9, 3.584213661793914*^9, 
   3.584214208478002*^9, 3.584221468014371*^9, 3.584224143253491*^9, 
   3.58427981732124*^9, 3.58431712902717*^9, 3.584362291670815*^9, 
   3.584383407473838*^9, 3.584448861635951*^9, 3.584453359760448*^9, 
   3.584453442218988*^9, 3.584453644462735*^9, 3.5844538834895287`*^9, 
   3.5844796211826572`*^9, 3.584485230344225*^9, 3.584708544785718*^9, 
   3.584720431213213*^9, 3.58472556556429*^9, 3.584874803475388*^9, 
   3.584876056283066*^9, 3.5848796003765078`*^9, 3.603755761310216*^9, 
   3.603757505147403*^9, 3.603849924377825*^9, 3.603850251026742*^9, 
   3.6038539976341867`*^9, 3.603925624330783*^9, 3.6041576465800734`*^9, 
   3.604236443510688*^9, 3.605050501225808*^9, 3.6054522846474857`*^9, 
   3.605453061611868*^9, 3.612794862364303*^9, 3.612794987122232*^9, 
   3.612798737575655*^9, 3.6127988193184147`*^9, 3.612800506833547*^9, {
   3.613319933501606*^9, 3.613319940021532*^9}, 3.61332034556533*^9, 
   3.613578479515424*^9, 3.6148130515961847`*^9, 3.674606545158496*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "16"}], " ", 
  SuperscriptBox["\[Pi]", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    FractionBox["m3", 
     RowBox[{"32", " ", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "m3"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "m2"}], "+", "m3"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"m3", "-", "m4"}], ")"}], " ", 
      SuperscriptBox["\[Pi]", "2"]}]], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["m1", "2"], " ", 
      RowBox[{"Log", "[", "m1", "]"}]}], 
     RowBox[{"32", " ", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "m2"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m1", "-", "m3"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "m4"}], ")"}], " ", 
      SuperscriptBox["\[Pi]", "2"]}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["m2", "2"], " ", 
      RowBox[{"Log", "[", "m2", "]"}]}], 
     RowBox[{"32", " ", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "m2"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m2", "-", "m3"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"m2", "-", "m4"}], ")"}], " ", 
      SuperscriptBox["\[Pi]", "2"]}]], "-", 
    FractionBox[
     RowBox[{"m3", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["m3", "3"]}], "+", 
        RowBox[{"m2", " ", "m3", " ", "m4"}], "+", 
        RowBox[{"m1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"m2", " ", 
            RowBox[{"(", 
             RowBox[{"m3", "-", 
              RowBox[{"2", " ", "m4"}]}], ")"}]}], "+", 
           RowBox[{"m3", " ", "m4"}]}], ")"}]}]}], ")"}], " ", 
      RowBox[{"Log", "[", "m3", "]"}]}], 
     RowBox[{"32", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m1", "-", "m3"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m2", "-", "m3"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m3", "-", "m4"}], ")"}], "2"], " ", 
      SuperscriptBox["\[Pi]", "2"]}]], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["m4", "2"], " ", 
      RowBox[{"Log", "[", "m4", "]"}]}], 
     RowBox[{"32", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m3", "-", "m4"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "m1"}], "+", "m4"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "m2"}], "+", "m4"}], ")"}], " ", 
      SuperscriptBox["\[Pi]", "2"]}]]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.5754851334620256`*^9, 3.575485151760275*^9}, 
   3.575485237957575*^9, 3.575485414026136*^9, 3.57549122643036*^9, 
   3.575503826674211*^9, 3.5755039913916807`*^9, 3.575741228272266*^9, 
   3.5757429366240873`*^9, 3.575818579841455*^9, 3.5759271892066174`*^9, 
   3.575928318178528*^9, 3.575930609470294*^9, 3.575931355756001*^9, 
   3.575932846326412*^9, 3.5759331323645267`*^9, 3.575933719543247*^9, 
   3.5759350003859043`*^9, 3.575935285404949*^9, 3.575935919241797*^9, 
   3.575938402541052*^9, 3.5759386665746393`*^9, 3.575939457380842*^9, 
   3.575940313757991*^9, 3.575940649796879*^9, 3.575943051479282*^9, 
   3.575944561671377*^9, 3.575945981249181*^9, 3.5760077510567427`*^9, 
   3.576008665128105*^9, 3.5760151091671677`*^9, 3.576097354184353*^9, 
   3.576100016360208*^9, 3.576192480169691*^9, 3.576195044179431*^9, 
   3.576198822688588*^9, 3.57624603709592*^9, 3.576251981481688*^9, 
   3.576253393856606*^9, 3.57635905896844*^9, 3.576363246421652*^9, 
   3.576364142173952*^9, 3.5763642684832907`*^9, 3.57636434977099*^9, 
   3.576364486614077*^9, 3.576372588940572*^9, 3.576429174808331*^9, 
   3.576536750989402*^9, 3.576539519005745*^9, 3.576539853987096*^9, 
   3.576690474695641*^9, 3.5766929402489777`*^9, 3.576712179506568*^9, 
   3.576795773388871*^9, 3.576983766737238*^9, 3.576983846581143*^9, 
   3.577215488038548*^9, 3.577278700231367*^9, 3.577283293994624*^9, 
   3.577296690005501*^9, 3.577383153662348*^9, 3.5774013234455843`*^9, 
   3.5776630874597063`*^9, {3.5776752132862997`*^9, 3.577675230222495*^9}, 
   3.5776754870079813`*^9, 3.577677100256071*^9, 3.577816978903994*^9, 
   3.577834620689064*^9, 3.577915989965722*^9, 3.577928474887126*^9, 
   3.577931077221633*^9, 3.577934537207737*^9, 3.5783303171343727`*^9, 
   3.5783426315979147`*^9, 3.578344542892704*^9, 3.5784942210094624`*^9, 
   3.578756843396254*^9, 3.5788499774245577`*^9, 3.578850494071684*^9, 
   3.578867504434476*^9, 3.5789536333990593`*^9, 3.579005061907187*^9, 
   3.5790059176168413`*^9, 3.579006079945463*^9, 3.579006466009828*^9, 
   3.579007237838382*^9, 3.579016664137938*^9, 3.579016701122136*^9, 
   3.57902395369766*^9, 3.5791951680588083`*^9, 3.5792169296329527`*^9, 
   3.5792825360904493`*^9, 3.579283988125764*^9, 3.579303933071027*^9, 
   3.579452416065567*^9, 3.579456381145067*^9, 3.579820912322165*^9, 
   3.579824041281846*^9, 3.580008844640867*^9, 3.5804391952511253`*^9, 
   3.580596089430189*^9, 3.5806429970184793`*^9, 3.580671618809381*^9, 
   3.580699223314061*^9, 3.5808459659360743`*^9, 3.581172112488388*^9, 
   3.58119039288946*^9, 3.581195645808908*^9, 3.581269002564117*^9, 
   3.58127095647579*^9, 3.5812763333248167`*^9, 3.581291838174244*^9, 
   3.581295541347492*^9, 3.5812976773007727`*^9, 3.5812982765610943`*^9, 
   3.581298876112742*^9, 3.5813466702890263`*^9, 3.581363566406095*^9, 
   3.581369226054878*^9, 3.581369616299371*^9, 3.581442037638076*^9, 
   3.581450840802713*^9, 3.58175796424507*^9, 3.581915440103265*^9, 
   3.58202178551322*^9, 3.582483507074375*^9, 3.5840655510092487`*^9, 
   3.584109881234305*^9, 3.584110111211309*^9, 3.584208735061964*^9, 
   3.584208943113117*^9, 3.58421131939331*^9, 3.584213661793914*^9, 
   3.584214208478002*^9, 3.584221468014371*^9, 3.584224143253491*^9, 
   3.58427981732124*^9, 3.58431712902717*^9, 3.584362291670815*^9, 
   3.584383407473838*^9, 3.584448861635951*^9, 3.584453359760448*^9, 
   3.584453442218988*^9, 3.584453644462735*^9, 3.5844538834895287`*^9, 
   3.5844796211826572`*^9, 3.584485230344225*^9, 3.584708544785718*^9, 
   3.584720431213213*^9, 3.58472556556429*^9, 3.584874803475388*^9, 
   3.584876056283066*^9, 3.5848796003765078`*^9, 3.603755761310216*^9, 
   3.603757505147403*^9, 3.603849924377825*^9, 3.603850251026742*^9, 
   3.6038539976341867`*^9, 3.603925624330783*^9, 3.6041576465800734`*^9, 
   3.604236443510688*^9, 3.605050501225808*^9, 3.6054522846474857`*^9, 
   3.605453061611868*^9, 3.612794862364303*^9, 3.612794987122232*^9, 
   3.612798737575655*^9, 3.6127988193184147`*^9, 3.612800506833547*^9, {
   3.613319933501606*^9, 3.613319940021532*^9}, 3.61332034556533*^9, 
   3.613578479515424*^9, 3.6148130515961847`*^9, 3.67460654755368*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "16"}], " ", 
  SuperscriptBox["\[Pi]", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    FractionBox["m4", 
     RowBox[{"32", " ", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "m4"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "m2"}], "+", "m4"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "m3"}], "+", "m4"}], ")"}], " ", 
      SuperscriptBox["\[Pi]", "2"]}]], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["m1", "2"], " ", 
      RowBox[{"Log", "[", "m1", "]"}]}], 
     RowBox[{"32", " ", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "m2"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "m3"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m1", "-", "m4"}], ")"}], "2"], " ", 
      SuperscriptBox["\[Pi]", "2"]}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["m2", "2"], " ", 
      RowBox[{"Log", "[", "m2", "]"}]}], 
     RowBox[{"32", " ", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "m2"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"m2", "-", "m3"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m2", "-", "m4"}], ")"}], "2"], " ", 
      SuperscriptBox["\[Pi]", "2"]}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["m3", "2"], " ", 
      RowBox[{"Log", "[", "m3", "]"}]}], 
     RowBox[{"32", " ", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "m3"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "m2"}], "+", "m3"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m3", "-", "m4"}], ")"}], "2"], " ", 
      SuperscriptBox["\[Pi]", "2"]}]], "-", 
    FractionBox[
     RowBox[{"m4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"m2", " ", "m3", " ", "m4"}], "-", 
        SuperscriptBox["m4", "3"], "+", 
        RowBox[{"m1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"m3", " ", "m4"}], "+", 
           RowBox[{"m2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "m3"}], "+", "m4"}], ")"}]}]}], 
          ")"}]}]}], ")"}], " ", 
      RowBox[{"Log", "[", "m4", "]"}]}], 
     RowBox[{"32", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m1", "-", "m4"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m2", "-", "m4"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m3", "-", "m4"}], ")"}], "2"], " ", 
      SuperscriptBox["\[Pi]", "2"]}]]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.5754851334620256`*^9, 3.575485151760275*^9}, 
   3.575485237957575*^9, 3.575485414026136*^9, 3.57549122643036*^9, 
   3.575503826674211*^9, 3.5755039913916807`*^9, 3.575741228272266*^9, 
   3.5757429366240873`*^9, 3.575818579841455*^9, 3.5759271892066174`*^9, 
   3.575928318178528*^9, 3.575930609470294*^9, 3.575931355756001*^9, 
   3.575932846326412*^9, 3.5759331323645267`*^9, 3.575933719543247*^9, 
   3.5759350003859043`*^9, 3.575935285404949*^9, 3.575935919241797*^9, 
   3.575938402541052*^9, 3.5759386665746393`*^9, 3.575939457380842*^9, 
   3.575940313757991*^9, 3.575940649796879*^9, 3.575943051479282*^9, 
   3.575944561671377*^9, 3.575945981249181*^9, 3.5760077510567427`*^9, 
   3.576008665128105*^9, 3.5760151091671677`*^9, 3.576097354184353*^9, 
   3.576100016360208*^9, 3.576192480169691*^9, 3.576195044179431*^9, 
   3.576198822688588*^9, 3.57624603709592*^9, 3.576251981481688*^9, 
   3.576253393856606*^9, 3.57635905896844*^9, 3.576363246421652*^9, 
   3.576364142173952*^9, 3.5763642684832907`*^9, 3.57636434977099*^9, 
   3.576364486614077*^9, 3.576372588940572*^9, 3.576429174808331*^9, 
   3.576536750989402*^9, 3.576539519005745*^9, 3.576539853987096*^9, 
   3.576690474695641*^9, 3.5766929402489777`*^9, 3.576712179506568*^9, 
   3.576795773388871*^9, 3.576983766737238*^9, 3.576983846581143*^9, 
   3.577215488038548*^9, 3.577278700231367*^9, 3.577283293994624*^9, 
   3.577296690005501*^9, 3.577383153662348*^9, 3.5774013234455843`*^9, 
   3.5776630874597063`*^9, {3.5776752132862997`*^9, 3.577675230222495*^9}, 
   3.5776754870079813`*^9, 3.577677100256071*^9, 3.577816978903994*^9, 
   3.577834620689064*^9, 3.577915989965722*^9, 3.577928474887126*^9, 
   3.577931077221633*^9, 3.577934537207737*^9, 3.5783303171343727`*^9, 
   3.5783426315979147`*^9, 3.578344542892704*^9, 3.5784942210094624`*^9, 
   3.578756843396254*^9, 3.5788499774245577`*^9, 3.578850494071684*^9, 
   3.578867504434476*^9, 3.5789536333990593`*^9, 3.579005061907187*^9, 
   3.5790059176168413`*^9, 3.579006079945463*^9, 3.579006466009828*^9, 
   3.579007237838382*^9, 3.579016664137938*^9, 3.579016701122136*^9, 
   3.57902395369766*^9, 3.5791951680588083`*^9, 3.5792169296329527`*^9, 
   3.5792825360904493`*^9, 3.579283988125764*^9, 3.579303933071027*^9, 
   3.579452416065567*^9, 3.579456381145067*^9, 3.579820912322165*^9, 
   3.579824041281846*^9, 3.580008844640867*^9, 3.5804391952511253`*^9, 
   3.580596089430189*^9, 3.5806429970184793`*^9, 3.580671618809381*^9, 
   3.580699223314061*^9, 3.5808459659360743`*^9, 3.581172112488388*^9, 
   3.58119039288946*^9, 3.581195645808908*^9, 3.581269002564117*^9, 
   3.58127095647579*^9, 3.5812763333248167`*^9, 3.581291838174244*^9, 
   3.581295541347492*^9, 3.5812976773007727`*^9, 3.5812982765610943`*^9, 
   3.581298876112742*^9, 3.5813466702890263`*^9, 3.581363566406095*^9, 
   3.581369226054878*^9, 3.581369616299371*^9, 3.581442037638076*^9, 
   3.581450840802713*^9, 3.58175796424507*^9, 3.581915440103265*^9, 
   3.58202178551322*^9, 3.582483507074375*^9, 3.5840655510092487`*^9, 
   3.584109881234305*^9, 3.584110111211309*^9, 3.584208735061964*^9, 
   3.584208943113117*^9, 3.58421131939331*^9, 3.584213661793914*^9, 
   3.584214208478002*^9, 3.584221468014371*^9, 3.584224143253491*^9, 
   3.58427981732124*^9, 3.58431712902717*^9, 3.584362291670815*^9, 
   3.584383407473838*^9, 3.584448861635951*^9, 3.584453359760448*^9, 
   3.584453442218988*^9, 3.584453644462735*^9, 3.5844538834895287`*^9, 
   3.5844796211826572`*^9, 3.584485230344225*^9, 3.584708544785718*^9, 
   3.584720431213213*^9, 3.58472556556429*^9, 3.584874803475388*^9, 
   3.584876056283066*^9, 3.5848796003765078`*^9, 3.603755761310216*^9, 
   3.603757505147403*^9, 3.603849924377825*^9, 3.603850251026742*^9, 
   3.6038539976341867`*^9, 3.603925624330783*^9, 3.6041576465800734`*^9, 
   3.604236443510688*^9, 3.605050501225808*^9, 3.6054522846474857`*^9, 
   3.605453061611868*^9, 3.612794862364303*^9, 3.612794987122232*^9, 
   3.612798737575655*^9, 3.6127988193184147`*^9, 3.612800506833547*^9, {
   3.613319933501606*^9, 3.613319940021532*^9}, 3.61332034556533*^9, 
   3.613578479515424*^9, 3.6148130515961847`*^9, 3.674606550077301*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Dij", " ", "with", " ", 
     SuperscriptBox["p1", "2"]}], "=", 
    RowBox[{
     SuperscriptBox["p2", "2"], "=", 
     RowBox[{
      SuperscriptBox["p3", "2"], "=", 
      RowBox[{
       RowBox[{
       "0", " ", "and", " ", "expanded", " ", "to", " ", "zeroth", " ", 
        "order", " ", "around", " ", "p1dotp2"}], "=", 
       RowBox[{"p1dotp3", "=", 
        RowBox[{"p2dotp3", "=", "0"}]}]}]}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Use", " ", 
     RowBox[{"identity", ":", " ", 
      RowBox[{"\[Integral]", " ", 
       RowBox[{
        SuperscriptBox["d", "4"], "k", " ", 
        SuperscriptBox["k", "\[Mu]"], 
        SuperscriptBox["k", "\[Nu]"], 
        SuperscriptBox["k", "\[Rho]"], 
        SuperscriptBox["k", "\[Sigma]"], 
        SuperscriptBox["k", "\[Alpha]"], 
        SuperscriptBox["k", "\[Beta]"], 
        RowBox[{"f", "[", 
         SuperscriptBox["k", "2"], "]"}]}]}]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"1", "/", "192"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Eta]", "\[Mu]\[Nu]"], 
        SuperscriptBox["\[Eta]", "\[Rho]\[Sigma]"], 
        SuperscriptBox["\[Eta]", "\[Alpha]\[Beta]"]}], "+", "perms"}], ")"}], 
     
     RowBox[{"\[Integral]", " ", 
      RowBox[{
       SuperscriptBox["d", "4"], "k", " ", 
       SuperscriptBox["k", "6"], 
       RowBox[{"f", "[", 
        SuperscriptBox["k", "2"], "]"}]}]}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"integrandDijtemp", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Expand", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Normal", "[", 
                RowBox[{"Series", "[", 
                 RowBox[{
                  RowBox[{"k\[Mu]", " ", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"k\[Nu]", "/", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["k", "2"], "+", "m1"}], ")"}]}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["k", "2"], "+", 
                    RowBox[{"2", "\[Epsilon]", " ", "kdotp1"}], "+", "m2"}], 
                    ")"}]}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["k", "2"], "+", 
                    RowBox[{"2", "\[Epsilon]", " ", "kdotp2"}], "+", "m3"}], 
                    ")"}]}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["k", "2"], "+", 
                    RowBox[{"2", "\[Epsilon]", " ", "kdotp3"}], "+", "m4"}], 
                    ")"}]}]}], ",", 
                  RowBox[{"{", 
                   RowBox[{"\[Epsilon]", ",", "0", ",", "2"}], "}"}]}], "]"}],
                 "]"}], "/.", 
               RowBox[{
                SuperscriptBox["\[Epsilon]", "k_"], "\[RuleDelayed]", 
                RowBox[{"1", "/;", 
                 RowBox[{"EvenQ", "[", "k", "]"}]}]}]}], "/.", 
              RowBox[{"\[Epsilon]", "\[Rule]", "0"}]}], "]"}], "/.", 
            RowBox[{
             RowBox[{
              SuperscriptBox["kdotp3", "2"], " ", "k\[Mu]", " ", "k\[Nu]"}], 
             "\[Rule]", 
             RowBox[{
              RowBox[{"1", "/", 
               RowBox[{"(", 
                RowBox[{"d", 
                 RowBox[{"(", 
                  RowBox[{"d", "+", "2"}], ")"}]}], ")"}]}], 
              RowBox[{"(", 
               RowBox[{"2", "p3\[Mu]", " ", "p3\[Nu]", " ", 
                SuperscriptBox["k", "4"]}], ")"}]}]}]}], "/.", 
           RowBox[{
            RowBox[{
             SuperscriptBox["kdotp2", "2"], " ", "k\[Mu]", " ", "k\[Nu]"}], 
            "\[Rule]", 
            RowBox[{
             RowBox[{"1", "/", 
              RowBox[{"(", 
               RowBox[{"d", 
                RowBox[{"(", 
                 RowBox[{"d", "+", "2"}], ")"}]}], ")"}]}], 
             RowBox[{"(", 
              RowBox[{"2", "p2\[Mu]", " ", "p2\[Nu]", " ", 
               SuperscriptBox["k", "4"]}], ")"}]}]}]}], "/.", 
          RowBox[{
           RowBox[{
            SuperscriptBox["kdotp1", "2"], " ", "k\[Mu]", " ", "k\[Nu]"}], 
           "\[Rule]", 
           RowBox[{
            RowBox[{"1", "/", 
             RowBox[{"(", 
              RowBox[{"d", 
               RowBox[{"(", 
                RowBox[{"d", "+", "2"}], ")"}]}], ")"}]}], 
            RowBox[{"(", 
             RowBox[{"2", "p1\[Mu]", " ", "p1\[Nu]", " ", 
              SuperscriptBox["k", "4"]}], ")"}]}]}]}], "/.", 
         RowBox[{
          RowBox[{"kdotp1", " ", "kdotp2", " ", "k\[Mu]", " ", "k\[Nu]"}], 
          "\[Rule]", 
          RowBox[{
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"d", 
              RowBox[{"(", 
               RowBox[{"d", "+", "2"}], ")"}]}], ")"}]}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"p1\[Mu]", " ", "p2\[Nu]"}], "+", 
             RowBox[{"p2\[Mu]", " ", "p1\[Nu]"}]}], ")"}], 
           SuperscriptBox["k", "4"]}]}]}], "/.", 
        RowBox[{
         RowBox[{"kdotp1", " ", "kdotp3", " ", "k\[Mu]", " ", "k\[Nu]"}], 
         "\[Rule]", 
         RowBox[{
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{"d", 
             RowBox[{"(", 
              RowBox[{"d", "+", "2"}], ")"}]}], ")"}]}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"p1\[Mu]", " ", "p3\[Nu]"}], "+", 
            RowBox[{"p3\[Mu]", " ", "p1\[Nu]"}]}], ")"}], 
          SuperscriptBox["k", "4"]}]}]}], "/.", 
       RowBox[{
        RowBox[{"kdotp2", " ", "kdotp3", " ", "k\[Mu]", " ", "k\[Nu]"}], 
        "\[Rule]", 
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"d", 
            RowBox[{"(", 
             RowBox[{"d", "+", "2"}], ")"}]}], ")"}]}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"p2\[Mu]", " ", "p3\[Nu]"}], "+", 
           RowBox[{"p3\[Mu]", " ", "p2\[Nu]"}]}], ")"}], 
         SuperscriptBox["k", "4"]}]}]}], "/.", 
      RowBox[{
       RowBox[{"k\[Mu]", " ", "k\[Nu]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"1", "/", "d"}], " ", "\[Eta]\[Mu]\[Nu]", " ", 
        SuperscriptBox["k", "2"]}]}]}], "/.", 
     RowBox[{"d", "\[Rule]", 
      RowBox[{"4", "-", "\[Delta]"}]}]}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.574900226988413*^9, 3.574900264108863*^9}, {
   3.574900328087408*^9, 3.574900396959166*^9}, {3.574901224333816*^9, 
   3.574901243102832*^9}, {3.574901702649322*^9, 3.5749017754695377`*^9}, {
   3.574901849582118*^9, 3.5749019113833723`*^9}, {3.5749026103462667`*^9, 
   3.574902628406314*^9}, {3.574903114210644*^9, 3.5749032650500603`*^9}, {
   3.574903473994944*^9, 3.574903484149876*^9}, {3.5776702440754642`*^9, 
   3.577670273015163*^9}, {3.613312950631494*^9, 3.6133129529209347`*^9}, {
   3.6133129939484167`*^9, 3.613312998708416*^9}, {3.613313062400214*^9, 
   3.613313064736075*^9}, {3.613313362498254*^9, 3.6133133933291817`*^9}, 
   3.613313951707707*^9, {3.613314020655747*^9, 3.613314104077064*^9}, 
   3.613319946536448*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Dijtemp", "=", 
   RowBox[{"Intfuncgen", "[", "integrandDijtemp", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5754829785813828`*^9, 3.575482980173191*^9}, {
  3.5754847863059807`*^9, 3.5754847893206453`*^9}, {3.613314168216404*^9, 
  3.613314170560111*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"D00temp", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "dd"}], " ", 
     RowBox[{"D", "[", 
      RowBox[{"Dijtemp", ",", "\[Eta]\[Mu]\[Nu]"}], "]"}]}], "/.", 
    "subtry"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"D11temp", "=", 
   RowBox[{
    RowBox[{"dd", " ", 
     RowBox[{"D", "[", 
      RowBox[{"Dijtemp", ",", "p1\[Mu]", ",", "p1\[Nu]"}], "]"}]}], "/.", 
    "subtry"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"D12temp", "=", 
   RowBox[{
    RowBox[{"dd", " ", 
     RowBox[{"D", "[", 
      RowBox[{"Dijtemp", ",", "p1\[Mu]", ",", "p2\[Nu]"}], "]"}]}], "/.", 
    "subtry"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"D22temp", "=", 
   RowBox[{
    RowBox[{"dd", " ", 
     RowBox[{"D", "[", 
      RowBox[{"Dijtemp", ",", "p2\[Mu]", ",", "p2\[Nu]"}], "]"}]}], "/.", 
    "subtry"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.575482955815819*^9, 3.575482975374505*^9}, {
   3.575484938445628*^9, 3.575484976569477*^9}, {3.575498108963306*^9, 
   3.575498120837516*^9}, {3.57729663952792*^9, 3.577296651078128*^9}, {
   3.577675322044446*^9, 3.5776753315322533`*^9}, {3.6133141726630507`*^9, 
   3.61331417992109*^9}, {3.61331850765359*^9, 3.613318510997018*^9}, {
   3.6133190641145163`*^9, 3.613319067041044*^9}, 3.613319950684722*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DefineIntegralFunction4", "[", 
   RowBox[{"funcname_", ",", "funcexpr_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"singlist", "=", 
      RowBox[{"Sort", "[", 
       RowBox[{"SingularityList", "[", 
        RowBox[{"{", 
         RowBox[{"m1temp", ",", "m2temp", ",", "m3temp", ",", "m4temp"}], 
         "}"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"funcsinglist", "=", 
      RowBox[{"Collect", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Normal", "[", 
           RowBox[{"Simplify", "[", 
            RowBox[{"Series", "[", 
             RowBox[{
              RowBox[{"Series", "[", 
               RowBox[{
                RowBox[{"Series", "[", 
                 RowBox[{
                  RowBox[{"Series", "[", 
                   RowBox[{"funcexpr", ",", 
                    RowBox[{"{", 
                    RowBox[{"m1", ",", 
                    RowBox[{"singlist", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", "0"}], 
                    "}"}]}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"m2", ",", 
                    RowBox[{"singlist", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", "0"}], 
                   "}"}]}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"m3", ",", 
                  RowBox[{"singlist", "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", "3"}], "]"}], "]"}], ",", "0"}], 
                 "}"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"m4", ",", 
                RowBox[{"singlist", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", "4"}], "]"}], "]"}], ",", "0"}], "}"}]}], 
             "]"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "singlist", "]"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"qsq", ",", 
          RowBox[{"Log", "[", "x_", "]"}]}], "}"}], ",", "FullSimplify"}], 
       "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"singlist2", "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"singlist", "/.", 
          RowBox[{"m1temp", "\[Rule]", "m1temp_"}]}], "/.", 
         RowBox[{"m2temp", "\[Rule]", "m2temp_"}]}], "/.", 
        RowBox[{"m3temp", "\[Rule]", "m3temp_"}]}], "/.", 
       RowBox[{"m4temp", "\[Rule]", "m4temp_"}]}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"funcname", "[", 
         RowBox[{
          RowBox[{"singlist2", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{"singlist2", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
          RowBox[{"singlist2", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "3"}], "]"}], "]"}], ",", 
          RowBox[{"singlist2", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "4"}], "]"}], "]"}]}], "]"}], ":=", 
        RowBox[{"Evaluate", "[", 
         RowBox[{"funcsinglist", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "singlist", "]"}]}], "}"}]}], "]"}], ";"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.57901413783385*^9, 3.579014325937989*^9}, {
  3.579014547976462*^9, 3.579014550384428*^9}, {3.579014752081843*^9, 
  3.5790147649070177`*^9}, {3.579015630404708*^9, 3.5790157011872063`*^9}, {
  3.579015733662081*^9, 3.579015790749215*^9}, {3.579015854522386*^9, 
  3.5790158760769176`*^9}, {3.579015921525936*^9, 3.579015933441277*^9}, {
  3.579016053813599*^9, 3.579016186150105*^9}, {3.579016254715197*^9, 
  3.579016275169539*^9}, {3.5790163133645163`*^9, 3.579016350792935*^9}, {
  3.579016490272854*^9, 3.579016534589794*^9}, {3.579016657549486*^9, 
  3.5790166582117147`*^9}, {3.579016688907885*^9, 3.5790166906428337`*^9}, {
  3.581757844274192*^9, 3.581757857321286*^9}, {3.582483388896821*^9, 
  3.582483407426077*^9}, {3.614813146347336*^9, 3.614813154265102*^9}}],

Cell[BoxData[
 RowBox[{"Series", "[", 
  RowBox[{
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{"Series", "[", 
        RowBox[{"D0temp", ",", 
         RowBox[{"{", 
          RowBox[{"m1", ",", "0", ",", "0"}], "}"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"m2", ",", "0", ",", "0"}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"m3", ",", "m3temp", ",", "0"}], "}"}]}], "]"}], ",", 
   RowBox[{"{", "m4"}]}]}]], "Input",
 CellChangeTimes->{{3.614813262806082*^9, 3.614813284973069*^9}},
 EmphasizeSyntaxErrors->True],

Cell[CellGroupData[{

Cell[BoxData["singlist2"], "Input",
 CellChangeTimes->{{3.614813234462207*^9, 3.61481323940429*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "m2temp_"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"m1temp_", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"m1temp_", ",", "m1temp_"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"m1temp_", ",", "m2temp_"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.614813239636723*^9, 3.6746066070842047`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["funcsinglist"], "Input",
 CellChangeTimes->{{3.6148132232539988`*^9, 3.614813225796831*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["psq", 
      RowBox[{"6", " ", "m2"}]]}], "-", 
    FractionBox[
     RowBox[{"4", "+", "\[Delta]", "-", 
      RowBox[{"2", " ", "EulerGamma", " ", "\[Delta]"}]}], 
     RowBox[{"4", " ", "\[Delta]"}]], "-", 
    FractionBox[
     RowBox[{"Log", "[", "16", "]"}], "4"], "+", 
    FractionBox[
     RowBox[{"Log", "[", "m2", "]"}], "2"], "-", 
    FractionBox[
     RowBox[{"Log", "[", "\[Pi]", "]"}], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["psq", 
      RowBox[{"6", " ", "m2temp"}]]}], "-", 
    FractionBox[
     RowBox[{"4", "+", "\[Delta]", "-", 
      RowBox[{"2", " ", "EulerGamma", " ", "\[Delta]"}]}], 
     RowBox[{"4", " ", "\[Delta]"}]], "-", 
    RowBox[{"Log", "[", "2", "]"}], "+", 
    FractionBox[
     RowBox[{"Log", "[", "m2temp", "]"}], "2"], "-", 
    FractionBox[
     RowBox[{"Log", "[", "\[Pi]", "]"}], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["3", "4"]}], "+", 
    FractionBox["EulerGamma", "2"], "-", 
    FractionBox["psq", 
     RowBox[{"3", " ", "m1temp"}]], "-", 
    FractionBox["1", "\[Delta]"], "-", 
    RowBox[{"Log", "[", "2", "]"}], "+", 
    FractionBox[
     RowBox[{"Log", "[", "m1temp", "]"}], "2"], "-", 
    FractionBox[
     RowBox[{"Log", "[", "\[Pi]", "]"}], "2"]}], ",", 
   RowBox[{
    FractionBox["EulerGamma", "2"], "-", 
    FractionBox["psq", 
     RowBox[{"12", " ", "m1temp"}]], "-", 
    FractionBox["1", "\[Delta]"], "-", 
    RowBox[{"Log", "[", "2", "]"}], "+", 
    FractionBox[
     RowBox[{"Log", "[", "m1temp", "]"}], "2"], "-", 
    FractionBox[
     RowBox[{"Log", "[", "\[Pi]", "]"}], "2"]}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", "EulerGamma"}], "+", 
       FractionBox[
        RowBox[{"2", " ", "m1temp"}], 
        RowBox[{
         RowBox[{"-", "m1temp"}], "+", "m2temp"}]], "-", 
       FractionBox["4", "\[Delta]"]}], ")"}]}], "-", 
    FractionBox[
     RowBox[{"m1temp", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["m1temp", "2"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["m2temp", "2"]}]}], ")"}], " ", 
      RowBox[{"Log", "[", "2", "]"}]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"m1temp", "-", "m2temp"}], ")"}], "3"]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["m2temp", "3"], " ", 
      RowBox[{"Log", "[", "16", "]"}]}], 
     RowBox[{"4", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m1temp", "-", "m2temp"}], ")"}], "3"]}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["m1temp", "2"], " ", "m2temp", " ", 
      RowBox[{"Log", "[", "4096", "]"}]}], 
     RowBox[{"4", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m1temp", "-", "m2temp"}], ")"}], "3"]}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["m1temp", "2"], " ", 
      RowBox[{"Log", "[", "m1temp", "]"}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m1temp", "-", "m2temp"}], ")"}], "2"]}]], "+", 
    FractionBox[
     RowBox[{"m2temp", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "m1temp"}], "+", "m2temp"}], ")"}], " ", 
      RowBox[{"Log", "[", "m2temp", "]"}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m1temp", "-", "m2temp"}], ")"}], "2"]}]], "+", 
    RowBox[{"psq", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SuperscriptBox["m1temp", "2"]}], "-", 
         RowBox[{"5", " ", "m1temp", " ", "m2temp"}], "+", 
         SuperscriptBox["m2temp", "2"]}], 
        RowBox[{"6", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"m1temp", "-", "m2temp"}], ")"}], "3"]}]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["m1temp", "2"], " ", "m2temp", " ", 
         RowBox[{"Log", "[", "m1temp", "]"}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"m1temp", "-", "m2temp"}], ")"}], "4"]], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["m1temp", "2"], " ", "m2temp", " ", 
         RowBox[{"Log", "[", "m2temp", "]"}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"m1temp", "-", "m2temp"}], ")"}], "4"]]}], ")"}]}], "-", 
    FractionBox[
     RowBox[{"Log", "[", "\[Pi]", "]"}], "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.614813226136199*^9, 3.67460660711133*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D0func", "[", 
  RowBox[{"0", ",", "0", ",", "x", ",", "y"}], "]"}]], "Input",
 CellChangeTimes->{{3.614813183503829*^9, 3.614813187574574*^9}}],

Cell[BoxData[
 RowBox[{"D0func", "[", 
  RowBox[{"0", ",", "0", ",", "x", ",", "y"}], "]"}]], "Output",
 CellChangeTimes->{3.614813188061748*^9, 3.674606607126555*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["D0temp"], "Input",
 CellChangeTimes->{{3.6148130620100718`*^9, 3.6148130654894238`*^9}, {
  3.6148131694531507`*^9, 3.614813170580662*^9}}],

Cell[BoxData[
 RowBox[{"16", " ", 
  SuperscriptBox["\[Pi]", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"m1", " ", 
       RowBox[{"Log", "[", "m1", "]"}]}], 
      RowBox[{"16", " ", 
       RowBox[{"(", 
        RowBox[{"m1", "-", "m2"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"m1", "-", "m3"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"m1", "-", "m4"}], ")"}], " ", 
       SuperscriptBox["\[Pi]", "2"]}]]}], "+", 
    FractionBox[
     RowBox[{"m2", " ", 
      RowBox[{"Log", "[", "m2", "]"}]}], 
     RowBox[{"16", " ", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "m2"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"m2", "-", "m3"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"m2", "-", "m4"}], ")"}], " ", 
      SuperscriptBox["\[Pi]", "2"]}]], "+", 
    FractionBox[
     RowBox[{"m3", " ", 
      RowBox[{"Log", "[", "m3", "]"}]}], 
     RowBox[{"16", " ", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "m3"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "m2"}], "+", "m3"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"m3", "-", "m4"}], ")"}], " ", 
      SuperscriptBox["\[Pi]", "2"]}]], "+", 
    FractionBox[
     RowBox[{"m4", " ", 
      RowBox[{"Log", "[", "m4", "]"}]}], 
     RowBox[{"16", " ", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "m4"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "m2"}], "+", "m4"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "m3"}], "+", "m4"}], ")"}], " ", 
      SuperscriptBox["\[Pi]", "2"]}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.6148130987693167`*^9, 3.614813158600038*^9, 
  3.674606607145978*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D0func", "[", 
  RowBox[{"x", ",", "y", ",", "0", ",", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.614813162778282*^9, 3.614813164741125*^9}}],

Cell[BoxData[
 RowBox[{"D0func", "[", 
  RowBox[{"x", ",", "y", ",", "0", ",", "0"}], "]"}]], "Output",
 CellChangeTimes->{3.614813165148766*^9, 3.674606607160482*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"DefineIntegralFunction4", "[", 
  RowBox[{"D0func", ",", "D0temp"}], "]"}]], "Input",
 CellChangeTimes->{{3.5741842522206697`*^9, 3.574184257406048*^9}, 
   3.5749007486822853`*^9}],

Cell[BoxData[{
 RowBox[{"DefineIntegralFunction4", "[", 
  RowBox[{"D1func", ",", "D1temp"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"DefineIntegralFunction4", "[", 
  RowBox[{"D2func", ",", "D2temp"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"DefineIntegralFunction4", "[", 
  RowBox[{"D3func", ",", "D3temp"}], "]"}]}], "Input",
 CellChangeTimes->{{3.5741842522206697`*^9, 3.574184257406048*^9}, {
  3.5741843018694572`*^9, 3.57418430878379*^9}, {3.574900750619013*^9, 
  3.574900751722684*^9}}],

Cell[BoxData[{
 RowBox[{"DefineIntegralFunction4", "[", 
  RowBox[{"D00func", ",", "D00temp"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"DefineIntegralFunction4", "[", 
  RowBox[{"D11func", ",", "D11temp"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"DefineIntegralFunction4", "[", 
  RowBox[{"D12func", ",", "D12temp"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"DefineIntegralFunction4", "[", 
  RowBox[{"D22func", ",", "D22temp"}], "]"}]}], "Input",
 CellChangeTimes->{{3.5741844000602083`*^9, 3.574184401789412*^9}, 
   3.57490075521059*^9, {3.6133191006539917`*^9, 3.613319109262628*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Write everything out to file for future use", "Subsection",
 CellChangeTimes->{{3.612800564097028*^9, 3.612800572416815*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Definition", "[", "B0func", "]"}], ">>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\n", 
 RowBox[{
  RowBox[{"Definition", "[", "B1func", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Definition", "[", "B0func0", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Definition", "[", "B1func0", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Definition", "[", "B0func1", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Definition", "[", "B1func1", "]"}], ">>>", 
   "\"\<~/LoopIntegrals.m\>\""}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Definition", "[", "C0func", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\n", 
 RowBox[{
  RowBox[{"Definition", "[", "C1func", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\n", 
 RowBox[{
  RowBox[{"Definition", "[", "C2func", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\n", 
 RowBox[{
  RowBox[{"Definition", "[", "C00func", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\n", 
 RowBox[{
  RowBox[{"Definition", "[", "C11func", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\n", 
 RowBox[{
  RowBox[{"Definition", "[", "C12func", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Definition", "[", "C22func", "]"}], ">>>", 
   "\"\<~/LoopIntegrals.m\>\""}], "\n", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Definition", "[", "C0func0", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\n", 
 RowBox[{
  RowBox[{"Definition", "[", "C1func0", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\n", 
 RowBox[{
  RowBox[{"Definition", "[", "C2func0", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\n", 
 RowBox[{
  RowBox[{"Definition", "[", "C00func0", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\n", 
 RowBox[{
  RowBox[{"Definition", "[", "C11func0", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\n", 
 RowBox[{
  RowBox[{"Definition", "[", "C12func0", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Definition", "[", "C22func0", "]"}], ">>>", 
   "\"\<~/LoopIntegrals.m\>\""}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Definition", "[", "C0func1", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\n", 
 RowBox[{
  RowBox[{"Definition", "[", "C1func1", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\n", 
 RowBox[{
  RowBox[{"Definition", "[", "C2func1", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\n", 
 RowBox[{
  RowBox[{"Definition", "[", "C00func1", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\n", 
 RowBox[{
  RowBox[{"Definition", "[", "C11func1", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\n", 
 RowBox[{
  RowBox[{"Definition", "[", "C12func1", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Definition", "[", "C22func1", "]"}], ">>>", 
   "\"\<~/LoopIntegrals.m\>\""}], "\n", "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{"Definition", "[", "D0func", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\n", 
 RowBox[{
  RowBox[{"Definition", "[", "D1func", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\n", 
 RowBox[{
  RowBox[{"Definition", "[", "D2func", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\n", 
 RowBox[{
  RowBox[{"Definition", "[", "D3func", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\n", 
 RowBox[{
  RowBox[{"Definition", "[", "D00func", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\n", 
 RowBox[{
  RowBox[{"Definition", "[", "D11func", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Definition", "[", "D12func", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Definition", "[", "D22func", "]"}], ">>>", 
  "\"\<~/LoopIntegrals.m\>\""}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.6128005438304377`*^9, 3.612800578260236*^9}, {
  3.612800694269403*^9, 3.612800707674554*^9}, {3.61331995900333*^9, 
  3.613319963655051*^9}, {3.613320153165607*^9, 3.6133201708648252`*^9}, {
  3.613320268494182*^9, 3.613320271189755*^9}, {3.674606758311288*^9, 
  3.674606775312838*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{740, 589},
WindowMargins->{{87, Automatic}, {Automatic, 0}},
ShowSelection->True,
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (July 22, \
2012)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 259, 3, 67, "Section"],
Cell[CellGroupData[{
Cell[863, 29, 102, 1, 34, "Subsection"],
Cell[968, 32, 233, 5, 27, "Input"],
Cell[CellGroupData[{
Cell[1226, 41, 187, 4, 27, "Input"],
Cell[1416, 47, 399, 9, 57, "Message"]
}, Open  ]],
Cell[1830, 59, 771, 16, 43, "Input"],
Cell[2604, 77, 817, 22, 58, "Input"],
Cell[3424, 101, 2436, 56, 163, "Input"],
Cell[5863, 159, 3102, 79, 253, "Input"],
Cell[CellGroupData[{
Cell[8990, 242, 1621, 38, 110, "Input"],
Cell[10614, 282, 5953, 104, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16604, 391, 958, 29, 54, "Input"],
Cell[17565, 422, 3699, 67, 72, "Output"]
}, Open  ]],
Cell[21279, 492, 1804, 52, 98, "Input"],
Cell[23086, 546, 3155, 73, 231, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26278, 624, 312, 6, 34, "Subsection"],
Cell[CellGroupData[{
Cell[26615, 634, 2186, 53, 122, "Input"],
Cell[28804, 689, 5887, 102, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34728, 796, 427, 9, 27, "Input"],
Cell[35158, 807, 7422, 151, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42617, 963, 2946, 71, 162, "Input"],
Cell[45566, 1036, 6181, 111, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[51784, 1152, 442, 10, 27, "Input"],
Cell[52229, 1164, 7912, 168, 70, "Output"]
}, Open  ]],
Cell[60156, 1335, 175, 3, 27, "Input"],
Cell[60334, 1340, 175, 3, 27, "Input"],
Cell[CellGroupData[{
Cell[60534, 1347, 158, 3, 27, "Input"],
Cell[60695, 1352, 372, 10, 70, "Output"]
}, Open  ]],
Cell[61082, 1365, 5817, 185, 512, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[66936, 1555, 294, 5, 41, "Subsection"],
Cell[CellGroupData[{
Cell[67255, 1564, 2513, 66, 126, "Input"],
Cell[69771, 1632, 5516, 97, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[75324, 1734, 395, 7, 27, "Input"],
Cell[75722, 1743, 7857, 166, 188, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[83616, 1914, 5167, 133, 186, "Input"],
Cell[88786, 2049, 6440, 124, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[95263, 2178, 728, 18, 43, "Input"],
Cell[95994, 2198, 9560, 217, 280, "Output"],
Cell[105557, 2417, 9535, 215, 282, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[115129, 2637, 7890, 202, 297, "Input"],
Cell[123022, 2841, 9487, 217, 142, "Output"]
}, Open  ]],
Cell[132524, 3061, 247, 5, 27, "Input"],
Cell[132774, 3068, 1142, 32, 73, "Input"],
Cell[133919, 3102, 4213, 96, 268, "Input"],
Cell[138135, 3200, 3133, 80, 268, "Input"],
Cell[141271, 3282, 203, 4, 27, "Input"],
Cell[141477, 3288, 375, 8, 43, "Input"],
Cell[141855, 3298, 643, 11, 73, "Input"],
Cell[142501, 3311, 313, 6, 27, "Input"],
Cell[142817, 3319, 553, 13, 43, "Input"],
Cell[143373, 3334, 943, 20, 73, "Input"],
Cell[144319, 3356, 373, 7, 27, "Input"],
Cell[144695, 3365, 618, 14, 43, "Input"],
Cell[145316, 3381, 1021, 20, 73, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[146374, 3406, 227, 4, 26, "Subsection"],
Cell[146604, 3412, 588, 19, 35, "Input"],
Cell[CellGroupData[{
Cell[147217, 3435, 233, 6, 28, "Input"],
Cell[147453, 3443, 5783, 111, 70, "Output"]
}, Open  ]],
Cell[153251, 3557, 2386, 77, 84, "Input"],
Cell[CellGroupData[{
Cell[155662, 3638, 657, 19, 80, "Input"],
Cell[156322, 3659, 6717, 138, 70, "Output"],
Cell[163042, 3799, 6814, 142, 70, "Output"],
Cell[169859, 3943, 6832, 143, 70, "Output"]
}, Open  ]],
Cell[176706, 4089, 7409, 193, 311, "Input"],
Cell[184118, 4284, 296, 6, 28, "Input"],
Cell[184417, 4292, 1332, 35, 80, "Input"],
Cell[185752, 4329, 4500, 105, 369, "Input"],
Cell[190255, 4436, 596, 17, 46, "Input"],
Cell[CellGroupData[{
Cell[190876, 4457, 100, 1, 28, "Input"],
Cell[190979, 4460, 450, 13, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[191466, 4478, 106, 1, 28, "Input"],
Cell[191575, 4481, 4653, 140, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[196265, 4626, 168, 3, 28, "Input"],
Cell[196436, 4631, 167, 3, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[196640, 4639, 153, 2, 28, "Input"],
Cell[196796, 4643, 1730, 54, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[198563, 4702, 168, 3, 28, "Input"],
Cell[198734, 4707, 167, 3, 70, "Output"]
}, Open  ]],
Cell[198916, 4713, 205, 4, 28, "Input"],
Cell[199124, 4719, 498, 9, 63, "Input"],
Cell[199625, 4730, 590, 10, 80, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[200252, 4745, 131, 1, 26, "Subsection"],
Cell[200386, 4748, 4351, 117, 643, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
